/* ---------------------------------------------------------------------------------------
 *  @file:    YTM32Z1MC0_startup_gcc.s
 *  @purpose: GNU Compiler Collection Startup File
 *            YTM32Z1MC0
 *  @version: 1.0
 *  @date:    Fri Apr 21 15:42:36 2023
 * ---------------------------------------------------------------------------------------*/
/*****************************************************************************/
/* Version: GNU Compiler Collection                                          */
/*****************************************************************************/
    .syntax unified
    .arch armv6-m

    .section .isr_vector, "a"
    .align 2
    .globl __isr_vector
__isr_vector:
    .long   __StackTop                                        /* Top of Stack */
    .long   Reset_Handler                                     /* Reset Handler */
    .long   0                                                 /* Reserved*/
    .long   HardFault_Handler                                 /* HardFault Handler*/
    .long   0xFFFFFF01                                        /* uint8 ,0x10,node address */
    .long   0xFFFF0064                                        /* uint16,0x14,lin polling window */
    .long   0x5A5A5A5A                                        /* uint32,0x18,flash valid mark,MUST not modify */
    .long   0x00000001                                        /* uint8 ,0x1C,wdg status before jump2app 1 Enable WDG */
    .long   0x00000001                                        /* uint8 ,0x20,LIN PullUp cfg */
    .long   0                                                 /* Reserved*/
    .long   0                                                 /* Reserved*/
    .long   SVC_Handler                                       /* SVC Handler*/
    .long   0                                                 /* Reserved*/
    .long   0                                                 /* Reserved*/
    .long   PendSV_Handler                                    /* PendSV Handler*/
    .long   SysTick_Handler                                   /* SysTick Handler*/

/* External Interrupts*/
    .long   Reserved10_IRQHandler                                       /* Reserved10 Handler*/
    .long   Reserved11_IRQHandler                                       /* Reserved11 Handler*/
    .long   Reserved12_IRQHandler                                       /* Reserved12 Handler*/
    .long   Reserved13_IRQHandler                                       /* Reserved13 Handler*/
    .long   Reserved14_IRQHandler                                       /* Reserved14 Handler*/
    .long   Reserved15_IRQHandler                                       /* Reserved15 Handler*/
    .long   Reserved16_IRQHandler                                       /* Reserved16 Handler*/
    .long   Reserved17_IRQHandler                                       /* Reserved17 Handler*/
    .long   Reserved18_IRQHandler                                       /* Reserved18 Handler*/
    .long   GPIOA_IRQHandler                                            /* GPIOA Handler*/
    .long   Reserved19_IRQHandler                                       /* Reserved19 Handler*/
    .long   MSPWM_IRQHandler                                            /* MSPWM Handler*/
    .long   CCTMR0_Channel_IRQHandler                                   /* CCTMR0_Channel Handler*/
    .long   CCTMR0_Ovf_IRQHandler                                       /* CCTMR0_Ovf Handler*/
    .long   CCTMR1_Channel_IRQHandler                                   /* CCTMR1_Channel Handler*/
    .long   CCTMR1_Ovf_IRQHandler                                       /* CCTMR1_Ovf Handler*/
    .long   PREDRV_Fault_IRQHandler                                     /* PREDRV_Fault Handler*/
    .long   PREDRV_Vds_IRQHandler                                       /* PREDRV_Vds Handler*/
    .long   EFM_IRQHandler                                              /* EFM Handler*/
    .long   Reserved20_IRQHandler                                       /* Reserved20 Handler*/
    .long   pTMR0_Ch0_IRQHandler                                        /* pTMR0_Ch0 Handler*/
    .long   pTMR0_Ch1_IRQHandler                                        /* pTMR0_Ch1 Handler*/
    .long   pTMR0_Ch2_IRQHandler                                        /* pTMR0_Ch2 Handler*/
    .long   pTMR0_Ch3_IRQHandler                                        /* pTMR0_Ch3 Handler*/
    .long   PCU_IRQHandler                                              /* PCU Handler*/
    .long   WDG_IRQHandler                                              /* WDG Handler*/
    .long   SPI0_IRQHandler                                             /* SPI0 Handler*/
    .long   LINPHY_CTRL_IRQHandler                                      /* LINPHY_CTRL Handler*/
    .long   ADC0_IRQHandler                                             /* ADC0 Handler*/
    .long   ZDU_IRQHandler                                              /* ZDU Handler*/
    .long   UART1_IRQHandler                                            /* UART1 Handler*/
    .long   UART0_IRQHandler                                            /* UART0 Handler*/

    .size    __isr_vector, . - __isr_vector

    .text
    .thumb

/* Reset Handler */

    .thumb_func
    .align 2
    .globl   Reset_Handler
    .weak    Reset_Handler
    .type    Reset_Handler, %function
Reset_Handler:
    cpsid   i               /* Mask interrupts */

    /* Init the rest of the registers */
    ldr     r1,=0
    ldr     r2,=0
    ldr     r3,=0
    ldr     r4,=0
    ldr     r5,=0
    ldr     r6,=0
    ldr     r7,=0
    mov     r8,r7
    mov     r9,r7
    mov     r10,r7
    mov     r11,r7
    mov     r12,r7

#ifndef START_NO_ECC_INIT

    /* Init ECC RAM */

    ldr r1, =__RAM_START
    ldr r2, =__RAM_END

    subs    r2, r1
    subs    r2, #1
    ble SRAM_LOOP_END

    movs    r0, 0
    movs    r3, #4
SRAM_LOOP:
    str r0, [r1]
    add	r1, r1, r3
    subs r2, 4
    bge SRAM_LOOP
SRAM_LOOP_END:
#endif
    
    /* Initialize the stack pointer */
    ldr     r0,=__StackTop
    mov     r13,r0

#ifndef __NO_SYSTEM_INIT
    /* Call the system init routine */
    ldr     r0,=SystemInit
    blx     r0
#endif

    /* Init .data and .bss sections */
    ldr     r0,=init_data_bss
    blx     r0
    cpsie   i               /* Unmask interrupts */
    bl      main
JumpToSelf:
    b       JumpToSelf

    .pool
    .size Reset_Handler, . - Reset_Handler

    .align  1
    .thumb_func
    .weak DefaultISR
    .type DefaultISR, %function
DefaultISR:
    b       DefaultISR
    .size DefaultISR, . - DefaultISR

/*    Macro to define default handlers. Default handler
 *    will be weak symbol and just dead loops. They can be
 *    overwritten by other handlers */
    .macro def_irq_handler  handler_name
    .weak \handler_name
    .set  \handler_name, DefaultISR
    .endm

    /* Exception Handlers */
    def_irq_handler    Reserved0_Handler
    def_irq_handler    HardFault_Handler
    def_irq_handler    Reserved1_Handler
    def_irq_handler    Reserved2_Handler
    def_irq_handler    Reserved3_Handler
    def_irq_handler    Reserved4_Handler
    def_irq_handler    Reserved5_Handler
    def_irq_handler    Reserved6_Handler
    def_irq_handler    Reserved7_Handler
    def_irq_handler    SVC_Handler
    def_irq_handler    Reserved8_Handler
    def_irq_handler    Reserved9_Handler
    def_irq_handler    PendSV_Handler
    def_irq_handler    SysTick_Handler

    /* Device Exception Handlers */

    def_irq_handler    Reserved10_IRQHandler
    def_irq_handler    Reserved11_IRQHandler
    def_irq_handler    Reserved12_IRQHandler
    def_irq_handler    Reserved13_IRQHandler
    def_irq_handler    Reserved14_IRQHandler
    def_irq_handler    Reserved15_IRQHandler
    def_irq_handler    Reserved16_IRQHandler
    def_irq_handler    Reserved17_IRQHandler
    def_irq_handler    Reserved18_IRQHandler
    def_irq_handler    GPIOA_IRQHandler
    def_irq_handler    Reserved19_IRQHandler
    def_irq_handler    MSPWM_IRQHandler
    def_irq_handler    CCTMR0_Channel_IRQHandler
    def_irq_handler    CCTMR0_Ovf_IRQHandler
    def_irq_handler    CCTMR1_Channel_IRQHandler
    def_irq_handler    CCTMR1_Ovf_IRQHandler
    def_irq_handler    PREDRV_Fault_IRQHandler
    def_irq_handler    PREDRV_Vds_IRQHandler
    def_irq_handler    EFM_IRQHandler
    def_irq_handler    Reserved20_IRQHandler
    def_irq_handler    pTMR0_Ch0_IRQHandler
    def_irq_handler    pTMR0_Ch1_IRQHandler
    def_irq_handler    pTMR0_Ch2_IRQHandler
    def_irq_handler    pTMR0_Ch3_IRQHandler
    def_irq_handler    PCU_IRQHandler
    def_irq_handler    WDG_IRQHandler
    def_irq_handler    SPI0_IRQHandler
    def_irq_handler    LINPHY_CTRL_IRQHandler
    def_irq_handler    ADC0_IRQHandler
    def_irq_handler    ZDU_IRQHandler
    def_irq_handler    UART1_IRQHandler
    def_irq_handler    UART0_IRQHandler

    .end