/*
** ###################################################################
**     Processor:           YTM32Z1MC0
**     Version:             rev. 1.0, Fri Apr 21 15:42:36 2023
**
**     Abstract:
**         Peripheral Access Layer for YTM32Z1MC0
**
**     Copyright (c) YTMicro Semiconductor, Inc.
**     Copyright 2016-2020 YTM
**     All rights reserved.
**
** ###################################################################
*/

/*!
 * @file YTM32Z1MC0.h
 * @version 1.0
 * @date Fri Apr 21 15:42:36 2023
 * @brief Peripheral Access Layer for YTM32Z1MC0
 *
 * This file contains register definitions and macros for easy access to their
 * bit fields.
 *
 * This file assumes LITTLE endian system.
 */

/* ----------------------------------------------------------------------------
   -- MCU activation
   ---------------------------------------------------------------------------- */

/* Prevention from multiple including the same memory map */
#if !defined(YTM32Z1MC0_H_)  /* Check if memory map has not been already included */
#define YTM32Z1MC0_H_
#define MCU_YTM32Z1MC0

/* Check if another memory map has not been also included */
#if (defined(MCU_ACTIVE))
  #error YTM32Z1MC0 memory map: There is already included another memory map. Only one memory map can be included.
#endif /* (defined(MCU_ACTIVE)) */
#define MCU_ACTIVE

/** Memory map major version (memory maps with equal major version number are
 * compatible) */
#define MCU_MEM_MAP_VERSION 0x0100u
/** Memory map minor version */
#define MCU_MEM_MAP_VERSION_MINOR 0x0003u

#include <stdint.h>

/* ----------------------------------------------------------------------------
   -- Generic macros
   ---------------------------------------------------------------------------- */

/* IO definitions (access restrictions to peripheral registers) */
/**
*   IO Type Qualifiers are used
*   \li to specify the access to peripheral variables.
*   \li for automatic generation of peripheral register debug information.
*/
#ifndef __IO
#ifdef __cplusplus
  #define   __I     volatile             /*!< Defines 'read only' permissions                 */
#else
  #define   __I     volatile const       /*!< Defines 'read only' permissions                 */
#endif
#define     __O     volatile             /*!< Defines 'write only' permissions                */
#define     __IO    volatile             /*!< Defines 'read / write' permissions              */
#endif


/**
* @brief 32 bits memory read macro.
*/
#if !defined(REG_READ32)
  #define REG_READ32(address)               (*(volatile uint32_t*)(address))
#endif

/**
* @brief 32 bits memory write macro.
*/
#if !defined(REG_WRITE32)
  #define REG_WRITE32(address, value)       ((*(volatile uint32_t*)(address))= (uint32_t)(value))
#endif

/**
* @brief 32 bits bits setting macro.
*/
#if !defined(REG_BIT_SET32)
  #define REG_BIT_SET32(address, mask)      ((*(volatile uint32_t*)(address))|= (uint32_t)(mask))
#endif

/**
* @brief 32 bits bits clearing macro.
*/
#if !defined(REG_BIT_CLEAR32)
  #define REG_BIT_CLEAR32(address, mask)    ((*(volatile uint32_t*)(address))&= ((uint32_t)~((uint32_t)(mask))))
#endif

/**
* @brief 32 bit clear bits and set with new value
* @note It is user's responsability to make sure that value has only "mask" bits set - (value&~mask)==0
*/
#if !defined(REG_RMW32)
  #define REG_RMW32(address, mask, value)   (REG_WRITE32((address), ((REG_READ32(address)& ((uint32_t)~((uint32_t)(mask))))| ((uint32_t)(value)))))
#endif
/* ----------------------------------------------------------------------------
   -- Interrupt vector numbers for YTM32Z1MC0
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Interrupt_vector_numbers_YTM32B1L Interrupt vector numbers for YTM32B1L
 * @{
 */

/** Interrupt Number Definitions */
#define NUMBER_OF_INT_VECTORS 48u          /**< Number of interrupts in the Vector table */

/**
 * @brief Defines the Interrupt Numbers definitions
 *
 * This enumeration is used to configure the interrupts.
 *
 * Implements : IRQn_Type_Class
 */
typedef enum
{
  /* Auxiliary constants */
  NotAvail_IRQn     = -128,                /**< Not available device specific interrupt */

  /* Core interrupts */
  HardFault_IRQn              =  -13,                /**< HardFault Interrupt */ 
  SVC_IRQn                    =   -5,                /**< SVC Interrupt */ 
  PendSV_IRQn                 =   -2,                /**< PendSV Interrupt */ 
  SysTick_IRQn                =   -1,                /**< SysTick Interrupt */ 
  /* Device specific interrupts */
  Reserved10_IRQn             =    0,                /**< Reserved10 Interrupt */ 
  Reserved11_IRQn             =    1,                /**< Reserved11 Interrupt */ 
  Reserved12_IRQn             =    2,                /**< Reserved12 Interrupt */ 
  Reserved13_IRQn             =    3,                /**< Reserved13 Interrupt */ 
  Reserved14_IRQn             =    4,                /**< Reserved14 Interrupt */ 
  Reserved15_IRQn             =    5,                /**< Reserved15 Interrupt */ 
  Reserved16_IRQn             =    6,                /**< Reserved16 Interrupt */ 
  Reserved17_IRQn             =    7,                /**< Reserved17 Interrupt */ 
  Reserved18_IRQn             =    8,                /**< Reserved18 Interrupt */ 
  GPIOA_IRQn                  =    9,                /**< GPIOA Interrupt */ 
  Reserved19_IRQn             =   10,                /**< Reserved19 Interrupt */ 
  MSPWM_IRQn                  =   11,                /**< MSPWM Interrupt */ 
  CCTMR0_Channel_IRQn         =   12,                /**< CCTMR0_Channel Interrupt */ 
  CCTMR0_Ovf_IRQn             =   13,                /**< CCTMR0_Ovf Interrupt */ 
  CCTMR1_Channel_IRQn         =   14,                /**< CCTMR1_Channel Interrupt */ 
  CCTMR1_Ovf_IRQn             =   15,                /**< CCTMR1_Ovf Interrupt */ 
  PREDRV_Fault_IRQn           =   16,                /**< PREDRV_Fault Interrupt */ 
  PREDRV_Vds_IRQn             =   17,                /**< PREDRV_Vds Interrupt */ 
  EFM_IRQn                    =   18,                /**< EFM Interrupt */ 
  Reserved20_IRQn             =   19,                /**< Reserved20 Interrupt */ 
  pTMR0_Ch0_IRQn              =   20,                /**< pTMR0_Ch0 Interrupt */ 
  pTMR0_Ch1_IRQn              =   21,                /**< pTMR0_Ch1 Interrupt */ 
  pTMR0_Ch2_IRQn              =   22,                /**< pTMR0_Ch2 Interrupt */ 
  pTMR0_Ch3_IRQn              =   23,                /**< pTMR0_Ch3 Interrupt */ 
  PCU_IRQn                    =   24,                /**< PCU Interrupt */ 
  WDG_IRQn                    =   25,                /**< WDG Interrupt */ 
  SPI0_IRQn                   =   26,                /**< SPI0 Interrupt */ 
  LINPHY_CTRL_IRQn            =   27,                /**< LINPHY_CTRL Interrupt */ 
  ADC0_IRQn                   =   28,                /**< ADC0 Interrupt */ 
  ZDU_IRQn                    =   29,                /**< ZDU Interrupt */ 
  UART1_IRQn                  =   30,                /**< UART1 Interrupt */ 
  UART0_IRQn                  =   31,                /**< UART0 Interrupt */ 
} IRQn_Type;

/*!
 * @}
 */ /* end of group Interrupt_vector_numbers YTM32Z1MC0 */

/* ================================================================================ */
/* ================      Processor and Core Peripheral Section     ================ */
/* ================================================================================ */

/* -------  Start of section using anonymous unions and disabling warnings  ------- */
#if   defined (__CC_ARM)
  #pragma push
  #pragma anon_unions
#elif defined (__ICCARM__)
  #pragma language=extended
#elif defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
  #pragma clang diagnostic push
  #pragma clang diagnostic ignored "-Wc11-extensions"
  #pragma clang diagnostic ignored "-Wreserved-id-macro"
#elif defined (__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined (__TMS470__)
  /* anonymous unions are enabled by default */
#elif defined (__TASKING__)
  #pragma warning 586
#elif defined (__CSMC__)
  /* anonymous unions are enabled by default */
#else
  #warning Not supported compiler type
#endif


/* --------  Configuration of Core Peripherals  ----------------------------------- */
#define __CM0PLUS_REV             0x0001U          /* Core revision r0p1 */
#define __MPU_PRESENT             0U       /* MPU present */
#define __VTOR_PRESENT            1U      /* VTOR present */
#define __NVIC_PRIO_BITS          2U    /* Number of Bits used for Priority Levels */
#define __Vendor_SysTickConfig    0U    /* Set to 1 if different SysTick Config is used */

#include "core_cm0plus.h"                      /* Processor and core peripherals */
#include "core_common.h"                      /* Processor common */
#include "system_YTM32Z1MC0.h"                 /* System Header */


/* --------  End of section using anonymous unions and disabling warnings  -------- */
#if   defined (__CC_ARM)
  #pragma pop
#elif defined (__ICCARM__)
  /* leave anonymous unions enabled */
#elif (defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050))
  #pragma clang diagnostic pop
#elif defined (__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined (__TMS470__)
  /* anonymous unions are enabled by default */
#elif defined (__TASKING__)
  #pragma warning restore
#elif defined (__CSMC__)
  /* anonymous unions are enabled by default */
#else
  #warning Not supported compiler type
#endif
/* ----------------------------------------------------------------------------
   -- Device Peripheral Access Layer for YTM32Z1MC0
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Peripheral_access_layer_YTM32Z1MC0 Device Peripheral Access Layer for YTM32Z1MC0
 * @{
 */

/* @brief This module covers memory mapped registers available on SoC */

/* -------------------------------------------------------------
   -- EFM Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup EFM_Peripheral_Access_Layer EFM Peripheral Access Layer
 * @{
 */


/** EFM - Size of Registers Arrays */

/* EFM Register Layout Typedef */
typedef struct {
    __IO uint32_t CTRL;                               /**< Control Register, offset: 0x0000 */
    __IO uint32_t STS;                                /**< Status Register, offset: 0x0004 */
    __IO uint32_t CMD;                                /**< Flash Command Register, offset: 0x0008 */
    __IO uint32_t CMD_UNLOCK;                         /**< Command Unlock, offset: 0x000C */
    __IO uint32_t UNRECOV_ECC_ERR;                    /**< Unrecovery ECC Error, offset: 0x0010 */
    __IO uint32_t NVR_ADDR;                           /**< EFM NVR Address, offset: 0x0014 */
    __IO uint32_t NVR_DATA;                           /**< EFM NVR Data, offset: 0x0018 */
    __IO uint32_t Reserved0[ 1];                      /**< Reserved0, offset: 0x001C */
    __IO uint32_t EECTRL;                             /**< EEPROM Control Register, offset: 0x0020 */
    __IO uint32_t EESTS;                              /**< EEPROM Status Register, offset: 0x0024 */
    __IO uint32_t EECMD;                              /**< EEPROM Command, offset: 0x0028 */
    __IO uint32_t EECMD_UNLOCK;                       /**< EEPROM Command Unlock, offset: 0x002C */
    __IO uint32_t Reserved1[116];                      /**< Reserved1, offset: 0x0030 */
    __IO uint32_t CUS_KEY;                            /**< EFM Customer Key, offset: 0x0200 */
    __IO uint32_t RESERVED_14;                        /**< RESERVED_14, offset: 0x0204 */
    __IO uint32_t Reserved3[63];                      /**< Reserved3, offset: 0x0208 */
    __IO uint32_t RESERVED_16;                        /**< RESERVED_16, offset: 0x0304 */

} EFM_Type, *EFM_MemMapPtr;

/** Number of instances of the EFM module. */
#define EFM_INSTANCE_COUNT                             (1u)

/* EFM base address */
#define EFM_BASE                                          (0x40020000)
#define EFM                                               ((EFM_Type *)(EFM_BASE))

/** Array initializer of EFM peripheral base addresses */
#define EFM_BASE_ADDRS                                     { EFM_BASE }
/** Array initializer of EFM peripheral base pointers */
#define EFM_BASE_PTRS                                      { EFM }
/** Number of interrupt vector arrays for the EFM module. */
#define EFM_IRQS_ARR_COUNT                                 (1u)
/** Number of interrupt channels for the EFM. */
#define EFM_IRQS_CH_COUNT                         (1u)
/** Interrupt vectors for the EFM peripheral type */
#define EFM_IRQS                                  { EFM_IRQn }

/* EFM Register Mask */
/* EFM_CTRL Register */
#define EFM_CTRL_PRS_MASK                                  (0x1F0000U)
#define EFM_CTRL_PRS_SHIFT                                 (16U)
#define EFM_CTRL_PRS(x)                                    (((uint32_t)(((uint32_t)(x)) << EFM_CTRL_PRS_SHIFT)) & EFM_CTRL_PRS_MASK)
#define EFM_CTRL_RWS_MASK                                  (0x300U)
#define EFM_CTRL_RWS_SHIFT                                 (8U)
#define EFM_CTRL_RWS(x)                                    (((uint32_t)(((uint32_t)(x)) << EFM_CTRL_RWS_SHIFT)) & EFM_CTRL_RWS_MASK)
#define EFM_CTRL_WE_MASK                                   (0x80U)
#define EFM_CTRL_WE_SHIFT                                  (7U)
#define EFM_CTRL_WE(x)                                     (((uint32_t)(((uint32_t)(x)) << EFM_CTRL_WE_SHIFT)) & EFM_CTRL_WE_MASK)
#define EFM_CTRL_ACCERRIE_MASK                             (0x8U)
#define EFM_CTRL_ACCERRIE_SHIFT                            (3U)
#define EFM_CTRL_ACCERRIE(x)                               (((uint32_t)(((uint32_t)(x)) << EFM_CTRL_ACCERRIE_SHIFT)) & EFM_CTRL_ACCERRIE_MASK)
#define EFM_CTRL_UNRECOVERRIE_MASK                         (0x4U)
#define EFM_CTRL_UNRECOVERRIE_SHIFT                        (2U)
#define EFM_CTRL_UNRECOVERRIE(x)                           (((uint32_t)(((uint32_t)(x)) << EFM_CTRL_UNRECOVERRIE_SHIFT)) & EFM_CTRL_UNRECOVERRIE_MASK)
#define EFM_CTRL_RECOVERRIE_MASK                           (0x2U)
#define EFM_CTRL_RECOVERRIE_SHIFT                          (1U)
#define EFM_CTRL_RECOVERRIE(x)                             (((uint32_t)(((uint32_t)(x)) << EFM_CTRL_RECOVERRIE_SHIFT)) & EFM_CTRL_RECOVERRIE_MASK)
#define EFM_CTRL_DONEIE_MASK                               (0x1U)
#define EFM_CTRL_DONEIE_SHIFT                              (0U)
#define EFM_CTRL_DONEIE(x)                                 (((uint32_t)(((uint32_t)(x)) << EFM_CTRL_DONEIE_SHIFT)) & EFM_CTRL_DONEIE_MASK)
/* EFM_STS Register */
#define EFM_STS_IDLE_MASK                                  (0x80U)
#define EFM_STS_IDLE_SHIFT                                 (7U)
#define EFM_STS_IDLE(x)                                    (((uint32_t)(((uint32_t)(x)) << EFM_STS_IDLE_SHIFT)) & EFM_STS_IDLE_MASK)
#define EFM_STS_CMD_FAIL_MASK                              (0x40U)
#define EFM_STS_CMD_FAIL_SHIFT                             (6U)
#define EFM_STS_CMD_FAIL(x)                                (((uint32_t)(((uint32_t)(x)) << EFM_STS_CMD_FAIL_SHIFT)) & EFM_STS_CMD_FAIL_MASK)
#define EFM_STS_ACCERR_MASK                                (0x8U)
#define EFM_STS_ACCERR_SHIFT                               (3U)
#define EFM_STS_ACCERR(x)                                  (((uint32_t)(((uint32_t)(x)) << EFM_STS_ACCERR_SHIFT)) & EFM_STS_ACCERR_MASK)
#define EFM_STS_UNRECOVERR_MASK                            (0x4U)
#define EFM_STS_UNRECOVERR_SHIFT                           (2U)
#define EFM_STS_UNRECOVERR(x)                              (((uint32_t)(((uint32_t)(x)) << EFM_STS_UNRECOVERR_SHIFT)) & EFM_STS_UNRECOVERR_MASK)
#define EFM_STS_RECOVERR_MASK                              (0x2U)
#define EFM_STS_RECOVERR_SHIFT                             (1U)
#define EFM_STS_RECOVERR(x)                                (((uint32_t)(((uint32_t)(x)) << EFM_STS_RECOVERR_SHIFT)) & EFM_STS_RECOVERR_MASK)
#define EFM_STS_DONE_MASK                                  (0x1U)
#define EFM_STS_DONE_SHIFT                                 (0U)
#define EFM_STS_DONE(x)                                    (((uint32_t)(((uint32_t)(x)) << EFM_STS_DONE_SHIFT)) & EFM_STS_DONE_MASK)
/* EFM_CMD Register */
#define EFM_CMD_VAL_MASK                                   (0xFFU)
#define EFM_CMD_VAL_SHIFT                                  (0U)
#define EFM_CMD_VAL(x)                                     (((uint32_t)(((uint32_t)(x)) << EFM_CMD_VAL_SHIFT)) & EFM_CMD_VAL_MASK)
/* EFM_CMD_UNLOCK Register */
#define EFM_CMD_UNLOCK_CMD_UNLOCK_KEY_MASK                 (0xFFFFFFFFU)
#define EFM_CMD_UNLOCK_CMD_UNLOCK_KEY_SHIFT                (0U)
#define EFM_CMD_UNLOCK_CMD_UNLOCK_KEY(x)                   (((uint32_t)(((uint32_t)(x)) << EFM_CMD_UNLOCK_CMD_UNLOCK_KEY_SHIFT)) & EFM_CMD_UNLOCK_CMD_UNLOCK_KEY_MASK)
/* EFM_UNRECOV_ECC_ERR Register */
#define EFM_UNRECOV_ECC_ERR_ADDR_MASK                      (0xFFFFFFFFU)
#define EFM_UNRECOV_ECC_ERR_ADDR_SHIFT                     (0U)
#define EFM_UNRECOV_ECC_ERR_ADDR(x)                        (((uint32_t)(((uint32_t)(x)) << EFM_UNRECOV_ECC_ERR_ADDR_SHIFT)) & EFM_UNRECOV_ECC_ERR_ADDR_MASK)
/* EFM_NVR_ADDR Register */
#define EFM_NVR_ADDR_ADDR_MASK                             (0xFFFFFFFFU)
#define EFM_NVR_ADDR_ADDR_SHIFT                            (0U)
#define EFM_NVR_ADDR_ADDR(x)                               (((uint32_t)(((uint32_t)(x)) << EFM_NVR_ADDR_ADDR_SHIFT)) & EFM_NVR_ADDR_ADDR_MASK)
/* EFM_NVR_DATA Register */
#define EFM_NVR_DATA_DATA_MASK                             (0xFFFFFFFFU)
#define EFM_NVR_DATA_DATA_SHIFT                            (0U)
#define EFM_NVR_DATA_DATA(x)                               (((uint32_t)(((uint32_t)(x)) << EFM_NVR_DATA_DATA_SHIFT)) & EFM_NVR_DATA_DATA_MASK)
/* EFM_EECTRL Register */
#define EFM_EECTRL_WE_MASK                                 (0x80U)
#define EFM_EECTRL_WE_SHIFT                                (7U)
#define EFM_EECTRL_WE(x)                                   (((uint32_t)(((uint32_t)(x)) << EFM_EECTRL_WE_SHIFT)) & EFM_EECTRL_WE_MASK)
/* EFM_EESTS Register */
#define EFM_EESTS_NVRAM_DATA_EQ_MASK                       (0x8000U)
#define EFM_EESTS_NVRAM_DATA_EQ_SHIFT                      (15U)
#define EFM_EESTS_NVRAM_DATA_EQ(x)                         (((uint32_t)(((uint32_t)(x)) << EFM_EESTS_NVRAM_DATA_EQ_SHIFT)) & EFM_EESTS_NVRAM_DATA_EQ_MASK)
#define EFM_EESTS_IDLE_MASK                                (0x80U)
#define EFM_EESTS_IDLE_SHIFT                               (7U)
#define EFM_EESTS_IDLE(x)                                  (((uint32_t)(((uint32_t)(x)) << EFM_EESTS_IDLE_SHIFT)) & EFM_EESTS_IDLE_MASK)
#define EFM_EESTS_CMD_FAIL_MASK                            (0x40U)
#define EFM_EESTS_CMD_FAIL_SHIFT                           (6U)
#define EFM_EESTS_CMD_FAIL(x)                              (((uint32_t)(((uint32_t)(x)) << EFM_EESTS_CMD_FAIL_SHIFT)) & EFM_EESTS_CMD_FAIL_MASK)
#define EFM_EESTS_ACCERR_MASK                              (0x8U)
#define EFM_EESTS_ACCERR_SHIFT                             (3U)
#define EFM_EESTS_ACCERR(x)                                (((uint32_t)(((uint32_t)(x)) << EFM_EESTS_ACCERR_SHIFT)) & EFM_EESTS_ACCERR_MASK)
#define EFM_EESTS_DONE_MASK                                (0x1U)
#define EFM_EESTS_DONE_SHIFT                               (0U)
#define EFM_EESTS_DONE(x)                                  (((uint32_t)(((uint32_t)(x)) << EFM_EESTS_DONE_SHIFT)) & EFM_EESTS_DONE_MASK)
/* EFM_EECMD Register */
#define EFM_EECMD_EECMD_MASK                               (0xFU)
#define EFM_EECMD_EECMD_SHIFT                              (0U)
#define EFM_EECMD_EECMD(x)                                 (((uint32_t)(((uint32_t)(x)) << EFM_EECMD_EECMD_SHIFT)) & EFM_EECMD_EECMD_MASK)
/* EFM_EECMD_UNLOCK Register */
#define EFM_EECMD_UNLOCK_KEY_MASK                          (0xFFFFFFFFU)
#define EFM_EECMD_UNLOCK_KEY_SHIFT                         (0U)
#define EFM_EECMD_UNLOCK_KEY(x)                            (((uint32_t)(((uint32_t)(x)) << EFM_EECMD_UNLOCK_KEY_SHIFT)) & EFM_EECMD_UNLOCK_KEY_MASK)
/* EFM_CUS_KEY Register */
#define EFM_CUS_KEY_VAL_MASK                               (0xFFFFFFU)
#define EFM_CUS_KEY_VAL_SHIFT                              (0U)
#define EFM_CUS_KEY_VAL(x)                                 (((uint32_t)(((uint32_t)(x)) << EFM_CUS_KEY_VAL_SHIFT)) & EFM_CUS_KEY_VAL_MASK)


/*!
 * @}
 */ /* end of group EFM_Register_Masks */


/*!
 * @}
 */ /* end of group EFM_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- GPIO Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup GPIO_Peripheral_Access_Layer GPIO Peripheral Access Layer
 * @{
 */


/** GPIO - Size of Registers Arrays */
#define GPIO_PCR_COUNT                     (8)

/* GPIO Register Layout Typedef */
typedef struct {
    __IO uint32_t PDOR;                               /**< Port Data Output Register, offset: 0x0000 */
    __O  uint32_t PSOR;                               /**< Port Set Output Register, offset: 0x0004 */
    __O  uint32_t PCOR;                               /**< Port Clear Output Register, offset: 0x0008 */
    __O  uint32_t PTOR;                               /**< Port Toggle Output Register, offset: 0x000C */
    __I  uint32_t PDIR;                               /**< Port Data Input Register, offset: 0x0010 */
    __IO uint32_t POER;                               /**< Port Output Enable Register, offset: 0x0014 */
    __IO uint32_t PIER;                               /**< Port Input Enable Register, offset: 0x0018 */
    __IO uint32_t PIFR;                               /**< Port Interrupt Status Flag Register, offset: 0x001C */
    __IO uint32_t Reserved0[16];                      /**< Reserved0, offset: 0x0020 */
    __O  uint32_t FILT;                               /**< Filter configuration register, offset: 0x0060 */
    __IO uint32_t Reserved1[ 7];                      /**< Reserved1, offset: 0x0064 */
    __IO uint32_t PCR[ 8];                            /**< Port Control Register, offset: 0x0080 */

} GPIO_Type, *GPIO_MemMapPtr;

/** Number of instances of the GPIO module. */
#define GPIO_INSTANCE_COUNT                            (1u)

/* GPIOA  base address */
#define GPIOA_BASE                                         (0x4000F000)
#define GPIOA                                              ((GPIO_Type *)(GPIOA_BASE))

/** Array initializer of GPIO peripheral base addresses */
#define GPIO_BASE_ADDRS                                    { GPIOA_BASE }
/** Array initializer of GPIO peripheral base pointers */
#define GPIO_BASE_PTRS                                     { GPIOA }
/** Number of interrupt vector arrays for the GPIO module. */
#define GPIO_IRQS_ARR_COUNT                                (1u)
/** Number of interrupt channels for the GPIO. */
#define GPIO_IRQS_CH_COUNT                        (1u)
/** Interrupt vectors for the GPIO peripheral type */
#define GPIO_IRQS                                 { GPIOA_IRQn }

/* GPIO Register Mask */
/* GPIO_PDOR Register */
#define GPIO_PDOR_PDO_MASK                                  (0x1FFU)
#define GPIO_PDOR_PDO_SHIFT                                 (0U)
#define GPIO_PDOR_PDO(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_PDOR_PDO_SHIFT)) & GPIO_PDOR_PDO_MASK)
/* GPIO_PSOR Register */
#define GPIO_PSOR_PSO_MASK                                  (0x1FFU)
#define GPIO_PSOR_PSO_SHIFT                                 (0U)
#define GPIO_PSOR_PSO(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_PSOR_PSO_SHIFT)) & GPIO_PSOR_PSO_MASK)
/* GPIO_PCOR Register */
#define GPIO_PCOR_PCO_MASK                                  (0x1FFU)
#define GPIO_PCOR_PCO_SHIFT                                 (0U)
#define GPIO_PCOR_PCO(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_PCOR_PCO_SHIFT)) & GPIO_PCOR_PCO_MASK)
/* GPIO_PTOR Register */
#define GPIO_PTOR_PTO_MASK                                  (0x1FFU)
#define GPIO_PTOR_PTO_SHIFT                                 (0U)
#define GPIO_PTOR_PTO(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_PTOR_PTO_SHIFT)) & GPIO_PTOR_PTO_MASK)
/* GPIO_PDIR Register */
#define GPIO_PDIR_PDI_MASK                                  (0x1FFU)
#define GPIO_PDIR_PDI_SHIFT                                 (0U)
#define GPIO_PDIR_PDI(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_PDIR_PDI_SHIFT)) & GPIO_PDIR_PDI_MASK)
/* GPIO_POER Register */
#define GPIO_POER_POE_MASK                                  (0x1FFU)
#define GPIO_POER_POE_SHIFT                                 (0U)
#define GPIO_POER_POE(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_POER_POE_SHIFT)) & GPIO_POER_POE_MASK)
/* GPIO_PIER Register */
#define GPIO_PIER_PIE_MASK                                  (0x1FFU)
#define GPIO_PIER_PIE_SHIFT                                 (0U)
#define GPIO_PIER_PIE(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_PIER_PIE_SHIFT)) & GPIO_PIER_PIE_MASK)
/* GPIO_PIFR Register */
#define GPIO_PIFR_PIF_MASK                                  (0x1FFU)
#define GPIO_PIFR_PIF_SHIFT                                 (0U)
#define GPIO_PIFR_PIF(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_PIFR_PIF_SHIFT)) & GPIO_PIFR_PIF_MASK)
/* GPIO_FILT Register */
#define GPIO_FILT_DFW_WIDTH                                 (5)
#define GPIO_FILT_DFW_MASK                                  (0x1F000000U)
#define GPIO_FILT_DFW_SHIFT                                 (24U)
#define GPIO_FILT_DFW(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_FILT_DFW_SHIFT)) & GPIO_FILT_DFW_MASK)
/* GPIO_PCR Register */
#define GPIO_PCR_DFW_WIDTH                                  (5)
#define GPIO_PCR_DFW_MASK                                   (0x1F000000U)
#define GPIO_PCR_DFW_SHIFT                                  (24U)
#define GPIO_PCR_DFW(x)                                     (((uint32_t)(((uint32_t)(x)) << GPIO_PCR_DFW_SHIFT)) & GPIO_PCR_DFW_MASK)
#define GPIO_PCR_DFE_MASK                                   (0x10000U)
#define GPIO_PCR_DFE_SHIFT                                  (16U)
#define GPIO_PCR_DFE(x)                                     (((uint32_t)(((uint32_t)(x)) << GPIO_PCR_DFE_SHIFT)) & GPIO_PCR_DFE_MASK)
#define GPIO_PCR_INVE_MASK                                  (0x10U)
#define GPIO_PCR_INVE_SHIFT                                 (4U)
#define GPIO_PCR_INVE(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_PCR_INVE_SHIFT)) & GPIO_PCR_INVE_MASK)
#define GPIO_PCR_IRQC_MASK                                  (0xFU)
#define GPIO_PCR_IRQC_SHIFT                                 (0U)
#define GPIO_PCR_IRQC(x)                                    (((uint32_t)(((uint32_t)(x)) << GPIO_PCR_IRQC_SHIFT)) & GPIO_PCR_IRQC_MASK)


/*!
 * @}
 */ /* end of group GPIO_Register_Masks */


/*!
 * @}
 */ /* end of group GPIO_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- PCTRL Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup PCTRL_Peripheral_Access_Layer PCTRL Peripheral Access Layer
 * @{
 */


/** PCTRL - Size of Registers Arrays */
#define PCTRL_PCR_COUNT                     (8)

/* PCTRL Register Layout Typedef */
typedef struct {
    __IO uint32_t PCR[ 8];                            /**< Port Control Register, offset: 0x0000 */

} PCTRL_Type, *PCTRL_MemMapPtr;

/** Number of instances of the PCTRL module. */
#define PCTRL_INSTANCE_COUNT                           (1u)

/* PCTRLA  base address */
#define PCTRLA_BASE                                        (0x40049000)
#define PCTRLA                                             ((PCTRL_Type *)(PCTRLA_BASE))

/** Array initializer of PCTRL peripheral base addresses */
#define PCTRL_BASE_ADDRS                                   { PCTRLA_BASE }
/** Array initializer of PCTRL peripheral base pointers */
#define PCTRL_BASE_PTRS                                    { PCTRLA }

/* PCTRL Register Mask */
/* PCTRL_PCR Register */
#define PCTRL_PCR_MUX_WIDTH                                  (3)
#define PCTRL_PCR_MUX_MASK                                   (0x700U)
#define PCTRL_PCR_MUX_SHIFT                                  (8U)
#define PCTRL_PCR_MUX(x)                                     (((uint32_t)(((uint32_t)(x)) << PCTRL_PCR_MUX_SHIFT)) & PCTRL_PCR_MUX_MASK)
#define PCTRL_PCR_ODE_MASK                                   (0x20U)
#define PCTRL_PCR_ODE_SHIFT                                  (5U)
#define PCTRL_PCR_ODE(x)                                     (((uint32_t)(((uint32_t)(x)) << PCTRL_PCR_ODE_SHIFT)) & PCTRL_PCR_ODE_MASK)
#define PCTRL_PCR_PE_MASK                                    (0x2U)
#define PCTRL_PCR_PE_SHIFT                                   (1U)
#define PCTRL_PCR_PE(x)                                      (((uint32_t)(((uint32_t)(x)) << PCTRL_PCR_PE_SHIFT)) & PCTRL_PCR_PE_MASK)
#define PCTRL_PCR_PS_MASK                                    (0x1U)
#define PCTRL_PCR_PS_SHIFT                                   (0U)
#define PCTRL_PCR_PS(x)                                      (((uint32_t)(((uint32_t)(x)) << PCTRL_PCR_PS_SHIFT)) & PCTRL_PCR_PS_MASK)


/*!
 * @}
 */ /* end of group PCTRL_Register_Masks */


/*!
 * @}
 */ /* end of group PCTRL_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- SDK_NVIC Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup SDK_NVIC_Peripheral_Access_Layer SDK_NVIC Peripheral Access Layer
 * @{
 */


/** SDK_NVIC - Size of Registers Arrays */
#define SDK_NVIC_ISER_COUNT                     (1)
#define SDK_NVIC_ICER_COUNT                     (1)
#define SDK_NVIC_ISPR_COUNT                     (1)
#define SDK_NVIC_ICPR_COUNT                     (1)
#define SDK_NVIC_IPR_COUNT                     (8)

/* SDK_NVIC Register Layout Typedef */
typedef struct {
    __IO uint32_t ISER[ 1];                           /**< Interrupt Set Enable Register, offset: 0x0000 */
    __IO uint32_t Reserved0[31];                      /**< Reserved0, offset: 0x0004 */
    __IO uint32_t ICER[ 1];                           /**< Interrupt Clear Enable Register, offset: 0x0080 */
    __IO uint32_t Reserved1[31];                      /**< Reserved1, offset: 0x0004 */
    __IO uint32_t ISPR[ 1];                           /**< Interrupt Set Pending Register, offset: 0x0100 */
    __IO uint32_t Reserved2[31];                      /**< Reserved2, offset: 0x0004 */
    __IO uint32_t ICPR[ 1];                           /**< Interrupt Clear Pending Register, offset: 0x0180 */
    __IO uint32_t Reserved3[95];                      /**< Reserved3, offset: 0x0004 */
    __IO uint32_t IPR[ 8];                            /**< Interrupt Priority Register, offset: 0x0400 */

} SDK_NVIC_Type, *SDK_NVIC_MemMapPtr;

/** Number of instances of the SDK_NVIC module. */
#define SDK_NVIC_INSTANCE_COUNT                        (1u)

/* SDK_NVIC base address */
#define SDK_NVIC_BASE                                     (0xE000E100)
#define SDK_NVIC                                          ((SDK_NVIC_Type *)(SDK_NVIC_BASE))

/** Array initializer of SDK_NVIC peripheral base addresses */
#define SDK_NVIC_BASE_ADDRS                                { SDK_NVIC_BASE }
/** Array initializer of SDK_NVIC peripheral base pointers */
#define SDK_NVIC_BASE_PTRS                                 { SDK_NVIC }

/* SDK_NVIC Register Mask */
/* SDK_NVIC_ISER Register */
#define SDK_NVIC_ISER_ISER_MASK                                 (0xFFFFFFFFU)
#define SDK_NVIC_ISER_ISER_SHIFT                                (0U)
#define SDK_NVIC_ISER_ISER(x)                                   (((uint32_t)(((uint32_t)(x)) << SDK_NVIC_ISER_ISER_SHIFT)) & SDK_NVIC_ISER_ISER_MASK)
/* SDK_NVIC_ICER Register */
#define SDK_NVIC_ICER_ICER_MASK                                 (0xFFFFFFFFU)
#define SDK_NVIC_ICER_ICER_SHIFT                                (0U)
#define SDK_NVIC_ICER_ICER(x)                                   (((uint32_t)(((uint32_t)(x)) << SDK_NVIC_ICER_ICER_SHIFT)) & SDK_NVIC_ICER_ICER_MASK)
/* SDK_NVIC_ISPR Register */
#define SDK_NVIC_ISPR_ISPR_MASK                                 (0xFFFFFFFFU)
#define SDK_NVIC_ISPR_ISPR_SHIFT                                (0U)
#define SDK_NVIC_ISPR_ISPR(x)                                   (((uint32_t)(((uint32_t)(x)) << SDK_NVIC_ISPR_ISPR_SHIFT)) & SDK_NVIC_ISPR_ISPR_MASK)
/* SDK_NVIC_ICPR Register */
#define SDK_NVIC_ICPR_ICPR_MASK                                 (0xFFFFFFFFU)
#define SDK_NVIC_ICPR_ICPR_SHIFT                                (0U)
#define SDK_NVIC_ICPR_ICPR(x)                                   (((uint32_t)(((uint32_t)(x)) << SDK_NVIC_ICPR_ICPR_SHIFT)) & SDK_NVIC_ICPR_ICPR_MASK)
/* SDK_NVIC_IPR Register */
#define SDK_NVIC_IPR_IPR_MASK                                   (0xFFFFFFFFU)
#define SDK_NVIC_IPR_IPR_SHIFT                                  (0U)
#define SDK_NVIC_IPR_IPR(x)                                     (((uint32_t)(((uint32_t)(x)) << SDK_NVIC_IPR_IPR_SHIFT)) & SDK_NVIC_IPR_IPR_MASK)


/*!
 * @}
 */ /* end of group SDK_NVIC_Register_Masks */


/*!
 * @}
 */ /* end of group SDK_NVIC_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- SDK_SCB Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup SDK_SCB_Peripheral_Access_Layer SDK_SCB Peripheral Access Layer
 * @{
 */


/** SDK_SCB - Size of Registers Arrays */

/* SDK_SCB Register Layout Typedef */
typedef struct {
    __IO uint32_t Reserved0[832];                      /**< Reserved0, offset: 0x0000 */
    __IO uint32_t CPUID;                              /**< CPUID base Register, offset: 0x0D00 */
    __IO uint32_t ICSR;                               /**< Interrupt Control and Status Register, offset: 0x0D04 */
    __IO uint32_t VTOR;                               /**< Vector Table Offset Register, offset: 0x0D08 */
    __IO uint32_t AIRCR;                              /**< Application Interrupt and Reset Control Register, offset: 0x0D0C */
    __IO uint32_t SCR;                                /**< System Control Register, offset: 0x0D10 */
    __IO uint32_t CCR;                                /**< Configuration and Control Register, offset: 0x0D14 */
    __IO uint32_t SHPR1;                              /**< System Handler Priority Register 1, offset: 0x0D18 */
    __IO uint32_t SHPR2;                              /**< System Handler Priority Register 2, offset: 0x0D1C */
    __IO uint32_t SHPR3;                              /**< System Handler Priority Register 3, offset: 0x0D20 */
    __IO uint32_t SHCSR;                              /**< System Handler Control and State Register, offset: 0x0D24 */
    __IO uint32_t Reserved2[ 2];                      /**< Reserved2, offset: 0x0D28 */
    __IO uint32_t DFSR;                               /**< Debug Fault Status Register, offset: 0x0D30 */

} SDK_SCB_Type, *SDK_SCB_MemMapPtr;

/** Number of instances of the SDK_SCB module. */
#define SDK_SCB_INSTANCE_COUNT                         (1u)

/* SDK_SCB base address */
#define SDK_SCB_BASE                                      (0xE000E000)
#define SDK_SCB                                           ((SDK_SCB_Type *)(SDK_SCB_BASE))

/** Array initializer of SDK_SCB peripheral base addresses */
#define SDK_SCB_BASE_ADDRS                                 { SDK_SCB_BASE }
/** Array initializer of SDK_SCB peripheral base pointers */
#define SDK_SCB_BASE_PTRS                                  { SDK_SCB }

/* SDK_SCB Register Mask */
/* SDK_SCB_CPUID Register */
#define SDK_SCB_CPUID_IMPLEMENTER_WIDTH                        (8)
#define SDK_SCB_CPUID_IMPLEMENTER_MASK                         (0xFF000000U)
#define SDK_SCB_CPUID_IMPLEMENTER_SHIFT                        (24U)
#define SDK_SCB_CPUID_IMPLEMENTER(x)                           (((uint32_t)(((uint32_t)(x)) << SDK_SCB_CPUID_IMPLEMENTER_SHIFT)) & SDK_SCB_CPUID_IMPLEMENTER_MASK)
#define SDK_SCB_CPUID_VARIANT_WIDTH                            (4)
#define SDK_SCB_CPUID_VARIANT_MASK                             (0xF00000U)
#define SDK_SCB_CPUID_VARIANT_SHIFT                            (20U)
#define SDK_SCB_CPUID_VARIANT(x)                               (((uint32_t)(((uint32_t)(x)) << SDK_SCB_CPUID_VARIANT_SHIFT)) & SDK_SCB_CPUID_VARIANT_MASK)
#define SDK_SCB_CPUID_PARTNO_WIDTH                             (12)
#define SDK_SCB_CPUID_PARTNO_MASK                              (0xFFF0U)
#define SDK_SCB_CPUID_PARTNO_SHIFT                             (4U)
#define SDK_SCB_CPUID_PARTNO(x)                                (((uint32_t)(((uint32_t)(x)) << SDK_SCB_CPUID_PARTNO_SHIFT)) & SDK_SCB_CPUID_PARTNO_MASK)
#define SDK_SCB_CPUID_REVISION_WIDTH                           (4)
#define SDK_SCB_CPUID_REVISION_MASK                            (0xFU)
#define SDK_SCB_CPUID_REVISION_SHIFT                           (0U)
#define SDK_SCB_CPUID_REVISION(x)                              (((uint32_t)(((uint32_t)(x)) << SDK_SCB_CPUID_REVISION_SHIFT)) & SDK_SCB_CPUID_REVISION_MASK)
/* SDK_SCB_ICSR Register */
#define SDK_SCB_ICSR_NMIPENDSET_MASK                           (0x80000000U)
#define SDK_SCB_ICSR_NMIPENDSET_SHIFT                          (31U)
#define SDK_SCB_ICSR_NMIPENDSET(x)                             (((uint32_t)(((uint32_t)(x)) << SDK_SCB_ICSR_NMIPENDSET_SHIFT)) & SDK_SCB_ICSR_NMIPENDSET_MASK)
#define SDK_SCB_ICSR_PENDSVSET_MASK                            (0x10000000U)
#define SDK_SCB_ICSR_PENDSVSET_SHIFT                           (28U)
#define SDK_SCB_ICSR_PENDSVSET(x)                              (((uint32_t)(((uint32_t)(x)) << SDK_SCB_ICSR_PENDSVSET_SHIFT)) & SDK_SCB_ICSR_PENDSVSET_MASK)
#define SDK_SCB_ICSR_PENDSVCLR_MASK                            (0x2000000U)
#define SDK_SCB_ICSR_PENDSVCLR_SHIFT                           (25U)
#define SDK_SCB_ICSR_PENDSVCLR(x)                              (((uint32_t)(((uint32_t)(x)) << SDK_SCB_ICSR_PENDSVCLR_SHIFT)) & SDK_SCB_ICSR_PENDSVCLR_MASK)
#define SDK_SCB_ICSR_ISRPENDING_MASK                           (0x400000U)
#define SDK_SCB_ICSR_ISRPENDING_SHIFT                          (22U)
#define SDK_SCB_ICSR_ISRPENDING(x)                             (((uint32_t)(((uint32_t)(x)) << SDK_SCB_ICSR_ISRPENDING_SHIFT)) & SDK_SCB_ICSR_ISRPENDING_MASK)
#define SDK_SCB_ICSR_VECTPENDING_WIDTH                         (6)
#define SDK_SCB_ICSR_VECTPENDING_MASK                          (0x3F000U)
#define SDK_SCB_ICSR_VECTPENDING_SHIFT                         (12U)
#define SDK_SCB_ICSR_VECTPENDING(x)                            (((uint32_t)(((uint32_t)(x)) << SDK_SCB_ICSR_VECTPENDING_SHIFT)) & SDK_SCB_ICSR_VECTPENDING_MASK)
#define SDK_SCB_ICSR_VECTACTIVE_WIDTH                          (6)
#define SDK_SCB_ICSR_VECTACTIVE_MASK                           (0x3FU)
#define SDK_SCB_ICSR_VECTACTIVE_SHIFT                          (0U)
#define SDK_SCB_ICSR_VECTACTIVE(x)                             (((uint32_t)(((uint32_t)(x)) << SDK_SCB_ICSR_VECTACTIVE_SHIFT)) & SDK_SCB_ICSR_VECTACTIVE_MASK)
/* SDK_SCB_VTOR Register */
#define SDK_SCB_VTOR_TBLOFF_WIDTH                              (25)
#define SDK_SCB_VTOR_TBLOFF_MASK                               (0xFFFFFF80U)
#define SDK_SCB_VTOR_TBLOFF_SHIFT                              (7U)
#define SDK_SCB_VTOR_TBLOFF(x)                                 (((uint32_t)(((uint32_t)(x)) << SDK_SCB_VTOR_TBLOFF_SHIFT)) & SDK_SCB_VTOR_TBLOFF_MASK)
/* SDK_SCB_AIRCR Register */
#define SDK_SCB_AIRCR_VECTKEY_WIDTH                            (16)
#define SDK_SCB_AIRCR_VECTKEY_MASK                             (0xFFFF0000U)
#define SDK_SCB_AIRCR_VECTKEY_SHIFT                            (16U)
#define SDK_SCB_AIRCR_VECTKEY(x)                               (((uint32_t)(((uint32_t)(x)) << SDK_SCB_AIRCR_VECTKEY_SHIFT)) & SDK_SCB_AIRCR_VECTKEY_MASK)
#define SDK_SCB_AIRCR_ENDIANNESS_MASK                          (0x8000U)
#define SDK_SCB_AIRCR_ENDIANNESS_SHIFT                         (15U)
#define SDK_SCB_AIRCR_ENDIANNESS(x)                            (((uint32_t)(((uint32_t)(x)) << SDK_SCB_AIRCR_ENDIANNESS_SHIFT)) & SDK_SCB_AIRCR_ENDIANNESS_MASK)
#define SDK_SCB_AIRCR_SYSRESETREQ_MASK                         (0x4U)
#define SDK_SCB_AIRCR_SYSRESETREQ_SHIFT                        (2U)
#define SDK_SCB_AIRCR_SYSRESETREQ(x)                           (((uint32_t)(((uint32_t)(x)) << SDK_SCB_AIRCR_SYSRESETREQ_SHIFT)) & SDK_SCB_AIRCR_SYSRESETREQ_MASK)
#define SDK_SCB_AIRCR_VECTCLRACTIVE_MASK                       (0x2U)
#define SDK_SCB_AIRCR_VECTCLRACTIVE_SHIFT                      (1U)
#define SDK_SCB_AIRCR_VECTCLRACTIVE(x)                         (((uint32_t)(((uint32_t)(x)) << SDK_SCB_AIRCR_VECTCLRACTIVE_SHIFT)) & SDK_SCB_AIRCR_VECTCLRACTIVE_MASK)
/* SDK_SCB_SCR Register */
#define SDK_SCB_SCR_SEVONPEND_MASK                             (0x10U)
#define SDK_SCB_SCR_SEVONPEND_SHIFT                            (4U)
#define SDK_SCB_SCR_SEVONPEND(x)                               (((uint32_t)(((uint32_t)(x)) << SDK_SCB_SCR_SEVONPEND_SHIFT)) & SDK_SCB_SCR_SEVONPEND_MASK)
#define SDK_SCB_SCR_SLEEPDEEP_MASK                             (0x4U)
#define SDK_SCB_SCR_SLEEPDEEP_SHIFT                            (2U)
#define SDK_SCB_SCR_SLEEPDEEP(x)                               (((uint32_t)(((uint32_t)(x)) << SDK_SCB_SCR_SLEEPDEEP_SHIFT)) & SDK_SCB_SCR_SLEEPDEEP_MASK)
#define SDK_SCB_SCR_SLEEPONEXIT_MASK                           (0x2U)
#define SDK_SCB_SCR_SLEEPONEXIT_SHIFT                          (1U)
#define SDK_SCB_SCR_SLEEPONEXIT(x)                             (((uint32_t)(((uint32_t)(x)) << SDK_SCB_SCR_SLEEPONEXIT_SHIFT)) & SDK_SCB_SCR_SLEEPONEXIT_MASK)
/* SDK_SCB_CCR Register */
#define SDK_SCB_CCR_STKALIGN_MASK                              (0x200U)
#define SDK_SCB_CCR_STKALIGN_SHIFT                             (9U)
#define SDK_SCB_CCR_STKALIGN(x)                                (((uint32_t)(((uint32_t)(x)) << SDK_SCB_CCR_STKALIGN_SHIFT)) & SDK_SCB_CCR_STKALIGN_MASK)
#define SDK_SCB_CCR_UNALIGN_TRP_MASK                           (0x8U)
#define SDK_SCB_CCR_UNALIGN_TRP_SHIFT                          (3U)
#define SDK_SCB_CCR_UNALIGN_TRP(x)                             (((uint32_t)(((uint32_t)(x)) << SDK_SCB_CCR_UNALIGN_TRP_SHIFT)) & SDK_SCB_CCR_UNALIGN_TRP_MASK)
/* SDK_SCB_SHPR1 Register */
#define SDK_SCB_SHPR1_PRI_11_MASK                              (0xFF000000U)
#define SDK_SCB_SHPR1_PRI_11_SHIFT                             (24U)
#define SDK_SCB_SHPR1_PRI_11(x)                                (((uint32_t)(((uint32_t)(x)) << SDK_SCB_SHPR1_PRI_11_SHIFT)) & SDK_SCB_SHPR1_PRI_11_MASK)
/* SDK_SCB_SHPR2 Register */
#define SDK_SCB_SHPR2_PRI_11_MASK                              (0xFF000000U)
#define SDK_SCB_SHPR2_PRI_11_SHIFT                             (24U)
#define SDK_SCB_SHPR2_PRI_11(x)                                (((uint32_t)(((uint32_t)(x)) << SDK_SCB_SHPR2_PRI_11_SHIFT)) & SDK_SCB_SHPR2_PRI_11_MASK)
/* SDK_SCB_SHPR3 Register */
#define SDK_SCB_SHPR3_PRI_15_MASK                              (0xFF000000U)
#define SDK_SCB_SHPR3_PRI_15_SHIFT                             (24U)
#define SDK_SCB_SHPR3_PRI_15(x)                                (((uint32_t)(((uint32_t)(x)) << SDK_SCB_SHPR3_PRI_15_SHIFT)) & SDK_SCB_SHPR3_PRI_15_MASK)
#define SDK_SCB_SHPR3_PRI_14_MASK                              (0xFF0000U)
#define SDK_SCB_SHPR3_PRI_14_SHIFT                             (16U)
#define SDK_SCB_SHPR3_PRI_14(x)                                (((uint32_t)(((uint32_t)(x)) << SDK_SCB_SHPR3_PRI_14_SHIFT)) & SDK_SCB_SHPR3_PRI_14_MASK)
/* SDK_SCB_SHCSR Register */
#define SDK_SCB_SHCSR_SVCALLPENDED_MASK                        (0x8000U)
#define SDK_SCB_SHCSR_SVCALLPENDED_SHIFT                       (15U)
#define SDK_SCB_SHCSR_SVCALLPENDED(x)                          (((uint32_t)(((uint32_t)(x)) << SDK_SCB_SHCSR_SVCALLPENDED_SHIFT)) & SDK_SCB_SHCSR_SVCALLPENDED_MASK)
/* SDK_SCB_DFSR Register */
#define SDK_SCB_DFSR_EXTERNAL_MASK                             (0x10U)
#define SDK_SCB_DFSR_EXTERNAL_SHIFT                            (4U)
#define SDK_SCB_DFSR_EXTERNAL(x)                               (((uint32_t)(((uint32_t)(x)) << SDK_SCB_DFSR_EXTERNAL_SHIFT)) & SDK_SCB_DFSR_EXTERNAL_MASK)
#define SDK_SCB_DFSR_VCATCH_MASK                               (0x8U)
#define SDK_SCB_DFSR_VCATCH_SHIFT                              (3U)
#define SDK_SCB_DFSR_VCATCH(x)                                 (((uint32_t)(((uint32_t)(x)) << SDK_SCB_DFSR_VCATCH_SHIFT)) & SDK_SCB_DFSR_VCATCH_MASK)
#define SDK_SCB_DFSR_DWTTRAP_MASK                              (0x4U)
#define SDK_SCB_DFSR_DWTTRAP_SHIFT                             (2U)
#define SDK_SCB_DFSR_DWTTRAP(x)                                (((uint32_t)(((uint32_t)(x)) << SDK_SCB_DFSR_DWTTRAP_SHIFT)) & SDK_SCB_DFSR_DWTTRAP_MASK)
#define SDK_SCB_DFSR_BKPT_MASK                                 (0x2U)
#define SDK_SCB_DFSR_BKPT_SHIFT                                (1U)
#define SDK_SCB_DFSR_BKPT(x)                                   (((uint32_t)(((uint32_t)(x)) << SDK_SCB_DFSR_BKPT_SHIFT)) & SDK_SCB_DFSR_BKPT_MASK)
#define SDK_SCB_DFSR_HALTED_MASK                               (0x1U)
#define SDK_SCB_DFSR_HALTED_SHIFT                              (0U)
#define SDK_SCB_DFSR_HALTED(x)                                 (((uint32_t)(((uint32_t)(x)) << SDK_SCB_DFSR_HALTED_SHIFT)) & SDK_SCB_DFSR_HALTED_MASK)


/*!
 * @}
 */ /* end of group SDK_SCB_Register_Masks */


/*!
 * @}
 */ /* end of group SDK_SCB_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- SDK_SysTick Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup SDK_SysTick_Peripheral_Access_Layer SDK_SysTick Peripheral Access Layer
 * @{
 */


/** SDK_SysTick - Size of Registers Arrays */

/* SDK_SysTick Register Layout Typedef */
typedef struct {
    __IO uint32_t CSR;                                /**< Control and status Register, offset: 0x0000 */
    __IO uint32_t RVR;                                /**< Systick Reload Value Register, offset: 0x0004 */
    __IO uint32_t CVR;                                /**< Systick Current Value Register, offset: 0x0008 */
    __I  uint32_t CALIB;                              /**< Systick Calibration Value Register, offset: 0x000C */

} SDK_SysTick_Type, *SDK_SysTick_MemMapPtr;

/** Number of instances of the SDK_SysTick module. */
#define SDK_SysTick_INSTANCE_COUNT                        (1u)

/* SDK_SysTick base address */
#define SDK_SysTick_BASE                                  (0xE000E010)
#define SDK_SysTick                                       ((SDK_SysTick_Type *)(SDK_SysTick_BASE))

/** Array initializer of SDK_SysTick peripheral base addresses */
#define SDK_SysTick_BASE_ADDRS                             { SDK_SysTick_BASE }
/** Array initializer of SDK_SysTick peripheral base pointers */
#define SDK_SysTick_BASE_PTRS                              { SDK_SysTick }

/* SDK_SysTick Register Mask */
/* SDK_SysTick_CSR Register */
#define SDK_SysTick_CSR_COUNTFLAG_MASK                             (0x10000U)
#define SDK_SysTick_CSR_COUNTFLAG_SHIFT                            (16U)
#define SDK_SysTick_CSR_COUNTFLAG(x)                               (((uint32_t)(((uint32_t)(x)) << SDK_SysTick_CSR_COUNTFLAG_SHIFT)) & SDK_SysTick_CSR_COUNTFLAG_MASK)
#define SDK_SysTick_CSR_CLKSOURCE_MASK                             (0x4U)
#define SDK_SysTick_CSR_CLKSOURCE_SHIFT                            (2U)
#define SDK_SysTick_CSR_CLKSOURCE(x)                               (((uint32_t)(((uint32_t)(x)) << SDK_SysTick_CSR_CLKSOURCE_SHIFT)) & SDK_SysTick_CSR_CLKSOURCE_MASK)
#define SDK_SysTick_CSR_TICKINT_MASK                               (0x2U)
#define SDK_SysTick_CSR_TICKINT_SHIFT                              (1U)
#define SDK_SysTick_CSR_TICKINT(x)                                 (((uint32_t)(((uint32_t)(x)) << SDK_SysTick_CSR_TICKINT_SHIFT)) & SDK_SysTick_CSR_TICKINT_MASK)
#define SDK_SysTick_CSR_ENABLE_MASK                                (0x1U)
#define SDK_SysTick_CSR_ENABLE_SHIFT                               (0U)
#define SDK_SysTick_CSR_ENABLE(x)                                  (((uint32_t)(((uint32_t)(x)) << SDK_SysTick_CSR_ENABLE_SHIFT)) & SDK_SysTick_CSR_ENABLE_MASK)
/* SDK_SysTick_RVR Register */
#define SDK_SysTick_RVR_RELOAD_WIDTH                               (24)
#define SDK_SysTick_RVR_RELOAD_MASK                                (0xFFFFFFU)
#define SDK_SysTick_RVR_RELOAD_SHIFT                               (0U)
#define SDK_SysTick_RVR_RELOAD(x)                                  (((uint32_t)(((uint32_t)(x)) << SDK_SysTick_RVR_RELOAD_SHIFT)) & SDK_SysTick_RVR_RELOAD_MASK)
/* SDK_SysTick_CVR Register */
#define SDK_SysTick_CVR_CURRENT_WIDTH                              (24)
#define SDK_SysTick_CVR_CURRENT_MASK                               (0xFFFFFFU)
#define SDK_SysTick_CVR_CURRENT_SHIFT                              (0U)
#define SDK_SysTick_CVR_CURRENT(x)                                 (((uint32_t)(((uint32_t)(x)) << SDK_SysTick_CVR_CURRENT_SHIFT)) & SDK_SysTick_CVR_CURRENT_MASK)
/* SDK_SysTick_CALIB Register */
#define SDK_SysTick_CALIB_NOREF_MASK                               (0x80000000U)
#define SDK_SysTick_CALIB_NOREF_SHIFT                              (31U)
#define SDK_SysTick_CALIB_NOREF(x)                                 (((uint32_t)(((uint32_t)(x)) << SDK_SysTick_CALIB_NOREF_SHIFT)) & SDK_SysTick_CALIB_NOREF_MASK)
#define SDK_SysTick_CALIB_SKEW_MASK                                (0x40000000U)
#define SDK_SysTick_CALIB_SKEW_SHIFT                               (30U)
#define SDK_SysTick_CALIB_SKEW(x)                                  (((uint32_t)(((uint32_t)(x)) << SDK_SysTick_CALIB_SKEW_SHIFT)) & SDK_SysTick_CALIB_SKEW_MASK)
#define SDK_SysTick_CALIB_TENMS_MASK                               (0xFFFFFFU)
#define SDK_SysTick_CALIB_TENMS_SHIFT                              (0U)
#define SDK_SysTick_CALIB_TENMS(x)                                 (((uint32_t)(((uint32_t)(x)) << SDK_SysTick_CALIB_TENMS_SHIFT)) & SDK_SysTick_CALIB_TENMS_MASK)


/*!
 * @}
 */ /* end of group SDK_SysTick_Register_Masks */


/*!
 * @}
 */ /* end of group SDK_SysTick_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- DIVSQRT Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup DIVSQRT_Peripheral_Access_Layer DIVSQRT Peripheral Access Layer
 * @{
 */


/** DIVSQRT - Size of Registers Arrays */

/* DIVSQRT Register Layout Typedef */
typedef struct {
    __IO uint32_t DEND;                               /**< Dividend Register, offset: 0x0000 */
    __IO uint32_t DSOR;                               /**< Divisor Register, offset: 0x0004 */
    __IO uint32_t CSR;                                /**< Control and Status Register, offset: 0x0008 */
    __IO uint32_t RES;                                /**< Result Register, offset: 0x000C */
    __IO uint32_t RCND;                               /**< Radicand Register, offset: 0x0010 */

} DIVSQRT_Type, *DIVSQRT_MemMapPtr;

/** Number of instances of the DIVSQRT module. */
#define DIVSQRT_INSTANCE_COUNT                         (1u)

/* DIVSQRT base address */
#define DIVSQRT_BASE                                      (0x4000E000)
#define DIVSQRT                                           ((DIVSQRT_Type *)(DIVSQRT_BASE))

/** Array initializer of DIVSQRT peripheral base addresses */
#define DIVSQRT_BASE_ADDRS                                 { DIVSQRT_BASE }
/** Array initializer of DIVSQRT peripheral base pointers */
#define DIVSQRT_BASE_PTRS                                  { DIVSQRT }

/* DIVSQRT Register Mask */
/* DIVSQRT_DEND Register */
#define DIVSQRT_DEND_DIVIDEND_MASK                             (0xFFFFFFFFU)
#define DIVSQRT_DEND_DIVIDEND_SHIFT                            (0U)
#define DIVSQRT_DEND_DIVIDEND(x)                               (((uint32_t)(((uint32_t)(x)) << DIVSQRT_DEND_DIVIDEND_SHIFT)) & DIVSQRT_DEND_DIVIDEND_MASK)
/* DIVSQRT_DSOR Register */
#define DIVSQRT_DSOR_DIVISOR_MASK                              (0xFFFFFFFFU)
#define DIVSQRT_DSOR_DIVISOR_SHIFT                             (0U)
#define DIVSQRT_DSOR_DIVISOR(x)                                (((uint32_t)(((uint32_t)(x)) << DIVSQRT_DSOR_DIVISOR_SHIFT)) & DIVSQRT_DSOR_DIVISOR_MASK)
/* DIVSQRT_CSR Register */
#define DIVSQRT_CSR_BUSY_MASK                                  (0x80000000U)
#define DIVSQRT_CSR_BUSY_SHIFT                                 (31U)
#define DIVSQRT_CSR_BUSY(x)                                    (((uint32_t)(((uint32_t)(x)) << DIVSQRT_CSR_BUSY_SHIFT)) & DIVSQRT_CSR_BUSY_MASK)
#define DIVSQRT_CSR_DIV_MASK                                   (0x40000000U)
#define DIVSQRT_CSR_DIV_SHIFT                                  (30U)
#define DIVSQRT_CSR_DIV(x)                                     (((uint32_t)(((uint32_t)(x)) << DIVSQRT_CSR_DIV_SHIFT)) & DIVSQRT_CSR_DIV_MASK)
#define DIVSQRT_CSR_SQRT_MASK                                  (0x20000000U)
#define DIVSQRT_CSR_SQRT_SHIFT                                 (29U)
#define DIVSQRT_CSR_SQRT(x)                                    (((uint32_t)(((uint32_t)(x)) << DIVSQRT_CSR_SQRT_SHIFT)) & DIVSQRT_CSR_SQRT_MASK)
#define DIVSQRT_CSR_DFS_MASK                                   (0x20U)
#define DIVSQRT_CSR_DFS_SHIFT                                  (5U)
#define DIVSQRT_CSR_DFS(x)                                     (((uint32_t)(((uint32_t)(x)) << DIVSQRT_CSR_DFS_SHIFT)) & DIVSQRT_CSR_DFS_MASK)
#define DIVSQRT_CSR_DZ_MASK                                    (0x10U)
#define DIVSQRT_CSR_DZ_SHIFT                                   (4U)
#define DIVSQRT_CSR_DZ(x)                                      (((uint32_t)(((uint32_t)(x)) << DIVSQRT_CSR_DZ_SHIFT)) & DIVSQRT_CSR_DZ_MASK)
#define DIVSQRT_CSR_DZE_MASK                                   (0x8U)
#define DIVSQRT_CSR_DZE_SHIFT                                  (3U)
#define DIVSQRT_CSR_DZE(x)                                     (((uint32_t)(((uint32_t)(x)) << DIVSQRT_CSR_DZE_SHIFT)) & DIVSQRT_CSR_DZE_MASK)
#define DIVSQRT_CSR_REM_MASK                                   (0x4U)
#define DIVSQRT_CSR_REM_SHIFT                                  (2U)
#define DIVSQRT_CSR_REM(x)                                     (((uint32_t)(((uint32_t)(x)) << DIVSQRT_CSR_REM_SHIFT)) & DIVSQRT_CSR_REM_MASK)
#define DIVSQRT_CSR_USGN_MASK                                  (0x2U)
#define DIVSQRT_CSR_USGN_SHIFT                                 (1U)
#define DIVSQRT_CSR_USGN(x)                                    (((uint32_t)(((uint32_t)(x)) << DIVSQRT_CSR_USGN_SHIFT)) & DIVSQRT_CSR_USGN_MASK)
#define DIVSQRT_CSR_SRT_MASK                                   (0x1U)
#define DIVSQRT_CSR_SRT_SHIFT                                  (0U)
#define DIVSQRT_CSR_SRT(x)                                     (((uint32_t)(((uint32_t)(x)) << DIVSQRT_CSR_SRT_SHIFT)) & DIVSQRT_CSR_SRT_MASK)
/* DIVSQRT_RES Register */
#define DIVSQRT_RES_RESULT_MASK                                (0xFFFFFFFFU)
#define DIVSQRT_RES_RESULT_SHIFT                               (0U)
#define DIVSQRT_RES_RESULT(x)                                  (((uint32_t)(((uint32_t)(x)) << DIVSQRT_RES_RESULT_SHIFT)) & DIVSQRT_RES_RESULT_MASK)
/* DIVSQRT_RCND Register */
#define DIVSQRT_RCND_RADICAND_MASK                             (0xFFFFFFFFU)
#define DIVSQRT_RCND_RADICAND_SHIFT                            (0U)
#define DIVSQRT_RCND_RADICAND(x)                               (((uint32_t)(((uint32_t)(x)) << DIVSQRT_RCND_RADICAND_SHIFT)) & DIVSQRT_RCND_RADICAND_MASK)


/*!
 * @}
 */ /* end of group DIVSQRT_Register_Masks */


/*!
 * @}
 */ /* end of group DIVSQRT_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- TMU Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup TMU_Peripheral_Access_Layer TMU Peripheral Access Layer
 * @{
 */


/** TMU - Size of Registers Arrays */
#define TMU_MUX_COUNT                     (4)

/* TMU Register Layout Typedef */
typedef struct {
    __IO uint32_t MUX[ 4];                            /**< MUX, offset: 0x0000 */

} TMU_Type, *TMU_MemMapPtr;

/** Number of instances of the TMU module. */
#define TMU_INSTANCE_COUNT                             (1u)

/* TMU base address */
#define TMU_BASE                                          (0x40063000)
#define TMU                                               ((TMU_Type *)(TMU_BASE))

/** Array initializer of TMU peripheral base addresses */
#define TMU_BASE_ADDRS                                     { TMU_BASE }
/** Array initializer of TMU peripheral base pointers */
#define TMU_BASE_PTRS                                      { TMU }

/* TMU Register Mask */
/* TMU_MUX Register */
#define TMU_MUX_LOCK_MASK                                  (0x80000000U)
#define TMU_MUX_LOCK_SHIFT                                 (31U)
#define TMU_MUX_LOCK(x)                                    (((uint32_t)(((uint32_t)(x)) << TMU_MUX_LOCK_SHIFT)) & TMU_MUX_LOCK_MASK)
#define TMU_MUX_SEL3_WIDTH                                 (7)
#define TMU_MUX_SEL3_MASK                                  (0x7F000000U)
#define TMU_MUX_SEL3_SHIFT                                 (24U)
#define TMU_MUX_SEL3(x)                                    (((uint32_t)(((uint32_t)(x)) << TMU_MUX_SEL3_SHIFT)) & TMU_MUX_SEL3_MASK)
#define TMU_MUX_SEL2_WIDTH                                 (7)
#define TMU_MUX_SEL2_MASK                                  (0x7F0000U)
#define TMU_MUX_SEL2_SHIFT                                 (16U)
#define TMU_MUX_SEL2(x)                                    (((uint32_t)(((uint32_t)(x)) << TMU_MUX_SEL2_SHIFT)) & TMU_MUX_SEL2_MASK)
#define TMU_MUX_SEL1_WIDTH                                 (7)
#define TMU_MUX_SEL1_MASK                                  (0x7F00U)
#define TMU_MUX_SEL1_SHIFT                                 (8U)
#define TMU_MUX_SEL1(x)                                    (((uint32_t)(((uint32_t)(x)) << TMU_MUX_SEL1_SHIFT)) & TMU_MUX_SEL1_MASK)
#define TMU_MUX_SEL0_WIDTH                                 (7)
#define TMU_MUX_SEL0_MASK                                  (0x7FU)
#define TMU_MUX_SEL0_SHIFT                                 (0U)
#define TMU_MUX_SEL0(x)                                    (((uint32_t)(((uint32_t)(x)) << TMU_MUX_SEL0_SHIFT)) & TMU_MUX_SEL0_MASK)


/*!
 * @}
 */ /* end of group TMU_Register_Masks */


/*!
 * @}
 */ /* end of group TMU_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- CIM Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup CIM_Peripheral_Access_Layer CIM Peripheral Access Layer
 * @{
 */


/** CIM - Size of Registers Arrays */

/* CIM Register Layout Typedef */
typedef struct {
    __IO uint32_t CTRL;                               /**< Control Register, offset: 0x0000 */
    __IO uint32_t SWTRIG;                             /**< Software Trigger Register, offset: 0x0004 */
    __I  uint32_t DIEINFO;                            /**< Die Information Register, offset: 0x0008 */
    __I  uint32_t CHIPINFO;                           /**< Chip Information Register, offset: 0x000C */
    __IO uint32_t RESERVED_4;                         /**< RESERVED_4, offset: 0x0010 */

} CIM_Type, *CIM_MemMapPtr;

/** Number of instances of the CIM module. */
#define CIM_INSTANCE_COUNT                             (1u)

/* CIM base address */
#define CIM_BASE                                          (0x40048000)
#define CIM                                               ((CIM_Type *)(CIM_BASE))

/** Array initializer of CIM peripheral base addresses */
#define CIM_BASE_ADDRS                                     { CIM_BASE }
/** Array initializer of CIM peripheral base pointers */
#define CIM_BASE_PTRS                                      { CIM }

/* CIM Register Mask */
/* CIM_CTRL Register */
#define CIM_CTRL_LIN_GPIO_SEL_MASK                         (0x30U)
#define CIM_CTRL_LIN_GPIO_SEL_SHIFT                        (4U)
#define CIM_CTRL_LIN_GPIO_SEL(x)                           (((uint32_t)(((uint32_t)(x)) << CIM_CTRL_LIN_GPIO_SEL_SHIFT)) & CIM_CTRL_LIN_GPIO_SEL_MASK)
#define CIM_CTRL_LOCKUPEN_MASK                             (0x4U)
#define CIM_CTRL_LOCKUPEN_SHIFT                            (2U)
#define CIM_CTRL_LOCKUPEN(x)                               (((uint32_t)(((uint32_t)(x)) << CIM_CTRL_LOCKUPEN_SHIFT)) & CIM_CTRL_LOCKUPEN_MASK)
#define CIM_CTRL_WICENREQ_MASK                             (0x1U)
#define CIM_CTRL_WICENREQ_SHIFT                            (0U)
#define CIM_CTRL_WICENREQ(x)                               (((uint32_t)(((uint32_t)(x)) << CIM_CTRL_WICENREQ_SHIFT)) & CIM_CTRL_WICENREQ_MASK)
/* CIM_SWTRIG Register */
#define CIM_SWTRIG_SWTCNT_MASK                             (0xFEU)
#define CIM_SWTRIG_SWTCNT_SHIFT                            (1U)
#define CIM_SWTRIG_SWTCNT(x)                               (((uint32_t)(((uint32_t)(x)) << CIM_SWTRIG_SWTCNT_SHIFT)) & CIM_SWTRIG_SWTCNT_MASK)
#define CIM_SWTRIG_SWT_MASK                                (0x1U)
#define CIM_SWTRIG_SWT_SHIFT                               (0U)
#define CIM_SWTRIG_SWT(x)                                  (((uint32_t)(((uint32_t)(x)) << CIM_SWTRIG_SWT_SHIFT)) & CIM_SWTRIG_SWT_MASK)
/* CIM_DIEINFO Register */
#define CIM_DIEINFO_FAMID_MASK                             (0xF0000000U)
#define CIM_DIEINFO_FAMID_SHIFT                            (28U)
#define CIM_DIEINFO_FAMID(x)                               (((uint32_t)(((uint32_t)(x)) << CIM_DIEINFO_FAMID_SHIFT)) & CIM_DIEINFO_FAMID_MASK)
#define CIM_DIEINFO_GENID_MASK                             (0xF000000U)
#define CIM_DIEINFO_GENID_SHIFT                            (24U)
#define CIM_DIEINFO_GENID(x)                               (((uint32_t)(((uint32_t)(x)) << CIM_DIEINFO_GENID_SHIFT)) & CIM_DIEINFO_GENID_MASK)
#define CIM_DIEINFO_SUBFAMIDH_MASK                         (0xF00000U)
#define CIM_DIEINFO_SUBFAMIDH_SHIFT                        (20U)
#define CIM_DIEINFO_SUBFAMIDH(x)                           (((uint32_t)(((uint32_t)(x)) << CIM_DIEINFO_SUBFAMIDH_SHIFT)) & CIM_DIEINFO_SUBFAMIDH_MASK)
#define CIM_DIEINFO_SUBFAMIDL_MASK                         (0xF0000U)
#define CIM_DIEINFO_SUBFAMIDL_SHIFT                        (16U)
#define CIM_DIEINFO_SUBFAMIDL(x)                           (((uint32_t)(((uint32_t)(x)) << CIM_DIEINFO_SUBFAMIDL_SHIFT)) & CIM_DIEINFO_SUBFAMIDL_MASK)
#define CIM_DIEINFO_MAJVER_MASK                            (0xF0U)
#define CIM_DIEINFO_MAJVER_SHIFT                           (4U)
#define CIM_DIEINFO_MAJVER(x)                              (((uint32_t)(((uint32_t)(x)) << CIM_DIEINFO_MAJVER_SHIFT)) & CIM_DIEINFO_MAJVER_MASK)
#define CIM_DIEINFO_MINVER_MASK                            (0xFU)
#define CIM_DIEINFO_MINVER_SHIFT                           (0U)
#define CIM_DIEINFO_MINVER(x)                              (((uint32_t)(((uint32_t)(x)) << CIM_DIEINFO_MINVER_SHIFT)) & CIM_DIEINFO_MINVER_MASK)
/* CIM_CHIPINFO Register */
#define CIM_CHIPINFO_PKGS_MASK                             (0xF00000U)
#define CIM_CHIPINFO_PKGS_SHIFT                            (20U)
#define CIM_CHIPINFO_PKGS(x)                               (((uint32_t)(((uint32_t)(x)) << CIM_CHIPINFO_PKGS_SHIFT)) & CIM_CHIPINFO_PKGS_MASK)
#define CIM_CHIPINFO_SRAMS_MASK                            (0xF0000U)
#define CIM_CHIPINFO_SRAMS_SHIFT                           (16U)
#define CIM_CHIPINFO_SRAMS(x)                              (((uint32_t)(((uint32_t)(x)) << CIM_CHIPINFO_SRAMS_SHIFT)) & CIM_CHIPINFO_SRAMS_MASK)
#define CIM_CHIPINFO_EEPROMS_MASK                          (0xF000U)
#define CIM_CHIPINFO_EEPROMS_SHIFT                         (12U)
#define CIM_CHIPINFO_EEPROMS(x)                            (((uint32_t)(((uint32_t)(x)) << CIM_CHIPINFO_EEPROMS_SHIFT)) & CIM_CHIPINFO_EEPROMS_MASK)
#define CIM_CHIPINFO_PFLASHS_MASK                          (0xF00U)
#define CIM_CHIPINFO_PFLASHS_SHIFT                         (8U)
#define CIM_CHIPINFO_PFLASHS(x)                            (((uint32_t)(((uint32_t)(x)) << CIM_CHIPINFO_PFLASHS_SHIFT)) & CIM_CHIPINFO_PFLASHS_MASK)


/*!
 * @}
 */ /* end of group CIM_Register_Masks */


/*!
 * @}
 */ /* end of group CIM_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- SCU Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup SCU_Peripheral_Access_Layer SCU Peripheral Access Layer
 * @{
 */


/** SCU - Size of Registers Arrays */

/* SCU Register Layout Typedef */
typedef struct {
    __IO uint32_t CLKS;                               /**< Clock Selection Register, offset: 0x0000 */
    __I  uint32_t STS;                                /**< Status Register, offset: 0x0004 */
    __IO uint32_t OSC_CTRL;                           /**< OSC Control Register, offset: 0x0008 */
    __IO uint32_t PLL_CTRL;                           /**< PLL Control Register, offset: 0x000C */
    __IO uint32_t RESERVED_4;                         /**< RESERVED_4, offset: 0x0010 */
    __IO uint32_t RESERVED_5;                         /**< RESERVED_5, offset: 0x0014 */
    __IO uint32_t RESERVED_6;                         /**< RESERVED_6, offset: 0x0018 */

} SCU_Type, *SCU_MemMapPtr;

/** Number of instances of the SCU module. */
#define SCU_INSTANCE_COUNT                             (1u)

/* SCU base address */
#define SCU_BASE                                          (0x40064000)
#define SCU                                               ((SCU_Type *)(SCU_BASE))

/** Array initializer of SCU peripheral base addresses */
#define SCU_BASE_ADDRS                                     { SCU_BASE }
/** Array initializer of SCU peripheral base pointers */
#define SCU_BASE_PTRS                                      { SCU }

/* SCU Register Mask */
/* SCU_CLKS Register */
#define SCU_CLKS_CLKSRCSEL_MASK                            (0x1U)
#define SCU_CLKS_CLKSRCSEL_SHIFT                           (0U)
#define SCU_CLKS_CLKSRCSEL(x)                              (((uint32_t)(((uint32_t)(x)) << SCU_CLKS_CLKSRCSEL_SHIFT)) & SCU_CLKS_CLKSRCSEL_MASK)
/* SCU_STS Register */
#define SCU_STS_PLL_LOCK_MASK                              (0x20U)
#define SCU_STS_PLL_LOCK_SHIFT                             (5U)
#define SCU_STS_PLL_LOCK(x)                                (((uint32_t)(((uint32_t)(x)) << SCU_STS_PLL_LOCK_SHIFT)) & SCU_STS_PLL_LOCK_MASK)
#define SCU_STS_CLKST_MASK                                 (0x1U)
#define SCU_STS_CLKST_SHIFT                                (0U)
#define SCU_STS_CLKST(x)                                   (((uint32_t)(((uint32_t)(x)) << SCU_STS_CLKST_SHIFT)) & SCU_STS_CLKST_MASK)
/* SCU_OSC_CTRL Register */
#define SCU_OSC_CTRL_OSC_DS_EN_MASK                        (0x2U)
#define SCU_OSC_CTRL_OSC_DS_EN_SHIFT                       (1U)
#define SCU_OSC_CTRL_OSC_DS_EN(x)                          (((uint32_t)(((uint32_t)(x)) << SCU_OSC_CTRL_OSC_DS_EN_SHIFT)) & SCU_OSC_CTRL_OSC_DS_EN_MASK)
/* SCU_PLL_CTRL Register */
#define SCU_PLL_CTRL_PLL_NDIV_MASK                         (0x1F00U)
#define SCU_PLL_CTRL_PLL_NDIV_SHIFT                        (8U)
#define SCU_PLL_CTRL_PLL_NDIV(x)                           (((uint32_t)(((uint32_t)(x)) << SCU_PLL_CTRL_PLL_NDIV_SHIFT)) & SCU_PLL_CTRL_PLL_NDIV_MASK)
#define SCU_PLL_CTRL_UNLOCK_RE_MASK                        (0x20U)
#define SCU_PLL_CTRL_UNLOCK_RE_SHIFT                       (5U)
#define SCU_PLL_CTRL_UNLOCK_RE(x)                          (((uint32_t)(((uint32_t)(x)) << SCU_PLL_CTRL_UNLOCK_RE_SHIFT)) & SCU_PLL_CTRL_UNLOCK_RE_MASK)
#define SCU_PLL_CTRL_PLL_OVRD_EN_MASK                      (0x4U)
#define SCU_PLL_CTRL_PLL_OVRD_EN_SHIFT                     (2U)
#define SCU_PLL_CTRL_PLL_OVRD_EN(x)                        (((uint32_t)(((uint32_t)(x)) << SCU_PLL_CTRL_PLL_OVRD_EN_SHIFT)) & SCU_PLL_CTRL_PLL_OVRD_EN_MASK)
#define SCU_PLL_CTRL_PLL_DS_EN_MASK                        (0x2U)
#define SCU_PLL_CTRL_PLL_DS_EN_SHIFT                       (1U)
#define SCU_PLL_CTRL_PLL_DS_EN(x)                          (((uint32_t)(((uint32_t)(x)) << SCU_PLL_CTRL_PLL_DS_EN_SHIFT)) & SCU_PLL_CTRL_PLL_DS_EN_MASK)
#define SCU_PLL_CTRL_PLL_EN_MASK                           (0x1U)
#define SCU_PLL_CTRL_PLL_EN_SHIFT                          (0U)
#define SCU_PLL_CTRL_PLL_EN(x)                             (((uint32_t)(((uint32_t)(x)) << SCU_PLL_CTRL_PLL_EN_SHIFT)) & SCU_PLL_CTRL_PLL_EN_MASK)


/*!
 * @}
 */ /* end of group SCU_Register_Masks */


/*!
 * @}
 */ /* end of group SCU_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- IPC Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup IPC_Peripheral_Access_Layer IPC Peripheral Access Layer
 * @{
 */


/** IPC - Size of Registers Arrays */
#define IPC_CTRL_COUNT                     (127)

/* IPC Register Layout Typedef */
typedef struct {
    __IO uint32_t CTRL[127];                           /**< Control Register, offset: 0x0000 */

} IPC_Type, *IPC_MemMapPtr;

/** Number of instances of the IPC module. */
#define IPC_INSTANCE_COUNT                             (1u)

/* IPC base address */
#define IPC_BASE                                          (0x40065000)
#define IPC                                               ((IPC_Type *)(IPC_BASE))

/** Array initializer of IPC peripheral base addresses */
#define IPC_BASE_ADDRS                                     { IPC_BASE }
/** Array initializer of IPC peripheral base pointers */
#define IPC_BASE_PTRS                                      { IPC }

/* IPC Register Mask */
/* IPC_CTRL Register */
#define IPC_CTRL_SRCSEL_WIDTH                              (2)
#define IPC_CTRL_SRCSEL_MASK                               (0x300U)
#define IPC_CTRL_SRCSEL_SHIFT                              (8U)
#define IPC_CTRL_SRCSEL(x)                                 (((uint32_t)(((uint32_t)(x)) << IPC_CTRL_SRCSEL_SHIFT)) & IPC_CTRL_SRCSEL_MASK)
#define IPC_CTRL_SWREN_MASK                                (0x2U)
#define IPC_CTRL_SWREN_SHIFT                               (1U)
#define IPC_CTRL_SWREN(x)                                  (((uint32_t)(((uint32_t)(x)) << IPC_CTRL_SWREN_SHIFT)) & IPC_CTRL_SWREN_MASK)
#define IPC_CTRL_CLKEN_MASK                                (0x1U)
#define IPC_CTRL_CLKEN_SHIFT                               (0U)
#define IPC_CTRL_CLKEN(x)                                  (((uint32_t)(((uint32_t)(x)) << IPC_CTRL_CLKEN_SHIFT)) & IPC_CTRL_CLKEN_MASK)


/*!
 * @}
 */ /* end of group IPC_Register_Masks */


/*!
 * @}
 */ /* end of group IPC_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- PCU Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup PCU_Peripheral_Access_Layer PCU Peripheral Access Layer
 * @{
 */


/** PCU - Size of Registers Arrays */

/* PCU Register Layout Typedef */
typedef struct {
    __IO uint32_t CR;                                 /**< Configure Register, offset: 0x0000 */
    __IO uint32_t SR;                                 /**< Status Register, offset: 0x0004 */
    __IO uint32_t IE;                                 /**< Interrupt Enable Register, offset: 0x0008 */
    __IO uint32_t LDOCR;                              /**< LDO Configure Register, offset: 0x000C */
    __IO uint32_t VSMOVMCR;                           /**< VSM Over Voltage Monitor Configure Register, offset: 0x0010 */
    __IO uint32_t OVTCR;                              /**< Over Temperature Detect Configure Register, offset: 0x0014 */
    __IO uint32_t OCCR;                               /**< Pre-Driver Over Current Detect Configure Register, offset: 0x0018 */
    __IO uint32_t VSLVDCR;                            /**< VS LVD Configure Register, offset: 0x001C */
    __IO uint32_t LDOLVDCR;                           /**< LDO LVD Configure Register, offset: 0x0020 */
    __IO uint32_t PUMPCR;                             /**< PUMP OSC Configure Register, offset: 0x0024 */
    __IO uint32_t BOOSTCR;                            /**< BOOST Configure Register, offset: 0x0028 */
    __IO uint32_t RESERVED_11;                        /**< RESERVED_11, offset: 0x002C */
    __IO uint32_t RESERVED_12;                        /**< RESERVED_12, offset: 0x0030 */
    __IO uint32_t RESERVED_13;                        /**< RESERVED_13, offset: 0x0034 */
    __IO uint32_t RESERVED_14;                        /**< RESERVED_14, offset: 0x0038 */
    __IO uint32_t RESERVED_15;                        /**< RESERVED_15, offset: 0x003C */

} PCU_Type, *PCU_MemMapPtr;

/** Number of instances of the PCU module. */
#define PCU_INSTANCE_COUNT                             (1u)

/* PCU base address */
#define PCU_BASE                                          (0x4007D000)
#define PCU                                               ((PCU_Type *)(PCU_BASE))

/** Array initializer of PCU peripheral base addresses */
#define PCU_BASE_ADDRS                                     { PCU_BASE }
/** Array initializer of PCU peripheral base pointers */
#define PCU_BASE_PTRS                                      { PCU }

/* PCU Register Mask */
/* PCU_CR Register */
#define PCU_CR_LOCK_IF_MASK                                (0x100U)
#define PCU_CR_LOCK_IF_SHIFT                               (8U)
#define PCU_CR_LOCK_IF(x)                                  (((uint32_t)(((uint32_t)(x)) << PCU_CR_LOCK_IF_SHIFT)) & PCU_CR_LOCK_IF_MASK)
#define PCU_CR_PTA3_WU_EN_MASK                             (0x10U)
#define PCU_CR_PTA3_WU_EN_SHIFT                            (4U)
#define PCU_CR_PTA3_WU_EN(x)                               (((uint32_t)(((uint32_t)(x)) << PCU_CR_PTA3_WU_EN_SHIFT)) & PCU_CR_PTA3_WU_EN_MASK)
#define PCU_CR_INT_WU_SET_MASK                             (0xCU)
#define PCU_CR_INT_WU_SET_SHIFT                            (2U)
#define PCU_CR_INT_WU_SET(x)                               (((uint32_t)(((uint32_t)(x)) << PCU_CR_INT_WU_SET_SHIFT)) & PCU_CR_INT_WU_SET_MASK)
#define PCU_CR_EN_WU_TIM_MASK                              (0x2U)
#define PCU_CR_EN_WU_TIM_SHIFT                             (1U)
#define PCU_CR_EN_WU_TIM(x)                                (((uint32_t)(((uint32_t)(x)) << PCU_CR_EN_WU_TIM_SHIFT)) & PCU_CR_EN_WU_TIM_MASK)
#define PCU_CR_PD_EN_MASK                                  (0x1U)
#define PCU_CR_PD_EN_SHIFT                                 (0U)
#define PCU_CR_PD_EN(x)                                    (((uint32_t)(((uint32_t)(x)) << PCU_CR_PD_EN_SHIFT)) & PCU_CR_PD_EN_MASK)
/* PCU_SR Register */
#define PCU_SR_OC_DRV_MASK                                 (0x1000000U)
#define PCU_SR_OC_DRV_SHIFT                                (24U)
#define PCU_SR_OC_DRV(x)                                   (((uint32_t)(((uint32_t)(x)) << PCU_SR_OC_DRV_SHIFT)) & PCU_SR_OC_DRV_MASK)
#define PCU_SR_OVT_DEB_MASK                                (0x100000U)
#define PCU_SR_OVT_DEB_SHIFT                               (20U)
#define PCU_SR_OVT_DEB(x)                                  (((uint32_t)(((uint32_t)(x)) << PCU_SR_OVT_DEB_SHIFT)) & PCU_SR_OVT_DEB_MASK)
#define PCU_SR_VS_LVD_MASK                                 (0x20000U)
#define PCU_SR_VS_LVD_SHIFT                                (17U)
#define PCU_SR_VS_LVD(x)                                   (((uint32_t)(((uint32_t)(x)) << PCU_SR_VS_LVD_SHIFT)) & PCU_SR_VS_LVD_MASK)
#define PCU_SR_VSM_OV_MASK                                 (0x10000U)
#define PCU_SR_VSM_OV_SHIFT                                (16U)
#define PCU_SR_VSM_OV(x)                                   (((uint32_t)(((uint32_t)(x)) << PCU_SR_VSM_OV_SHIFT)) & PCU_SR_VSM_OV_MASK)
#define PCU_SR_WU_FLAG_PTA3_MASK                           (0x40U)
#define PCU_SR_WU_FLAG_PTA3_SHIFT                          (6U)
#define PCU_SR_WU_FLAG_PTA3(x)                             (((uint32_t)(((uint32_t)(x)) << PCU_SR_WU_FLAG_PTA3_SHIFT)) & PCU_SR_WU_FLAG_PTA3_MASK)
#define PCU_SR_WU_FLAG_TIM_MASK                            (0x20U)
#define PCU_SR_WU_FLAG_TIM_SHIFT                           (5U)
#define PCU_SR_WU_FLAG_TIM(x)                              (((uint32_t)(((uint32_t)(x)) << PCU_SR_WU_FLAG_TIM_SHIFT)) & PCU_SR_WU_FLAG_TIM_MASK)
#define PCU_SR_WU_FLAG_LIN_MASK                            (0x10U)
#define PCU_SR_WU_FLAG_LIN_SHIFT                           (4U)
#define PCU_SR_WU_FLAG_LIN(x)                              (((uint32_t)(((uint32_t)(x)) << PCU_SR_WU_FLAG_LIN_SHIFT)) & PCU_SR_WU_FLAG_LIN_MASK)
#define PCU_SR_POR_MASK                                    (0x2U)
#define PCU_SR_POR_SHIFT                                   (1U)
#define PCU_SR_POR(x)                                      (((uint32_t)(((uint32_t)(x)) << PCU_SR_POR_SHIFT)) & PCU_SR_POR_MASK)
#define PCU_SR_PD_MASK                                     (0x1U)
#define PCU_SR_PD_SHIFT                                    (0U)
#define PCU_SR_PD(x)                                       (((uint32_t)(((uint32_t)(x)) << PCU_SR_PD_SHIFT)) & PCU_SR_PD_MASK)
/* PCU_IE Register */
#define PCU_IE_OC_DRV_IE_MASK                              (0x1000000U)
#define PCU_IE_OC_DRV_IE_SHIFT                             (24U)
#define PCU_IE_OC_DRV_IE(x)                                (((uint32_t)(((uint32_t)(x)) << PCU_IE_OC_DRV_IE_SHIFT)) & PCU_IE_OC_DRV_IE_MASK)
#define PCU_IE_OVT_DEB_IE_MASK                             (0x100000U)
#define PCU_IE_OVT_DEB_IE_SHIFT                            (20U)
#define PCU_IE_OVT_DEB_IE(x)                               (((uint32_t)(((uint32_t)(x)) << PCU_IE_OVT_DEB_IE_SHIFT)) & PCU_IE_OVT_DEB_IE_MASK)
#define PCU_IE_VS_LVD_IE_MASK                              (0x20000U)
#define PCU_IE_VS_LVD_IE_SHIFT                             (17U)
#define PCU_IE_VS_LVD_IE(x)                                (((uint32_t)(((uint32_t)(x)) << PCU_IE_VS_LVD_IE_SHIFT)) & PCU_IE_VS_LVD_IE_MASK)
#define PCU_IE_VSM_OV_IE_MASK                              (0x10000U)
#define PCU_IE_VSM_OV_IE_SHIFT                             (16U)
#define PCU_IE_VSM_OV_IE(x)                                (((uint32_t)(((uint32_t)(x)) << PCU_IE_VSM_OV_IE_SHIFT)) & PCU_IE_VSM_OV_IE_MASK)
/* PCU_LDOCR Register */
#define PCU_LDOCR_LDO3P3_EN_MASK                           (0x200U)
#define PCU_LDOCR_LDO3P3_EN_SHIFT                          (9U)
#define PCU_LDOCR_LDO3P3_EN(x)                             (((uint32_t)(((uint32_t)(x)) << PCU_LDOCR_LDO3P3_EN_SHIFT)) & PCU_LDOCR_LDO3P3_EN_MASK)
#define PCU_LDOCR_LDO1P8_EN_MASK                           (0x100U)
#define PCU_LDOCR_LDO1P8_EN_SHIFT                          (8U)
#define PCU_LDOCR_LDO1P8_EN(x)                             (((uint32_t)(((uint32_t)(x)) << PCU_LDOCR_LDO1P8_EN_SHIFT)) & PCU_LDOCR_LDO1P8_EN_MASK)
#define PCU_LDOCR_UNLOCK_MASK                              (0x1U)
#define PCU_LDOCR_UNLOCK_SHIFT                             (0U)
#define PCU_LDOCR_UNLOCK(x)                                (((uint32_t)(((uint32_t)(x)) << PCU_LDOCR_UNLOCK_SHIFT)) & PCU_LDOCR_UNLOCK_MASK)
/* PCU_VSMOVMCR Register */
#define PCU_VSMOVMCR_VSM_OV_DEBEN_MASK                     (0x4U)
#define PCU_VSMOVMCR_VSM_OV_DEBEN_SHIFT                    (2U)
#define PCU_VSMOVMCR_VSM_OV_DEBEN(x)                       (((uint32_t)(((uint32_t)(x)) << PCU_VSMOVMCR_VSM_OV_DEBEN_SHIFT)) & PCU_VSMOVMCR_VSM_OV_DEBEN_MASK)
#define PCU_VSMOVMCR_VSM_OV_DETEN_MASK                     (0x2U)
#define PCU_VSMOVMCR_VSM_OV_DETEN_SHIFT                    (1U)
#define PCU_VSMOVMCR_VSM_OV_DETEN(x)                       (((uint32_t)(((uint32_t)(x)) << PCU_VSMOVMCR_VSM_OV_DETEN_SHIFT)) & PCU_VSMOVMCR_VSM_OV_DETEN_MASK)
#define PCU_VSMOVMCR_VSM_OV_VSEL_MASK                      (0x1U)
#define PCU_VSMOVMCR_VSM_OV_VSEL_SHIFT                     (0U)
#define PCU_VSMOVMCR_VSM_OV_VSEL(x)                        (((uint32_t)(((uint32_t)(x)) << PCU_VSMOVMCR_VSM_OV_VSEL_SHIFT)) & PCU_VSMOVMCR_VSM_OV_VSEL_MASK)
/* PCU_OVTCR Register */
#define PCU_OVTCR_OVTCMP_OEN_MASK                          (0x2U)
#define PCU_OVTCR_OVTCMP_OEN_SHIFT                         (1U)
#define PCU_OVTCR_OVTCMP_OEN(x)                            (((uint32_t)(((uint32_t)(x)) << PCU_OVTCR_OVTCMP_OEN_SHIFT)) & PCU_OVTCR_OVTCMP_OEN_MASK)
#define PCU_OVTCR_SEL_OVT_MASK                             (0x1U)
#define PCU_OVTCR_SEL_OVT_SHIFT                            (0U)
#define PCU_OVTCR_SEL_OVT(x)                               (((uint32_t)(((uint32_t)(x)) << PCU_OVTCR_SEL_OVT_SHIFT)) & PCU_OVTCR_SEL_OVT_MASK)
/* PCU_OCCR Register */
#define PCU_OCCR_OC_DEB_CFG_MASK                           (0x30U)
#define PCU_OCCR_OC_DEB_CFG_SHIFT                          (4U)
#define PCU_OCCR_OC_DEB_CFG(x)                             (((uint32_t)(((uint32_t)(x)) << PCU_OCCR_OC_DEB_CFG_SHIFT)) & PCU_OCCR_OC_DEB_CFG_MASK)
#define PCU_OCCR_OC_DEBEN_MASK                             (0x4U)
#define PCU_OCCR_OC_DEBEN_SHIFT                            (2U)
#define PCU_OCCR_OC_DEBEN(x)                               (((uint32_t)(((uint32_t)(x)) << PCU_OCCR_OC_DEBEN_SHIFT)) & PCU_OCCR_OC_DEBEN_MASK)
/* PCU_VSLVDCR Register */
#define PCU_VSLVDCR_LVDT_VS_CFG_MASK                       (0x70U)
#define PCU_VSLVDCR_LVDT_VS_CFG_SHIFT                      (4U)
#define PCU_VSLVDCR_LVDT_VS_CFG(x)                         (((uint32_t)(((uint32_t)(x)) << PCU_VSLVDCR_LVDT_VS_CFG_SHIFT)) & PCU_VSLVDCR_LVDT_VS_CFG_MASK)
#define PCU_VSLVDCR_LVDT_VS_DEBEN_MASK                     (0x4U)
#define PCU_VSLVDCR_LVDT_VS_DEBEN_SHIFT                    (2U)
#define PCU_VSLVDCR_LVDT_VS_DEBEN(x)                       (((uint32_t)(((uint32_t)(x)) << PCU_VSLVDCR_LVDT_VS_DEBEN_SHIFT)) & PCU_VSLVDCR_LVDT_VS_DEBEN_MASK)
#define PCU_VSLVDCR_LVDT_VS_EN_MASK                        (0x1U)
#define PCU_VSLVDCR_LVDT_VS_EN_SHIFT                       (0U)
#define PCU_VSLVDCR_LVDT_VS_EN(x)                          (((uint32_t)(((uint32_t)(x)) << PCU_VSLVDCR_LVDT_VS_EN_SHIFT)) & PCU_VSLVDCR_LVDT_VS_EN_MASK)
/* PCU_LDOLVDCR Register */
#define PCU_LDOLVDCR_VDDA_LVDT_EN_MASK                     (0x10000U)
#define PCU_LDOLVDCR_VDDA_LVDT_EN_SHIFT                    (16U)
#define PCU_LDOLVDCR_VDDA_LVDT_EN(x)                       (((uint32_t)(((uint32_t)(x)) << PCU_LDOLVDCR_VDDA_LVDT_EN_SHIFT)) & PCU_LDOLVDCR_VDDA_LVDT_EN_MASK)
#define PCU_LDOLVDCR_VDDD_LVDT_EN_MASK                     (0x1U)
#define PCU_LDOLVDCR_VDDD_LVDT_EN_SHIFT                    (0U)
#define PCU_LDOLVDCR_VDDD_LVDT_EN(x)                       (((uint32_t)(((uint32_t)(x)) << PCU_LDOLVDCR_VDDD_LVDT_EN_SHIFT)) & PCU_LDOLVDCR_VDDD_LVDT_EN_MASK)
/* PCU_PUMPCR Register */
#define PCU_PUMPCR_PUMP_OSC_CFG_MASK                       (0x7U)
#define PCU_PUMPCR_PUMP_OSC_CFG_SHIFT                      (0U)
#define PCU_PUMPCR_PUMP_OSC_CFG(x)                         (((uint32_t)(((uint32_t)(x)) << PCU_PUMPCR_PUMP_OSC_CFG_SHIFT)) & PCU_PUMPCR_PUMP_OSC_CFG_MASK)
/* PCU_BOOSTCR Register */
#define PCU_BOOSTCR_BOOST_DTV_CFG_MASK                     (0xFU)
#define PCU_BOOSTCR_BOOST_DTV_CFG_SHIFT                    (0U)
#define PCU_BOOSTCR_BOOST_DTV_CFG(x)                       (((uint32_t)(((uint32_t)(x)) << PCU_BOOSTCR_BOOST_DTV_CFG_SHIFT)) & PCU_BOOSTCR_BOOST_DTV_CFG_MASK)


/*!
 * @}
 */ /* end of group PCU_Register_Masks */


/*!
 * @}
 */ /* end of group PCU_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- RCU Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup RCU_Peripheral_Access_Layer RCU Peripheral Access Layer
 * @{
 */


/** RCU - Size of Registers Arrays */

/* RCU Register Layout Typedef */
typedef struct {
    __IO uint32_t RSSR;                               /**< Reset Source Status Register, offset: 0x0000 */
    __IO uint32_t RPFR;                               /**< Reset Pin Filter Register, offset: 0x0004 */

} RCU_Type, *RCU_MemMapPtr;

/** Number of instances of the RCU module. */
#define RCU_INSTANCE_COUNT                             (1u)

/* RCU base address */
#define RCU_BASE                                          (0x4007F000)
#define RCU                                               ((RCU_Type *)(RCU_BASE))

/** Array initializer of RCU peripheral base addresses */
#define RCU_BASE_ADDRS                                     { RCU_BASE }
/** Array initializer of RCU peripheral base pointers */
#define RCU_BASE_PTRS                                      { RCU }

/* RCU Register Mask */
/* RCU_RSSR Register */
#define RCU_RSSR_DEEPSLEEPACK_MASK                         (0x80000U)
#define RCU_RSSR_DEEPSLEEPACK_SHIFT                        (19U)
#define RCU_RSSR_DEEPSLEEPACK(x)                           (((uint32_t)(((uint32_t)(x)) << RCU_RSSR_DEEPSLEEPACK_SHIFT)) & RCU_RSSR_DEEPSLEEPACK_MASK)
#define RCU_RSSR_PLL_UNLOCK_MASK                           (0x40000U)
#define RCU_RSSR_PLL_UNLOCK_SHIFT                          (18U)
#define RCU_RSSR_PLL_UNLOCK(x)                             (((uint32_t)(((uint32_t)(x)) << RCU_RSSR_PLL_UNLOCK_SHIFT)) & RCU_RSSR_PLL_UNLOCK_MASK)
#define RCU_RSSR_WDG_MASK                                  (0x20000U)
#define RCU_RSSR_WDG_SHIFT                                 (17U)
#define RCU_RSSR_WDG(x)                                    (((uint32_t)(((uint32_t)(x)) << RCU_RSSR_WDG_SHIFT)) & RCU_RSSR_WDG_MASK)
#define RCU_RSSR_LOCKUP_MASK                               (0x10000U)
#define RCU_RSSR_LOCKUP_SHIFT                              (16U)
#define RCU_RSSR_LOCKUP(x)                                 (((uint32_t)(((uint32_t)(x)) << RCU_RSSR_LOCKUP_SHIFT)) & RCU_RSSR_LOCKUP_MASK)
#define RCU_RSSR_SW_MASK                                   (0x100U)
#define RCU_RSSR_SW_SHIFT                                  (8U)
#define RCU_RSSR_SW(x)                                     (((uint32_t)(((uint32_t)(x)) << RCU_RSSR_SW_SHIFT)) & RCU_RSSR_SW_MASK)
#define RCU_RSSR_PIN_MASK                                  (0x2U)
#define RCU_RSSR_PIN_SHIFT                                 (1U)
#define RCU_RSSR_PIN(x)                                    (((uint32_t)(((uint32_t)(x)) << RCU_RSSR_PIN_SHIFT)) & RCU_RSSR_PIN_MASK)
#define RCU_RSSR_POR_MASK                                  (0x1U)
#define RCU_RSSR_POR_SHIFT                                 (0U)
#define RCU_RSSR_POR(x)                                    (((uint32_t)(((uint32_t)(x)) << RCU_RSSR_POR_SHIFT)) & RCU_RSSR_POR_MASK)
/* RCU_RPFR Register */
#define RCU_RPFR_RSTPIN_OBEN_MASK                          (0x10000U)
#define RCU_RPFR_RSTPIN_OBEN_SHIFT                         (16U)
#define RCU_RPFR_RSTPIN_OBEN(x)                            (((uint32_t)(((uint32_t)(x)) << RCU_RPFR_RSTPIN_OBEN_SHIFT)) & RCU_RPFR_RSTPIN_OBEN_MASK)
#define RCU_RPFR_FLTVAL_MASK                               (0xFF00U)
#define RCU_RPFR_FLTVAL_SHIFT                              (8U)
#define RCU_RPFR_FLTVAL(x)                                 (((uint32_t)(((uint32_t)(x)) << RCU_RPFR_FLTVAL_SHIFT)) & RCU_RPFR_FLTVAL_MASK)
#define RCU_RPFR_FLTCLKSEL_MASK                            (0x4U)
#define RCU_RPFR_FLTCLKSEL_SHIFT                           (2U)
#define RCU_RPFR_FLTCLKSEL(x)                              (((uint32_t)(((uint32_t)(x)) << RCU_RPFR_FLTCLKSEL_SHIFT)) & RCU_RPFR_FLTCLKSEL_MASK)
#define RCU_RPFR_FLTSTEN_MASK                              (0x2U)
#define RCU_RPFR_FLTSTEN_SHIFT                             (1U)
#define RCU_RPFR_FLTSTEN(x)                                (((uint32_t)(((uint32_t)(x)) << RCU_RPFR_FLTSTEN_SHIFT)) & RCU_RPFR_FLTSTEN_MASK)
#define RCU_RPFR_FLTEN_MASK                                (0x1U)
#define RCU_RPFR_FLTEN_SHIFT                               (0U)
#define RCU_RPFR_FLTEN(x)                                  (((uint32_t)(((uint32_t)(x)) << RCU_RPFR_FLTEN_SHIFT)) & RCU_RPFR_FLTEN_MASK)


/*!
 * @}
 */ /* end of group RCU_Register_Masks */


/*!
 * @}
 */ /* end of group RCU_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- UART Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup UART_Peripheral_Access_Layer UART Peripheral Access Layer
 * @{
 */


/** UART - Size of Registers Arrays */

/* UART Register Layout Typedef */
typedef struct {
    __IO uint32_t BAUD;                               /**< Baud Rate Configuration Register, offset: 0x0000 */
    __IO uint32_t CTRL0;                              /**< Control 0 Register, offset: 0x0004 */
    __IO uint32_t CTRL1;                              /**< Control 1 Register, offset: 0x0008 */
    __IO uint32_t INTF;                               /**< Interrupt Flag Register, offset: 0x000C */
    __IO uint32_t INTE;                               /**< Interrupt Enable Register, offset: 0x0010 */
    __IO uint32_t MATCH;                              /**< Match Configuration Register, offset: 0x0014 */
    __IO uint32_t DATA;                               /**< Data Buffer Register, offset: 0x0018 */

} UART_Type, *UART_MemMapPtr;

/** Number of instances of the UART module. */
#define UART_INSTANCE_COUNT                            (2u)

/* UART0  base address */
#define UART0_BASE                                         (0x4006A000)
#define UART0                                              ((UART_Type *)(UART0_BASE))
/* UART1  base address */
#define UART1_BASE                                         (0x4006B000)
#define UART1                                              ((UART_Type *)(UART1_BASE))

/** Array initializer of UART peripheral base addresses */
#define UART_BASE_ADDRS                                    { UART0_BASE,  UART1_BASE }
/** Array initializer of UART peripheral base pointers */
#define UART_BASE_PTRS                                     { UART0,  UART1 }
/** Number of interrupt vector arrays for the UART module. */
#define UART_IRQS_ARR_COUNT                                (1u)
/** Number of interrupt channels for the RX_TX type of UART. */
#define UART_RX_TX_IRQS_CH_COUNT                  (1u)
#define UART_RX_TX_IRQS                           { UART0_IRQn, UART1_IRQn }

/* UART Register Mask */
/* UART_BAUD Register */
#define UART_BAUD_OSRVAL_MASK                               (0x1F0000U)
#define UART_BAUD_OSRVAL_SHIFT                              (16U)
#define UART_BAUD_OSRVAL(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_BAUD_OSRVAL_SHIFT)) & UART_BAUD_OSRVAL_MASK)
#define UART_BAUD_DIV_MASK                                  (0x1FFFU)
#define UART_BAUD_DIV_SHIFT                                 (0U)
#define UART_BAUD_DIV(x)                                    (((uint32_t)(((uint32_t)(x)) << UART_BAUD_DIV_SHIFT)) & UART_BAUD_DIV_MASK)
/* UART_CTRL0 Register */
#define UART_CTRL0_MATEN_MASK                               (0x200000U)
#define UART_CTRL0_MATEN_SHIFT                              (21U)
#define UART_CTRL0_MATEN(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_CTRL0_MATEN_SHIFT)) & UART_CTRL0_MATEN_MASK)
#define UART_CTRL0_MATMOD_MASK                              (0x30000U)
#define UART_CTRL0_MATMOD_SHIFT                             (16U)
#define UART_CTRL0_MATMOD(x)                                (((uint32_t)(((uint32_t)(x)) << UART_CTRL0_MATMOD_SHIFT)) & UART_CTRL0_MATMOD_MASK)
#define UART_CTRL0_STDMODE_MASK                             (0x300U)
#define UART_CTRL0_STDMODE_SHIFT                            (8U)
#define UART_CTRL0_STDMODE(x)                               (((uint32_t)(((uint32_t)(x)) << UART_CTRL0_STDMODE_SHIFT)) & UART_CTRL0_STDMODE_MASK)
#define UART_CTRL0_TXEN_MASK                                (0x2U)
#define UART_CTRL0_TXEN_SHIFT                               (1U)
#define UART_CTRL0_TXEN(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_CTRL0_TXEN_SHIFT)) & UART_CTRL0_TXEN_MASK)
#define UART_CTRL0_RXEN_MASK                                (0x1U)
#define UART_CTRL0_RXEN_SHIFT                               (0U)
#define UART_CTRL0_RXEN(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_CTRL0_RXEN_SHIFT)) & UART_CTRL0_RXEN_MASK)
/* UART_CTRL1 Register */
#define UART_CTRL1_FRAMESZ_MASK                             (0xC0000000U)
#define UART_CTRL1_FRAMESZ_SHIFT                            (30U)
#define UART_CTRL1_FRAMESZ(x)                               (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_FRAMESZ_SHIFT)) & UART_CTRL1_FRAMESZ_MASK)
#define UART_CTRL1_STOPSZ_MASK                              (0x8000000U)
#define UART_CTRL1_STOPSZ_SHIFT                             (27U)
#define UART_CTRL1_STOPSZ(x)                                (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_STOPSZ_SHIFT)) & UART_CTRL1_STOPSZ_MASK)
#define UART_CTRL1_TXINV_MASK                               (0x1000000U)
#define UART_CTRL1_TXINV_SHIFT                              (24U)
#define UART_CTRL1_TXINV(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_TXINV_SHIFT)) & UART_CTRL1_TXINV_MASK)
#define UART_CTRL1_RXINV_MASK                               (0x800000U)
#define UART_CTRL1_RXINV_SHIFT                              (23U)
#define UART_CTRL1_RXINV(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_RXINV_SHIFT)) & UART_CTRL1_RXINV_MASK)
#define UART_CTRL1_SWAP_MASK                                (0x200000U)
#define UART_CTRL1_SWAP_SHIFT                               (21U)
#define UART_CTRL1_SWAP(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_SWAP_SHIFT)) & UART_CTRL1_SWAP_MASK)
#define UART_CTRL1_IDLESZ_MASK                              (0x70000U)
#define UART_CTRL1_IDLESZ_SHIFT                             (16U)
#define UART_CTRL1_IDLESZ(x)                                (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_IDLESZ_SHIFT)) & UART_CTRL1_IDLESZ_MASK)
#define UART_CTRL1_BOTHEDGE_MASK                            (0x8000U)
#define UART_CTRL1_BOTHEDGE_SHIFT                           (15U)
#define UART_CTRL1_BOTHEDGE(x)                              (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_BOTHEDGE_SHIFT)) & UART_CTRL1_BOTHEDGE_MASK)
#define UART_CTRL1_LBKDEN_MASK                              (0x400U)
#define UART_CTRL1_LBKDEN_SHIFT                             (10U)
#define UART_CTRL1_LBKDEN(x)                                (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_LBKDEN_SHIFT)) & UART_CTRL1_LBKDEN_MASK)
#define UART_CTRL1_LBKSZ_MASK                               (0x200U)
#define UART_CTRL1_LBKSZ_SHIFT                              (9U)
#define UART_CTRL1_LBKSZ(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_LBKSZ_SHIFT)) & UART_CTRL1_LBKSZ_MASK)
#define UART_CTRL1_MSBF_MASK                                (0x100U)
#define UART_CTRL1_MSBF_SHIFT                               (8U)
#define UART_CTRL1_MSBF(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_MSBF_SHIFT)) & UART_CTRL1_MSBF_MASK)
#define UART_CTRL1_SBK_MASK                                 (0x40U)
#define UART_CTRL1_SBK_SHIFT                                (6U)
#define UART_CTRL1_SBK(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_SBK_SHIFT)) & UART_CTRL1_SBK_MASK)
#define UART_CTRL1_PAREN_MASK                               (0x2U)
#define UART_CTRL1_PAREN_SHIFT                              (1U)
#define UART_CTRL1_PAREN(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_PAREN_SHIFT)) & UART_CTRL1_PAREN_MASK)
#define UART_CTRL1_PARSEL_MASK                              (0x1U)
#define UART_CTRL1_PARSEL_SHIFT                             (0U)
#define UART_CTRL1_PARSEL(x)                                (((uint32_t)(((uint32_t)(x)) << UART_CTRL1_PARSEL_SHIFT)) & UART_CTRL1_PARSEL_MASK)
/* UART_INTF Register */
#define UART_INTF_RXBUSY_MASK                               (0x20000U)
#define UART_INTF_RXBUSY_SHIFT                              (17U)
#define UART_INTF_RXBUSY(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_INTF_RXBUSY_SHIFT)) & UART_INTF_RXBUSY_MASK)
#define UART_INTF_LBKDIF_MASK                               (0x800U)
#define UART_INTF_LBKDIF_SHIFT                              (11U)
#define UART_INTF_LBKDIF(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_INTF_LBKDIF_SHIFT)) & UART_INTF_LBKDIF_MASK)
#define UART_INTF_RXEDGEIF_MASK                             (0x400U)
#define UART_INTF_RXEDGEIF_SHIFT                            (10U)
#define UART_INTF_RXEDGEIF(x)                               (((uint32_t)(((uint32_t)(x)) << UART_INTF_RXEDGEIF_SHIFT)) & UART_INTF_RXEDGEIF_MASK)
#define UART_INTF_MATIF_MASK                                (0x200U)
#define UART_INTF_MATIF_SHIFT                               (9U)
#define UART_INTF_MATIF(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_INTF_MATIF_SHIFT)) & UART_INTF_MATIF_MASK)
#define UART_INTF_NOZIF_MASK                                (0x80U)
#define UART_INTF_NOZIF_SHIFT                               (7U)
#define UART_INTF_NOZIF(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_INTF_NOZIF_SHIFT)) & UART_INTF_NOZIF_MASK)
#define UART_INTF_OVRIF_MASK                                (0x40U)
#define UART_INTF_OVRIF_SHIFT                               (6U)
#define UART_INTF_OVRIF(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_INTF_OVRIF_SHIFT)) & UART_INTF_OVRIF_MASK)
#define UART_INTF_FEIF_MASK                                 (0x20U)
#define UART_INTF_FEIF_SHIFT                                (5U)
#define UART_INTF_FEIF(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_INTF_FEIF_SHIFT)) & UART_INTF_FEIF_MASK)
#define UART_INTF_IDLEIF_MASK                               (0x10U)
#define UART_INTF_IDLEIF_SHIFT                              (4U)
#define UART_INTF_IDLEIF(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_INTF_IDLEIF_SHIFT)) & UART_INTF_IDLEIF_MASK)
#define UART_INTF_PARIF_MASK                                (0x8U)
#define UART_INTF_PARIF_SHIFT                               (3U)
#define UART_INTF_PARIF(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_INTF_PARIF_SHIFT)) & UART_INTF_PARIF_MASK)
#define UART_INTF_TCIF_MASK                                 (0x4U)
#define UART_INTF_TCIF_SHIFT                                (2U)
#define UART_INTF_TCIF(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_INTF_TCIF_SHIFT)) & UART_INTF_TCIF_MASK)
#define UART_INTF_TXIF_MASK                                 (0x2U)
#define UART_INTF_TXIF_SHIFT                                (1U)
#define UART_INTF_TXIF(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_INTF_TXIF_SHIFT)) & UART_INTF_TXIF_MASK)
#define UART_INTF_RXIF_MASK                                 (0x1U)
#define UART_INTF_RXIF_SHIFT                                (0U)
#define UART_INTF_RXIF(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_INTF_RXIF_SHIFT)) & UART_INTF_RXIF_MASK)
/* UART_INTE Register */
#define UART_INTE_LBKDIE_MASK                               (0x800U)
#define UART_INTE_LBKDIE_SHIFT                              (11U)
#define UART_INTE_LBKDIE(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_INTE_LBKDIE_SHIFT)) & UART_INTE_LBKDIE_MASK)
#define UART_INTE_RXEDGEIE_MASK                             (0x400U)
#define UART_INTE_RXEDGEIE_SHIFT                            (10U)
#define UART_INTE_RXEDGEIE(x)                               (((uint32_t)(((uint32_t)(x)) << UART_INTE_RXEDGEIE_SHIFT)) & UART_INTE_RXEDGEIE_MASK)
#define UART_INTE_MATIE_MASK                                (0x200U)
#define UART_INTE_MATIE_SHIFT                               (9U)
#define UART_INTE_MATIE(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_INTE_MATIE_SHIFT)) & UART_INTE_MATIE_MASK)
#define UART_INTE_NOZIE_MASK                                (0x80U)
#define UART_INTE_NOZIE_SHIFT                               (7U)
#define UART_INTE_NOZIE(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_INTE_NOZIE_SHIFT)) & UART_INTE_NOZIE_MASK)
#define UART_INTE_OVRIE_MASK                                (0x40U)
#define UART_INTE_OVRIE_SHIFT                               (6U)
#define UART_INTE_OVRIE(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_INTE_OVRIE_SHIFT)) & UART_INTE_OVRIE_MASK)
#define UART_INTE_FEIE_MASK                                 (0x20U)
#define UART_INTE_FEIE_SHIFT                                (5U)
#define UART_INTE_FEIE(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_INTE_FEIE_SHIFT)) & UART_INTE_FEIE_MASK)
#define UART_INTE_IDLEIE_MASK                               (0x10U)
#define UART_INTE_IDLEIE_SHIFT                              (4U)
#define UART_INTE_IDLEIE(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_INTE_IDLEIE_SHIFT)) & UART_INTE_IDLEIE_MASK)
#define UART_INTE_PARIE_MASK                                (0x8U)
#define UART_INTE_PARIE_SHIFT                               (3U)
#define UART_INTE_PARIE(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_INTE_PARIE_SHIFT)) & UART_INTE_PARIE_MASK)
#define UART_INTE_TCIE_MASK                                 (0x4U)
#define UART_INTE_TCIE_SHIFT                                (2U)
#define UART_INTE_TCIE(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_INTE_TCIE_SHIFT)) & UART_INTE_TCIE_MASK)
#define UART_INTE_TXIE_MASK                                 (0x2U)
#define UART_INTE_TXIE_SHIFT                                (1U)
#define UART_INTE_TXIE(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_INTE_TXIE_SHIFT)) & UART_INTE_TXIE_MASK)
#define UART_INTE_RXIE_MASK                                 (0x1U)
#define UART_INTE_RXIE_SHIFT                                (0U)
#define UART_INTE_RXIE(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_INTE_RXIE_SHIFT)) & UART_INTE_RXIE_MASK)
/* UART_MATCH Register */
#define UART_MATCH_DATA_MASK                                (0x3FFU)
#define UART_MATCH_DATA_SHIFT                               (0U)
#define UART_MATCH_DATA(x)                                  (((uint32_t)(((uint32_t)(x)) << UART_MATCH_DATA_SHIFT)) & UART_MATCH_DATA_MASK)
/* UART_DATA Register */
#define UART_DATA_RXEMPT_MASK                               (0x10000U)
#define UART_DATA_RXEMPT_SHIFT                              (16U)
#define UART_DATA_RXEMPT(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_DATA_RXEMPT_SHIFT)) & UART_DATA_RXEMPT_MASK)
#define UART_DATA_LINBRK_MASK                               (0x8000U)
#define UART_DATA_LINBRK_SHIFT                              (15U)
#define UART_DATA_LINBRK(x)                                 (((uint32_t)(((uint32_t)(x)) << UART_DATA_LINBRK_SHIFT)) & UART_DATA_LINBRK_MASK)
#define UART_DATA_DATA_MASK                                 (0x3FFU)
#define UART_DATA_DATA_SHIFT                                (0U)
#define UART_DATA_DATA(x)                                   (((uint32_t)(((uint32_t)(x)) << UART_DATA_DATA_SHIFT)) & UART_DATA_DATA_MASK)


/*!
 * @}
 */ /* end of group UART_Register_Masks */


/*!
 * @}
 */ /* end of group UART_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- SPI Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup SPI_Peripheral_Access_Layer SPI Peripheral Access Layer
 * @{
 */


/** SPI - Size of Registers Arrays */

/* SPI Register Layout Typedef */
typedef struct {
    __IO uint32_t CTRL;                               /**< Control Register, offset: 0x0000 */
    __IO uint32_t TXCFG;                              /**< Transmit Configuration Register, offset: 0x0004 */
    __IO uint32_t CLK;                                /**< Clock Configuration Register, offset: 0x0008 */
    __IO uint32_t STS;                                /**< Status Register, offset: 0x000C */
    __IO uint32_t INTE;                               /**< Interrupt Enable Register, offset: 0x0010 */
    __IO uint32_t MATCH0;                             /**< Data Match Register 0, offset: 0x0014 */
    __IO uint32_t MATCH1;                             /**< Data Match Register 1, offset: 0x0018 */
    __IO uint32_t Reserved1[ 2];                      /**< Reserved1, offset: 0x001C */
    __IO uint32_t DATA;                               /**< Data Register, offset: 0x0024 */

} SPI_Type, *SPI_MemMapPtr;

/** Number of instances of the SPI module. */
#define SPI_INSTANCE_COUNT                             (1u)

/* SPI0  base address */
#define SPI0_BASE                                          (0x4002C000)
#define SPI0                                               ((SPI_Type *)(SPI0_BASE))

/** Array initializer of SPI peripheral base addresses */
#define SPI_BASE_ADDRS                                     { SPI0_BASE }
/** Array initializer of SPI peripheral base pointers */
#define SPI_BASE_PTRS                                      { SPI0 }
/** Number of interrupt vector arrays for the SPI module. */
#define SPI_IRQS_ARR_COUNT                                 (u)
/** Number of interrupt channels for the SPI. */
#define SPI_IRQS_CH_COUNT                         (1u)
/** Interrupt vectors for the SPI peripheral type */
#define SPI_IRQS                                  { SPI0_IRQn }

/* SPI Register Mask */
/* SPI_CTRL Register */
#define SPI_CTRL_AUTOPCS_MASK                              (0x2000000U)
#define SPI_CTRL_AUTOPCS_SHIFT                             (25U)
#define SPI_CTRL_AUTOPCS(x)                                (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_AUTOPCS_SHIFT)) & SPI_CTRL_AUTOPCS_MASK)
#define SPI_CTRL_SPDEN_MASK                                (0x1000000U)
#define SPI_CTRL_SPDEN_SHIFT                               (24U)
#define SPI_CTRL_SPDEN(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_SPDEN_SHIFT)) & SPI_CTRL_SPDEN_MASK)
#define SPI_CTRL_MATCFG_MASK                               (0x70000U)
#define SPI_CTRL_MATCFG_SHIFT                              (16U)
#define SPI_CTRL_MATCFG(x)                                 (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_MATCFG_SHIFT)) & SPI_CTRL_MATCFG_MASK)
#define SPI_CTRL_CSPOL_MASK                                (0x300U)
#define SPI_CTRL_CSPOL_SHIFT                               (8U)
#define SPI_CTRL_CSPOL(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_CSPOL_SHIFT)) & SPI_CTRL_CSPOL_MASK)
#define SPI_CTRL_CSDEN_MASK                                (0x80U)
#define SPI_CTRL_CSDEN_SHIFT                               (7U)
#define SPI_CTRL_CSDEN(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_CSDEN_SHIFT)) & SPI_CTRL_CSDEN_MASK)
#define SPI_CTRL_DHZEN_MASK                                (0x40U)
#define SPI_CTRL_DHZEN_SHIFT                               (6U)
#define SPI_CTRL_DHZEN(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_DHZEN_SHIFT)) & SPI_CTRL_DHZEN_MASK)
#define SPI_CTRL_PINCFG_MASK                               (0x30U)
#define SPI_CTRL_PINCFG_SHIFT                              (4U)
#define SPI_CTRL_PINCFG(x)                                 (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_PINCFG_SHIFT)) & SPI_CTRL_PINCFG_MASK)
#define SPI_CTRL_RXMO_MASK                                 (0x8U)
#define SPI_CTRL_RXMO_SHIFT                                (3U)
#define SPI_CTRL_RXMO(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_RXMO_SHIFT)) & SPI_CTRL_RXMO_MASK)
#define SPI_CTRL_MODE_MASK                                 (0x2U)
#define SPI_CTRL_MODE_SHIFT                                (1U)
#define SPI_CTRL_MODE(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_MODE_SHIFT)) & SPI_CTRL_MODE_MASK)
#define SPI_CTRL_EN_MASK                                   (0x1U)
#define SPI_CTRL_EN_SHIFT                                  (0U)
#define SPI_CTRL_EN(x)                                     (((uint32_t)(((uint32_t)(x)) << SPI_CTRL_EN_SHIFT)) & SPI_CTRL_EN_MASK)
/* SPI_TXCFG Register */
#define SPI_TXCFG_CPOL_MASK                                (0x80000000U)
#define SPI_TXCFG_CPOL_SHIFT                               (31U)
#define SPI_TXCFG_CPOL(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_CPOL_SHIFT)) & SPI_TXCFG_CPOL_MASK)
#define SPI_TXCFG_CPHA_MASK                                (0x40000000U)
#define SPI_TXCFG_CPHA_SHIFT                               (30U)
#define SPI_TXCFG_CPHA(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_CPHA_SHIFT)) & SPI_TXCFG_CPHA_MASK)
#define SPI_TXCFG_PRESCALE_MASK                            (0x38000000U)
#define SPI_TXCFG_PRESCALE_SHIFT                           (27U)
#define SPI_TXCFG_PRESCALE(x)                              (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_PRESCALE_SHIFT)) & SPI_TXCFG_PRESCALE_MASK)
#define SPI_TXCFG_PCS_MASK                                 (0x3000000U)
#define SPI_TXCFG_PCS_SHIFT                                (24U)
#define SPI_TXCFG_PCS(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_PCS_SHIFT)) & SPI_TXCFG_PCS_MASK)
#define SPI_TXCFG_LSBF_MASK                                (0x800000U)
#define SPI_TXCFG_LSBF_SHIFT                               (23U)
#define SPI_TXCFG_LSBF(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_LSBF_SHIFT)) & SPI_TXCFG_LSBF_MASK)
#define SPI_TXCFG_BSW_MASK                                 (0x400000U)
#define SPI_TXCFG_BSW_SHIFT                                (22U)
#define SPI_TXCFG_BSW(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_BSW_SHIFT)) & SPI_TXCFG_BSW_MASK)
#define SPI_TXCFG_CONT_MASK                                (0x200000U)
#define SPI_TXCFG_CONT_SHIFT                               (21U)
#define SPI_TXCFG_CONT(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_CONT_SHIFT)) & SPI_TXCFG_CONT_MASK)
#define SPI_TXCFG_CONTC_MASK                               (0x100000U)
#define SPI_TXCFG_CONTC_SHIFT                              (20U)
#define SPI_TXCFG_CONTC(x)                                 (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_CONTC_SHIFT)) & SPI_TXCFG_CONTC_MASK)
#define SPI_TXCFG_MSKRX_MASK                               (0x80000U)
#define SPI_TXCFG_MSKRX_SHIFT                              (19U)
#define SPI_TXCFG_MSKRX(x)                                 (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_MSKRX_SHIFT)) & SPI_TXCFG_MSKRX_MASK)
#define SPI_TXCFG_MSKTX_MASK                               (0x40000U)
#define SPI_TXCFG_MSKTX_SHIFT                              (18U)
#define SPI_TXCFG_MSKTX(x)                                 (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_MSKTX_SHIFT)) & SPI_TXCFG_MSKTX_MASK)
#define SPI_TXCFG_WIDTH_MASK                               (0x30000U)
#define SPI_TXCFG_WIDTH_SHIFT                              (16U)
#define SPI_TXCFG_WIDTH(x)                                 (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_WIDTH_SHIFT)) & SPI_TXCFG_WIDTH_MASK)
#define SPI_TXCFG_FRAMESZ_WIDTH                            (12)
#define SPI_TXCFG_FRAMESZ_MASK                             (0xFFFU)
#define SPI_TXCFG_FRAMESZ_SHIFT                            (0U)
#define SPI_TXCFG_FRAMESZ(x)                               (((uint32_t)(((uint32_t)(x)) << SPI_TXCFG_FRAMESZ_SHIFT)) & SPI_TXCFG_FRAMESZ_MASK)
/* SPI_CLK Register */
#define SPI_CLK_SCKPCS_WIDTH                               (8)
#define SPI_CLK_SCKPCS_MASK                                (0xFF000000U)
#define SPI_CLK_SCKPCS_SHIFT                               (24U)
#define SPI_CLK_SCKPCS(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_CLK_SCKPCS_SHIFT)) & SPI_CLK_SCKPCS_MASK)
#define SPI_CLK_PCSSCK_WIDTH                               (8)
#define SPI_CLK_PCSSCK_MASK                                (0xFF0000U)
#define SPI_CLK_PCSSCK_SHIFT                               (16U)
#define SPI_CLK_PCSSCK(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_CLK_PCSSCK_SHIFT)) & SPI_CLK_PCSSCK_MASK)
#define SPI_CLK_FMDLY_WIDTH                                (8)
#define SPI_CLK_FMDLY_MASK                                 (0xFF00U)
#define SPI_CLK_FMDLY_SHIFT                                (8U)
#define SPI_CLK_FMDLY(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_CLK_FMDLY_SHIFT)) & SPI_CLK_FMDLY_MASK)
#define SPI_CLK_DIV_WIDTH                                  (8)
#define SPI_CLK_DIV_MASK                                   (0xFFU)
#define SPI_CLK_DIV_SHIFT                                  (0U)
#define SPI_CLK_DIV(x)                                     (((uint32_t)(((uint32_t)(x)) << SPI_CLK_DIV_SHIFT)) & SPI_CLK_DIV_MASK)
/* SPI_STS Register */
#define SPI_STS_BUSY_MASK                                  (0x40000U)
#define SPI_STS_BUSY_SHIFT                                 (18U)
#define SPI_STS_BUSY(x)                                    (((uint32_t)(((uint32_t)(x)) << SPI_STS_BUSY_SHIFT)) & SPI_STS_BUSY_MASK)
#define SPI_STS_RXEPT_MASK                                 (0x20000U)
#define SPI_STS_RXEPT_SHIFT                                (17U)
#define SPI_STS_RXEPT(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_STS_RXEPT_SHIFT)) & SPI_STS_RXEPT_MASK)
#define SPI_STS_SOF_MASK                                   (0x10000U)
#define SPI_STS_SOF_SHIFT                                  (16U)
#define SPI_STS_SOF(x)                                     (((uint32_t)(((uint32_t)(x)) << SPI_STS_SOF_SHIFT)) & SPI_STS_SOF_MASK)
#define SPI_STS_MATIF_MASK                                 (0x80U)
#define SPI_STS_MATIF_SHIFT                                (7U)
#define SPI_STS_MATIF(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_STS_MATIF_SHIFT)) & SPI_STS_MATIF_MASK)
#define SPI_STS_TCIF_MASK                                  (0x10U)
#define SPI_STS_TCIF_SHIFT                                 (4U)
#define SPI_STS_TCIF(x)                                    (((uint32_t)(((uint32_t)(x)) << SPI_STS_TCIF_SHIFT)) & SPI_STS_TCIF_MASK)
#define SPI_STS_FCIF_MASK                                  (0x8U)
#define SPI_STS_FCIF_SHIFT                                 (3U)
#define SPI_STS_FCIF(x)                                    (((uint32_t)(((uint32_t)(x)) << SPI_STS_FCIF_SHIFT)) & SPI_STS_FCIF_MASK)
#define SPI_STS_TXIF_MASK                                  (0x2U)
#define SPI_STS_TXIF_SHIFT                                 (1U)
#define SPI_STS_TXIF(x)                                    (((uint32_t)(((uint32_t)(x)) << SPI_STS_TXIF_SHIFT)) & SPI_STS_TXIF_MASK)
#define SPI_STS_RXIF_MASK                                  (0x1U)
#define SPI_STS_RXIF_SHIFT                                 (0U)
#define SPI_STS_RXIF(x)                                    (((uint32_t)(((uint32_t)(x)) << SPI_STS_RXIF_SHIFT)) & SPI_STS_RXIF_MASK)
/* SPI_INTE Register */
#define SPI_INTE_MATIE_MASK                                (0x80U)
#define SPI_INTE_MATIE_SHIFT                               (7U)
#define SPI_INTE_MATIE(x)                                  (((uint32_t)(((uint32_t)(x)) << SPI_INTE_MATIE_SHIFT)) & SPI_INTE_MATIE_MASK)
#define SPI_INTE_TCIE_MASK                                 (0x10U)
#define SPI_INTE_TCIE_SHIFT                                (4U)
#define SPI_INTE_TCIE(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_INTE_TCIE_SHIFT)) & SPI_INTE_TCIE_MASK)
#define SPI_INTE_FCIE_MASK                                 (0x8U)
#define SPI_INTE_FCIE_SHIFT                                (3U)
#define SPI_INTE_FCIE(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_INTE_FCIE_SHIFT)) & SPI_INTE_FCIE_MASK)
#define SPI_INTE_TXIE_MASK                                 (0x2U)
#define SPI_INTE_TXIE_SHIFT                                (1U)
#define SPI_INTE_TXIE(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_INTE_TXIE_SHIFT)) & SPI_INTE_TXIE_MASK)
#define SPI_INTE_RXIE_MASK                                 (0x1U)
#define SPI_INTE_RXIE_SHIFT                                (0U)
#define SPI_INTE_RXIE(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_INTE_RXIE_SHIFT)) & SPI_INTE_RXIE_MASK)
/* SPI_MATCH0 Register */
#define SPI_MATCH0_MATCH0_MASK                             (0xFFFFFFFFU)
#define SPI_MATCH0_MATCH0_SHIFT                            (0U)
#define SPI_MATCH0_MATCH0(x)                               (((uint32_t)(((uint32_t)(x)) << SPI_MATCH0_MATCH0_SHIFT)) & SPI_MATCH0_MATCH0_MASK)
/* SPI_MATCH1 Register */
#define SPI_MATCH1_MATCH1_MASK                             (0xFFFFFFFFU)
#define SPI_MATCH1_MATCH1_SHIFT                            (0U)
#define SPI_MATCH1_MATCH1(x)                               (((uint32_t)(((uint32_t)(x)) << SPI_MATCH1_MATCH1_SHIFT)) & SPI_MATCH1_MATCH1_MASK)
/* SPI_DATA Register */
#define SPI_DATA_DATA_MASK                                 (0xFFFFFFFFU)
#define SPI_DATA_DATA_SHIFT                                (0U)
#define SPI_DATA_DATA(x)                                   (((uint32_t)(((uint32_t)(x)) << SPI_DATA_DATA_SHIFT)) & SPI_DATA_DATA_MASK)


/*!
 * @}
 */ /* end of group SPI_Register_Masks */


/*!
 * @}
 */ /* end of group SPI_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- LINPHY Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup LINPHY_Peripheral_Access_Layer LINPHY Peripheral Access Layer
 * @{
 */


/** LINPHY - Size of Registers Arrays */

/* LINPHY Register Layout Typedef */
typedef struct {
    __IO uint32_t CR;                                 /**< Control Register, offset: 0x0000 */
    __IO uint32_t EHCR;                               /**< Enhanced Control Register, offset: 0x0004 */
    __IO uint32_t SCCR;                               /**< Switch Capacitor Configure Register, offset: 0x0008 */
    __IO uint32_t TBITCR;                             /**< LIN TBIT Configure Register, offset: 0x000C */
    __IO uint32_t SR;                                 /**< Status Register, offset: 0x0010 */
    __IO uint32_t IE;                                 /**< Interrupt Enable Register, offset: 0x0014 */

} LINPHY_Type, *LINPHY_MemMapPtr;

/** Number of instances of the LINPHY module. */
#define LINPHY_INSTANCE_COUNT                          (1u)

/* LINPHY base address */
#define LINPHY_BASE                                       (0x40070000)
#define LINPHY                                            ((LINPHY_Type *)(LINPHY_BASE))

/** Array initializer of LINPHY peripheral base addresses */
#define LINPHY_BASE_ADDRS                                  { LINPHY_BASE }
/** Array initializer of LINPHY peripheral base pointers */
#define LINPHY_BASE_PTRS                                   { LINPHY }

/* LINPHY Register Mask */
/* LINPHY_CR Register */
#define LINPHY_CR_RX_MODE_MASK                                (0x200U)
#define LINPHY_CR_RX_MODE_SHIFT                               (9U)
#define LINPHY_CR_RX_MODE(x)                                  (((uint32_t)(((uint32_t)(x)) << LINPHY_CR_RX_MODE_SHIFT)) & LINPHY_CR_RX_MODE_MASK)
#define LINPHY_CR_TX_MODE_MASK                                (0x100U)
#define LINPHY_CR_TX_MODE_SHIFT                               (8U)
#define LINPHY_CR_TX_MODE(x)                                  (((uint32_t)(((uint32_t)(x)) << LINPHY_CR_TX_MODE_SHIFT)) & LINPHY_CR_TX_MODE_MASK)
#define LINPHY_CR_EN_LIN_MASK                                 (0x1U)
#define LINPHY_CR_EN_LIN_SHIFT                                (0U)
#define LINPHY_CR_EN_LIN(x)                                   (((uint32_t)(((uint32_t)(x)) << LINPHY_CR_EN_LIN_SHIFT)) & LINPHY_CR_EN_LIN_MASK)
/* LINPHY_EHCR Register */
#define LINPHY_EHCR_CS_CLOSED_MASK                            (0x200U)
#define LINPHY_EHCR_CS_CLOSED_SHIFT                           (9U)
#define LINPHY_EHCR_CS_CLOSED(x)                              (((uint32_t)(((uint32_t)(x)) << LINPHY_EHCR_CS_CLOSED_SHIFT)) & LINPHY_EHCR_CS_CLOSED_MASK)
#define LINPHY_EHCR_BSMEN_MASK                                (0x100U)
#define LINPHY_EHCR_BSMEN_SHIFT                               (8U)
#define LINPHY_EHCR_BSMEN(x)                                  (((uint32_t)(((uint32_t)(x)) << LINPHY_EHCR_BSMEN_SHIFT)) & LINPHY_EHCR_BSMEN_MASK)
#define LINPHY_EHCR_LIN_IBIAS_CFG_MASK                        (0x70U)
#define LINPHY_EHCR_LIN_IBIAS_CFG_SHIFT                       (4U)
#define LINPHY_EHCR_LIN_IBIAS_CFG(x)                          (((uint32_t)(((uint32_t)(x)) << LINPHY_EHCR_LIN_IBIAS_CFG_SHIFT)) & LINPHY_EHCR_LIN_IBIAS_CFG_MASK)
#define LINPHY_EHCR_LIN_PU_ENH_MASK                           (0x4U)
#define LINPHY_EHCR_LIN_PU_ENH_SHIFT                          (2U)
#define LINPHY_EHCR_LIN_PU_ENH(x)                             (((uint32_t)(((uint32_t)(x)) << LINPHY_EHCR_LIN_PU_ENH_SHIFT)) & LINPHY_EHCR_LIN_PU_ENH_MASK)
#define LINPHY_EHCR_LIN_PU_CFG_MASK                           (0x3U)
#define LINPHY_EHCR_LIN_PU_CFG_SHIFT                          (0U)
#define LINPHY_EHCR_LIN_PU_CFG(x)                             (((uint32_t)(((uint32_t)(x)) << LINPHY_EHCR_LIN_PU_CFG_SHIFT)) & LINPHY_EHCR_LIN_PU_CFG_MASK)
/* LINPHY_SCCR Register */
#define LINPHY_SCCR_SC_SH_MASK                                (0x300U)
#define LINPHY_SCCR_SC_SH_SHIFT                               (8U)
#define LINPHY_SCCR_SC_SH(x)                                  (((uint32_t)(((uint32_t)(x)) << LINPHY_SCCR_SC_SH_SHIFT)) & LINPHY_SCCR_SC_SH_MASK)
#define LINPHY_SCCR_SC_GM_SEL_MASK                            (0xF0U)
#define LINPHY_SCCR_SC_GM_SEL_SHIFT                           (4U)
#define LINPHY_SCCR_SC_GM_SEL(x)                              (((uint32_t)(((uint32_t)(x)) << LINPHY_SCCR_SC_GM_SEL_SHIFT)) & LINPHY_SCCR_SC_GM_SEL_MASK)
#define LINPHY_SCCR_SCAMP_EN_MASK                             (0x1U)
#define LINPHY_SCCR_SCAMP_EN_SHIFT                            (0U)
#define LINPHY_SCCR_SCAMP_EN(x)                               (((uint32_t)(((uint32_t)(x)) << LINPHY_SCCR_SCAMP_EN_SHIFT)) & LINPHY_SCCR_SCAMP_EN_MASK)
/* LINPHY_TBITCR Register */
#define LINPHY_TBITCR_TBIT_DIV_MASK                           (0xFFFU)
#define LINPHY_TBITCR_TBIT_DIV_SHIFT                          (0U)
#define LINPHY_TBITCR_TBIT_DIV(x)                             (((uint32_t)(((uint32_t)(x)) << LINPHY_TBITCR_TBIT_DIV_SHIFT)) & LINPHY_TBITCR_TBIT_DIV_MASK)
/* LINPHY_SR Register */
#define LINPHY_SR_BSM_ST_MASK                                 (0x7000U)
#define LINPHY_SR_BSM_ST_SHIFT                                (12U)
#define LINPHY_SR_BSM_ST(x)                                   (((uint32_t)(((uint32_t)(x)) << LINPHY_SR_BSM_ST_SHIFT)) & LINPHY_SR_BSM_ST_MASK)
#define LINPHY_SR_CSOUTEN_ST_MASK                             (0x400U)
#define LINPHY_SR_CSOUTEN_ST_SHIFT                            (10U)
#define LINPHY_SR_CSOUTEN_ST(x)                               (((uint32_t)(((uint32_t)(x)) << LINPHY_SR_CSOUTEN_ST_SHIFT)) & LINPHY_SR_CSOUTEN_ST_MASK)
#define LINPHY_SR_CSEN_ST_MASK                                (0x200U)
#define LINPHY_SR_CSEN_ST_SHIFT                               (9U)
#define LINPHY_SR_CSEN_ST(x)                                  (((uint32_t)(((uint32_t)(x)) << LINPHY_SR_CSEN_ST_SHIFT)) & LINPHY_SR_CSEN_ST_MASK)
#define LINPHY_SR_BSM_DONE_MASK                               (0x100U)
#define LINPHY_SR_BSM_DONE_SHIFT                              (8U)
#define LINPHY_SR_BSM_DONE(x)                                 (((uint32_t)(((uint32_t)(x)) << LINPHY_SR_BSM_DONE_SHIFT)) & LINPHY_SR_BSM_DONE_MASK)
#define LINPHY_SR_LIN_PU_ENH_ST_MASK                          (0x4U)
#define LINPHY_SR_LIN_PU_ENH_ST_SHIFT                         (2U)
#define LINPHY_SR_LIN_PU_ENH_ST(x)                            (((uint32_t)(((uint32_t)(x)) << LINPHY_SR_LIN_PU_ENH_ST_SHIFT)) & LINPHY_SR_LIN_PU_ENH_ST_MASK)
#define LINPHY_SR_RXD_ST_MASK                                 (0x2U)
#define LINPHY_SR_RXD_ST_SHIFT                                (1U)
#define LINPHY_SR_RXD_ST(x)                                   (((uint32_t)(((uint32_t)(x)) << LINPHY_SR_RXD_ST_SHIFT)) & LINPHY_SR_RXD_ST_MASK)
#define LINPHY_SR_LIN_IRQ_MASK                                (0x1U)
#define LINPHY_SR_LIN_IRQ_SHIFT                               (0U)
#define LINPHY_SR_LIN_IRQ(x)                                  (((uint32_t)(((uint32_t)(x)) << LINPHY_SR_LIN_IRQ_SHIFT)) & LINPHY_SR_LIN_IRQ_MASK)
/* LINPHY_IE Register */
#define LINPHY_IE_BSM_DONE_IE_MASK                            (0x100U)
#define LINPHY_IE_BSM_DONE_IE_SHIFT                           (8U)
#define LINPHY_IE_BSM_DONE_IE(x)                              (((uint32_t)(((uint32_t)(x)) << LINPHY_IE_BSM_DONE_IE_SHIFT)) & LINPHY_IE_BSM_DONE_IE_MASK)
#define LINPHY_IE_LIN_IE_MASK                                 (0x1U)
#define LINPHY_IE_LIN_IE_SHIFT                                (0U)
#define LINPHY_IE_LIN_IE(x)                                   (((uint32_t)(((uint32_t)(x)) << LINPHY_IE_LIN_IE_SHIFT)) & LINPHY_IE_LIN_IE_MASK)


/*!
 * @}
 */ /* end of group LINPHY_Register_Masks */


/*!
 * @}
 */ /* end of group LINPHY_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- pTMR Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup pTMR_Peripheral_Access_Layer pTMR Peripheral Access Layer
 * @{
 */


/** pTMR - Size of Registers Arrays */
#define pTMR_CH_COUNT                     (4)

/* pTMR Register Layout Typedef */
typedef struct {
    __IO uint32_t MCR;                                /**< Module Control Register, offset: 0x0000 */
    __IO uint32_t RESERVED0[63];                      /**< RESERVED0, offset: 0x0004 */
    struct {
        __IO uint32_t TSV;                                /**< Timer Start Value Register, offset: 0x0100 */
        __IO uint32_t TCV;                                /**< Timer Current Value Register, offset: 0x0104 */
        __IO uint32_t TCR;                                /**< Timer Control Register, offset: 0x0108 */
        __IO uint32_t TFR;                                /**< Timer Flag Register, offset: 0x010C */

    } CH[4];

} pTMR_Type, *pTMR_MemMapPtr;

/** Number of instances of the pTMR module. */
#define pTMR_INSTANCE_COUNT                            (1u)

/* pTMR0  base address */
#define pTMR0_BASE                                         (0x40037000)
#define pTMR0                                              ((pTMR_Type *)(pTMR0_BASE))

/** Array initializer of pTMR peripheral base addresses */
#define pTMR_BASE_ADDRS                                    { pTMR0_BASE }
/** Array initializer of pTMR peripheral base pointers */
#define pTMR_BASE_PTRS                                     { pTMR0 }
/** Number of interrupt vector arrays for the pTMR module. */
#define pTMR_IRQS_ARR_COUNT                                (1u)
/** Number of interrupt channels for the pTMR. */
#define pTMR_IRQS_CH_COUNT                        (1u)
/** Interrupt vectors for the pTMR peripheral type */
#define pTMR_IRQS                                 { pTMR0_Ch0_IRQn, pTMR0_Ch1_IRQn, pTMR0_Ch2_IRQn, pTMR0_Ch3_IRQn }

/* pTMR Register Mask */
/* pTMR_MCR Register */
#define pTMR_MCR_FRZ_MASK                                   (0x2U)
#define pTMR_MCR_FRZ_SHIFT                                  (1U)
#define pTMR_MCR_FRZ(x)                                     (((uint32_t)(((uint32_t)(x)) << pTMR_MCR_FRZ_SHIFT)) & pTMR_MCR_FRZ_MASK)
#define pTMR_MCR_EN_MASK                                    (0x1U)
#define pTMR_MCR_EN_SHIFT                                   (0U)
#define pTMR_MCR_EN(x)                                      (((uint32_t)(((uint32_t)(x)) << pTMR_MCR_EN_SHIFT)) & pTMR_MCR_EN_MASK)
/* pTMR_CH_TSV Register */
#define pTMR_CH_TSV_STVAL_MASK                                 (0xFFFFU)
#define pTMR_CH_TSV_STVAL_SHIFT                                (0U)
#define pTMR_CH_TSV_STVAL(x)                                   (((uint32_t)(((uint32_t)(x)) << pTMR_CH_TSV_STVAL_SHIFT)) & pTMR_CH_TSV_STVAL_MASK)
/* pTMR_CH_TCV Register */
#define pTMR_CH_TCV_CVAL_MASK                                  (0xFFFFU)
#define pTMR_CH_TCV_CVAL_SHIFT                                 (0U)
#define pTMR_CH_TCV_CVAL(x)                                    (((uint32_t)(((uint32_t)(x)) << pTMR_CH_TCV_CVAL_SHIFT)) & pTMR_CH_TCV_CVAL_MASK)
/* pTMR_CH_TCR Register */
#define pTMR_CH_TCR_CHAIN_MASK                                 (0x4U)
#define pTMR_CH_TCR_CHAIN_SHIFT                                (2U)
#define pTMR_CH_TCR_CHAIN(x)                                   (((uint32_t)(((uint32_t)(x)) << pTMR_CH_TCR_CHAIN_SHIFT)) & pTMR_CH_TCR_CHAIN_MASK)
#define pTMR_CH_TCR_TIE_MASK                                   (0x2U)
#define pTMR_CH_TCR_TIE_SHIFT                                  (1U)
#define pTMR_CH_TCR_TIE(x)                                     (((uint32_t)(((uint32_t)(x)) << pTMR_CH_TCR_TIE_SHIFT)) & pTMR_CH_TCR_TIE_MASK)
#define pTMR_CH_TCR_TEN_MASK                                   (0x1U)
#define pTMR_CH_TCR_TEN_SHIFT                                  (0U)
#define pTMR_CH_TCR_TEN(x)                                     (((uint32_t)(((uint32_t)(x)) << pTMR_CH_TCR_TEN_SHIFT)) & pTMR_CH_TCR_TEN_MASK)
/* pTMR_CH_TFR Register */
#define pTMR_CH_TFR_TIF_MASK                                   (0x1U)
#define pTMR_CH_TFR_TIF_SHIFT                                  (0U)
#define pTMR_CH_TFR_TIF(x)                                     (((uint32_t)(((uint32_t)(x)) << pTMR_CH_TFR_TIF_SHIFT)) & pTMR_CH_TFR_TIF_MASK)



/*!
 * @}
 */ /* end of group pTMR_Register_Masks */


/*!
 * @}
 */ /* end of group pTMR_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- MSPWM Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup MSPWM_Peripheral_Access_Layer MSPWM Peripheral Access Layer
 * @{
 */


/** MSPWM - Size of Registers Arrays */
#define MSPWM_CH_COUNT                     (8)

/* MSPWM Register Layout Typedef */
typedef struct {
    __IO uint32_t STS;                                /**< Status Register, offset: 0x0000 */
    __IO uint32_t CNT;                                /**< Counter Value Register, offset: 0x0004 */
    __IO uint32_t CTRL;                               /**< Control Register, offset: 0x0008 */
    __IO uint32_t SYNC;                               /**< Synchronous Register, offset: 0x000C */
    __IO uint32_t OTRIG;                              /**< Output Trigger Register, offset: 0x0010 */
    __IO uint32_t OWIN;                               /**< Output Window, offset: 0x0014 */
    __IO uint32_t INTE;                               /**< Interrupt Enable Register, offset: 0x0018 */
    __IO uint32_t CHINITV;                            /**< Channel Output Initial Value Register, offset: 0x001C */
    __IO uint32_t CHSWV;                              /**< Channel Software Value Register, offset: 0x0020 */
    __IO uint32_t CHMASK;                             /**< Channel Output Mask Value Register, offset: 0x0024 */
    __IO uint32_t MOD;                                /**< Counter Modulus Value Register, offset: 0x0028 */
    __IO uint32_t Reserved0[ 5];                      /**< Reserved0, offset: 0x0030 */
    struct {
        __IO uint32_t CTRL;                               /**< Channel Control Register, offset: 0x0040 */
        __IO uint32_t VAL0;                               /**< Value 0 Register, offset: 0x0044 */
        __IO uint32_t VAL1;                               /**< Value 1 Register, offset: 0x0048 */
    __IO uint32_t Reserved1[ 5];                      /**< , offset: 0x004C */

    } CH[8];

} MSPWM_Type, *MSPWM_MemMapPtr;

/** Number of instances of the MSPWM module. */
#define MSPWM_INSTANCE_COUNT                           (1u)

/* MSPWM base address */
#define MSPWM_BASE                                        (0x40038000)
#define MSPWM                                             ((MSPWM_Type *)(MSPWM_BASE))

/** Array initializer of MSPWM peripheral base addresses */
#define MSPWM_BASE_ADDRS                                   { MSPWM_BASE }
/** Array initializer of MSPWM peripheral base pointers */
#define MSPWM_BASE_PTRS                                    { MSPWM }
/** Number of interrupt vector arrays for the MSPWM module. */
#define MSPWM_IRQS_ARR_COUNT                               (1u)
/** Number of interrupt channels for the CHN type of MSPWM. */
#define MSPWM_CHN_IRQS_CH_COUNT                   (1u)
#define MSPWM_CHN_IRQS                            { {MSPWM_IRQn, MSPWM_IRQn, MSPWM_IRQn, MSPWM_IRQn, MSPWM_IRQn, MSPWM_IRQn, MSPWM_IRQn, MSPWM_IRQn} }
/** Number of interrupt channels for the OVF type of MSPWM. */
#define MSPWM_OVF_IRQS_CH_COUNT                   (1u)
#define MSPWM_OVF_IRQS                            { MSPWM_IRQn }

/* MSPWM Register Mask */
/* MSPWM_STS Register */
#define MSPWM_STS_TOF_MASK                                   (0x2000U)
#define MSPWM_STS_TOF_SHIFT                                  (13U)
#define MSPWM_STS_TOF(x)                                     (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_TOF_SHIFT)) & MSPWM_STS_TOF_MASK)
#define MSPWM_STS_RF_MASK                                    (0x1000U)
#define MSPWM_STS_RF_SHIFT                                   (12U)
#define MSPWM_STS_RF(x)                                      (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_RF_SHIFT)) & MSPWM_STS_RF_MASK)
#define MSPWM_STS_CH7F_MASK                                  (0x80U)
#define MSPWM_STS_CH7F_SHIFT                                 (7U)
#define MSPWM_STS_CH7F(x)                                    (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_CH7F_SHIFT)) & MSPWM_STS_CH7F_MASK)
#define MSPWM_STS_CH6F_MASK                                  (0x40U)
#define MSPWM_STS_CH6F_SHIFT                                 (6U)
#define MSPWM_STS_CH6F(x)                                    (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_CH6F_SHIFT)) & MSPWM_STS_CH6F_MASK)
#define MSPWM_STS_CH5F_MASK                                  (0x20U)
#define MSPWM_STS_CH5F_SHIFT                                 (5U)
#define MSPWM_STS_CH5F(x)                                    (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_CH5F_SHIFT)) & MSPWM_STS_CH5F_MASK)
#define MSPWM_STS_CH4F_MASK                                  (0x10U)
#define MSPWM_STS_CH4F_SHIFT                                 (4U)
#define MSPWM_STS_CH4F(x)                                    (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_CH4F_SHIFT)) & MSPWM_STS_CH4F_MASK)
#define MSPWM_STS_CH3F_MASK                                  (0x8U)
#define MSPWM_STS_CH3F_SHIFT                                 (3U)
#define MSPWM_STS_CH3F(x)                                    (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_CH3F_SHIFT)) & MSPWM_STS_CH3F_MASK)
#define MSPWM_STS_CH2F_MASK                                  (0x4U)
#define MSPWM_STS_CH2F_SHIFT                                 (2U)
#define MSPWM_STS_CH2F(x)                                    (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_CH2F_SHIFT)) & MSPWM_STS_CH2F_MASK)
#define MSPWM_STS_CH1F_MASK                                  (0x2U)
#define MSPWM_STS_CH1F_SHIFT                                 (1U)
#define MSPWM_STS_CH1F(x)                                    (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_CH1F_SHIFT)) & MSPWM_STS_CH1F_MASK)
#define MSPWM_STS_CH0F_MASK                                  (0x1U)
#define MSPWM_STS_CH0F_SHIFT                                 (0U)
#define MSPWM_STS_CH0F(x)                                    (((uint32_t)(((uint32_t)(x)) << MSPWM_STS_CH0F_SHIFT)) & MSPWM_STS_CH0F_MASK)
/* MSPWM_CNT Register */
#define MSPWM_CNT_CNT_MASK                                   (0xFFFFU)
#define MSPWM_CNT_CNT_SHIFT                                  (0U)
#define MSPWM_CNT_CNT(x)                                     (((uint32_t)(((uint32_t)(x)) << MSPWM_CNT_CNT_SHIFT)) & MSPWM_CNT_CNT_MASK)
/* MSPWM_CTRL Register */
#define MSPWM_CTRL_COMPL67_MASK                              (0x8000000U)
#define MSPWM_CTRL_COMPL67_SHIFT                             (27U)
#define MSPWM_CTRL_COMPL67(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CTRL_COMPL67_SHIFT)) & MSPWM_CTRL_COMPL67_MASK)
#define MSPWM_CTRL_COMPL45_MASK                              (0x4000000U)
#define MSPWM_CTRL_COMPL45_SHIFT                             (26U)
#define MSPWM_CTRL_COMPL45(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CTRL_COMPL45_SHIFT)) & MSPWM_CTRL_COMPL45_MASK)
#define MSPWM_CTRL_COMPL23_MASK                              (0x2000000U)
#define MSPWM_CTRL_COMPL23_SHIFT                             (25U)
#define MSPWM_CTRL_COMPL23(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CTRL_COMPL23_SHIFT)) & MSPWM_CTRL_COMPL23_MASK)
#define MSPWM_CTRL_COMPL01_MASK                              (0x1000000U)
#define MSPWM_CTRL_COMPL01_SHIFT                             (24U)
#define MSPWM_CTRL_COMPL01(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CTRL_COMPL01_SHIFT)) & MSPWM_CTRL_COMPL01_MASK)
#define MSPWM_CTRL_DBGDIS_MASK                               (0x8000U)
#define MSPWM_CTRL_DBGDIS_SHIFT                              (15U)
#define MSPWM_CTRL_DBGDIS(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CTRL_DBGDIS_SHIFT)) & MSPWM_CTRL_DBGDIS_MASK)
#define MSPWM_CTRL_CLKPRS_WIDTH                              (7)
#define MSPWM_CTRL_CLKPRS_MASK                               (0x7F00U)
#define MSPWM_CTRL_CLKPRS_SHIFT                              (8U)
#define MSPWM_CTRL_CLKPRS(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CTRL_CLKPRS_SHIFT)) & MSPWM_CTRL_CLKPRS_MASK)
#define MSPWM_CTRL_GLOBEN_MASK                               (0x2U)
#define MSPWM_CTRL_GLOBEN_SHIFT                              (1U)
#define MSPWM_CTRL_GLOBEN(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CTRL_GLOBEN_SHIFT)) & MSPWM_CTRL_GLOBEN_MASK)
#define MSPWM_CTRL_EN_MASK                                   (0x1U)
#define MSPWM_CTRL_EN_SHIFT                                  (0U)
#define MSPWM_CTRL_EN(x)                                     (((uint32_t)(((uint32_t)(x)) << MSPWM_CTRL_EN_SHIFT)) & MSPWM_CTRL_EN_MASK)
/* MSPWM_SYNC Register */
#define MSPWM_SYNC_GLOB_MASK                                 (0x80000000U)
#define MSPWM_SYNC_GLOB_SHIFT                                (31U)
#define MSPWM_SYNC_GLOB(x)                                   (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_GLOB_SHIFT)) & MSPWM_SYNC_GLOB_MASK)
#define MSPWM_SYNC_LDFRQ_WIDTH                               (5)
#define MSPWM_SYNC_LDFRQ_MASK                                (0x1F000000U)
#define MSPWM_SYNC_LDFRQ_SHIFT                               (24U)
#define MSPWM_SYNC_LDFRQ(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_LDFRQ_SHIFT)) & MSPWM_SYNC_LDFRQ_MASK)
#define MSPWM_SYNC_TRIGEN_MASK                               (0x20000U)
#define MSPWM_SYNC_TRIGEN_SHIFT                              (17U)
#define MSPWM_SYNC_TRIGEN(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_TRIGEN_SHIFT)) & MSPWM_SYNC_TRIGEN_MASK)
#define MSPWM_SYNC_SWTRIG_MASK                               (0x10000U)
#define MSPWM_SYNC_SWTRIG_SHIFT                              (16U)
#define MSPWM_SYNC_SWTRIG(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_SWTRIG_SHIFT)) & MSPWM_SYNC_SWTRIG_MASK)
#define MSPWM_SYNC_MASKLD_WIDTH                              (2)
#define MSPWM_SYNC_MASKLD_MASK                               (0xC000U)
#define MSPWM_SYNC_MASKLD_SHIFT                              (14U)
#define MSPWM_SYNC_MASKLD(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_MASKLD_SHIFT)) & MSPWM_SYNC_MASKLD_MASK)
#define MSPWM_SYNC_TRIGS2_WIDTH                              (2)
#define MSPWM_SYNC_TRIGS2_MASK                               (0x3000U)
#define MSPWM_SYNC_TRIGS2_SHIFT                              (12U)
#define MSPWM_SYNC_TRIGS2(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_TRIGS2_SHIFT)) & MSPWM_SYNC_TRIGS2_MASK)
#define MSPWM_SYNC_CNTLD_WIDTH                               (2)
#define MSPWM_SYNC_CNTLD_MASK                                (0xC00U)
#define MSPWM_SYNC_CNTLD_SHIFT                               (10U)
#define MSPWM_SYNC_CNTLD(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_CNTLD_SHIFT)) & MSPWM_SYNC_CNTLD_MASK)
#define MSPWM_SYNC_TRIGS1_WIDTH                              (2)
#define MSPWM_SYNC_TRIGS1_MASK                               (0x300U)
#define MSPWM_SYNC_TRIGS1_SHIFT                              (8U)
#define MSPWM_SYNC_TRIGS1(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_TRIGS1_SHIFT)) & MSPWM_SYNC_TRIGS1_MASK)
#define MSPWM_SYNC_REGLD_WIDTH                               (2)
#define MSPWM_SYNC_REGLD_MASK                                (0xC0U)
#define MSPWM_SYNC_REGLD_SHIFT                               (6U)
#define MSPWM_SYNC_REGLD(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_REGLD_SHIFT)) & MSPWM_SYNC_REGLD_MASK)
#define MSPWM_SYNC_TRIGS0_WIDTH                              (2)
#define MSPWM_SYNC_TRIGS0_MASK                               (0x30U)
#define MSPWM_SYNC_TRIGS0_SHIFT                              (4U)
#define MSPWM_SYNC_TRIGS0(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_TRIGS0_SHIFT)) & MSPWM_SYNC_TRIGS0_MASK)
#define MSPWM_SYNC_CLDOK_MASK                                (0x2U)
#define MSPWM_SYNC_CLDOK_SHIFT                               (1U)
#define MSPWM_SYNC_CLDOK(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_CLDOK_SHIFT)) & MSPWM_SYNC_CLDOK_MASK)
#define MSPWM_SYNC_LDOK_MASK                                 (0x1U)
#define MSPWM_SYNC_LDOK_SHIFT                                (0U)
#define MSPWM_SYNC_LDOK(x)                                   (((uint32_t)(((uint32_t)(x)) << MSPWM_SYNC_LDOK_SHIFT)) & MSPWM_SYNC_LDOK_MASK)
/* MSPWM_OTRIG Register */
#define MSPWM_OTRIG_T1FRQ_WIDTH                              (5)
#define MSPWM_OTRIG_T1FRQ_MASK                               (0x1F000000U)
#define MSPWM_OTRIG_T1FRQ_SHIFT                              (24U)
#define MSPWM_OTRIG_T1FRQ(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_OTRIG_T1FRQ_SHIFT)) & MSPWM_OTRIG_T1FRQ_MASK)
#define MSPWM_OTRIG_MODT1EN_MASK                             (0x10000U)
#define MSPWM_OTRIG_MODT1EN_SHIFT                            (16U)
#define MSPWM_OTRIG_MODT1EN(x)                               (((uint32_t)(((uint32_t)(x)) << MSPWM_OTRIG_MODT1EN_SHIFT)) & MSPWM_OTRIG_MODT1EN_MASK)
#define MSPWM_OTRIG_T0FRQ_WIDTH                              (5)
#define MSPWM_OTRIG_T0FRQ_MASK                               (0x1F00U)
#define MSPWM_OTRIG_T0FRQ_SHIFT                              (8U)
#define MSPWM_OTRIG_T0FRQ(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_OTRIG_T0FRQ_SHIFT)) & MSPWM_OTRIG_T0FRQ_MASK)
#define MSPWM_OTRIG_MODT0EN_MASK                             (0x1U)
#define MSPWM_OTRIG_MODT0EN_SHIFT                            (0U)
#define MSPWM_OTRIG_MODT0EN(x)                               (((uint32_t)(((uint32_t)(x)) << MSPWM_OTRIG_MODT0EN_SHIFT)) & MSPWM_OTRIG_MODT0EN_MASK)
/* MSPWM_OWIN Register */
#define MSPWM_OWIN_WINSEL_WIDTH                              (4)
#define MSPWM_OWIN_WINSEL_MASK                               (0xF00U)
#define MSPWM_OWIN_WINSEL_SHIFT                              (8U)
#define MSPWM_OWIN_WINSEL(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_OWIN_WINSEL_SHIFT)) & MSPWM_OWIN_WINSEL_MASK)
#define MSPWM_OWIN_WINEN_MASK                                (0x1U)
#define MSPWM_OWIN_WINEN_SHIFT                               (0U)
#define MSPWM_OWIN_WINEN(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_OWIN_WINEN_SHIFT)) & MSPWM_OWIN_WINEN_MASK)
/* MSPWM_INTE Register */
#define MSPWM_INTE_TOIE_MASK                                 (0x2000U)
#define MSPWM_INTE_TOIE_SHIFT                                (13U)
#define MSPWM_INTE_TOIE(x)                                   (((uint32_t)(((uint32_t)(x)) << MSPWM_INTE_TOIE_SHIFT)) & MSPWM_INTE_TOIE_MASK)
#define MSPWM_INTE_CH7IE_MASK                                (0x80U)
#define MSPWM_INTE_CH7IE_SHIFT                               (7U)
#define MSPWM_INTE_CH7IE(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_INTE_CH7IE_SHIFT)) & MSPWM_INTE_CH7IE_MASK)
#define MSPWM_INTE_CH6IE_MASK                                (0x40U)
#define MSPWM_INTE_CH6IE_SHIFT                               (6U)
#define MSPWM_INTE_CH6IE(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_INTE_CH6IE_SHIFT)) & MSPWM_INTE_CH6IE_MASK)
#define MSPWM_INTE_CH5IE_MASK                                (0x20U)
#define MSPWM_INTE_CH5IE_SHIFT                               (5U)
#define MSPWM_INTE_CH5IE(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_INTE_CH5IE_SHIFT)) & MSPWM_INTE_CH5IE_MASK)
#define MSPWM_INTE_CH4IE_MASK                                (0x10U)
#define MSPWM_INTE_CH4IE_SHIFT                               (4U)
#define MSPWM_INTE_CH4IE(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_INTE_CH4IE_SHIFT)) & MSPWM_INTE_CH4IE_MASK)
#define MSPWM_INTE_CH3IE_MASK                                (0x8U)
#define MSPWM_INTE_CH3IE_SHIFT                               (3U)
#define MSPWM_INTE_CH3IE(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_INTE_CH3IE_SHIFT)) & MSPWM_INTE_CH3IE_MASK)
#define MSPWM_INTE_CH2IE_MASK                                (0x4U)
#define MSPWM_INTE_CH2IE_SHIFT                               (2U)
#define MSPWM_INTE_CH2IE(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_INTE_CH2IE_SHIFT)) & MSPWM_INTE_CH2IE_MASK)
#define MSPWM_INTE_CH1IE_MASK                                (0x2U)
#define MSPWM_INTE_CH1IE_SHIFT                               (1U)
#define MSPWM_INTE_CH1IE(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_INTE_CH1IE_SHIFT)) & MSPWM_INTE_CH1IE_MASK)
#define MSPWM_INTE_CH0IE_MASK                                (0x1U)
#define MSPWM_INTE_CH0IE_SHIFT                               (0U)
#define MSPWM_INTE_CH0IE(x)                                  (((uint32_t)(((uint32_t)(x)) << MSPWM_INTE_CH0IE_SHIFT)) & MSPWM_INTE_CH0IE_MASK)
/* MSPWM_CHINITV Register */
#define MSPWM_CHINITV_CH7INITV_MASK                          (0x80U)
#define MSPWM_CHINITV_CH7INITV_SHIFT                         (7U)
#define MSPWM_CHINITV_CH7INITV(x)                            (((uint32_t)(((uint32_t)(x)) << MSPWM_CHINITV_CH7INITV_SHIFT)) & MSPWM_CHINITV_CH7INITV_MASK)
#define MSPWM_CHINITV_CH6INITV_MASK                          (0x40U)
#define MSPWM_CHINITV_CH6INITV_SHIFT                         (6U)
#define MSPWM_CHINITV_CH6INITV(x)                            (((uint32_t)(((uint32_t)(x)) << MSPWM_CHINITV_CH6INITV_SHIFT)) & MSPWM_CHINITV_CH6INITV_MASK)
#define MSPWM_CHINITV_CH5INITV_MASK                          (0x20U)
#define MSPWM_CHINITV_CH5INITV_SHIFT                         (5U)
#define MSPWM_CHINITV_CH5INITV(x)                            (((uint32_t)(((uint32_t)(x)) << MSPWM_CHINITV_CH5INITV_SHIFT)) & MSPWM_CHINITV_CH5INITV_MASK)
#define MSPWM_CHINITV_CH4INITV_MASK                          (0x10U)
#define MSPWM_CHINITV_CH4INITV_SHIFT                         (4U)
#define MSPWM_CHINITV_CH4INITV(x)                            (((uint32_t)(((uint32_t)(x)) << MSPWM_CHINITV_CH4INITV_SHIFT)) & MSPWM_CHINITV_CH4INITV_MASK)
#define MSPWM_CHINITV_CH3INITV_MASK                          (0x8U)
#define MSPWM_CHINITV_CH3INITV_SHIFT                         (3U)
#define MSPWM_CHINITV_CH3INITV(x)                            (((uint32_t)(((uint32_t)(x)) << MSPWM_CHINITV_CH3INITV_SHIFT)) & MSPWM_CHINITV_CH3INITV_MASK)
#define MSPWM_CHINITV_CH2INITV_MASK                          (0x4U)
#define MSPWM_CHINITV_CH2INITV_SHIFT                         (2U)
#define MSPWM_CHINITV_CH2INITV(x)                            (((uint32_t)(((uint32_t)(x)) << MSPWM_CHINITV_CH2INITV_SHIFT)) & MSPWM_CHINITV_CH2INITV_MASK)
#define MSPWM_CHINITV_CH1INITV_MASK                          (0x2U)
#define MSPWM_CHINITV_CH1INITV_SHIFT                         (1U)
#define MSPWM_CHINITV_CH1INITV(x)                            (((uint32_t)(((uint32_t)(x)) << MSPWM_CHINITV_CH1INITV_SHIFT)) & MSPWM_CHINITV_CH1INITV_MASK)
#define MSPWM_CHINITV_CH0INITV_MASK                          (0x1U)
#define MSPWM_CHINITV_CH0INITV_SHIFT                         (0U)
#define MSPWM_CHINITV_CH0INITV(x)                            (((uint32_t)(((uint32_t)(x)) << MSPWM_CHINITV_CH0INITV_SHIFT)) & MSPWM_CHINITV_CH0INITV_MASK)
/* MSPWM_CHSWV Register */
#define MSPWM_CHSWV_CH7SWV_MASK                              (0x80U)
#define MSPWM_CHSWV_CH7SWV_SHIFT                             (7U)
#define MSPWM_CHSWV_CH7SWV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHSWV_CH7SWV_SHIFT)) & MSPWM_CHSWV_CH7SWV_MASK)
#define MSPWM_CHSWV_CH6SWV_MASK                              (0x40U)
#define MSPWM_CHSWV_CH6SWV_SHIFT                             (6U)
#define MSPWM_CHSWV_CH6SWV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHSWV_CH6SWV_SHIFT)) & MSPWM_CHSWV_CH6SWV_MASK)
#define MSPWM_CHSWV_CH5SWV_MASK                              (0x20U)
#define MSPWM_CHSWV_CH5SWV_SHIFT                             (5U)
#define MSPWM_CHSWV_CH5SWV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHSWV_CH5SWV_SHIFT)) & MSPWM_CHSWV_CH5SWV_MASK)
#define MSPWM_CHSWV_CH4SWV_MASK                              (0x10U)
#define MSPWM_CHSWV_CH4SWV_SHIFT                             (4U)
#define MSPWM_CHSWV_CH4SWV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHSWV_CH4SWV_SHIFT)) & MSPWM_CHSWV_CH4SWV_MASK)
#define MSPWM_CHSWV_CH3SWV_MASK                              (0x8U)
#define MSPWM_CHSWV_CH3SWV_SHIFT                             (3U)
#define MSPWM_CHSWV_CH3SWV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHSWV_CH3SWV_SHIFT)) & MSPWM_CHSWV_CH3SWV_MASK)
#define MSPWM_CHSWV_CH2SWV_MASK                              (0x4U)
#define MSPWM_CHSWV_CH2SWV_SHIFT                             (2U)
#define MSPWM_CHSWV_CH2SWV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHSWV_CH2SWV_SHIFT)) & MSPWM_CHSWV_CH2SWV_MASK)
#define MSPWM_CHSWV_CH1SWV_MASK                              (0x2U)
#define MSPWM_CHSWV_CH1SWV_SHIFT                             (1U)
#define MSPWM_CHSWV_CH1SWV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHSWV_CH1SWV_SHIFT)) & MSPWM_CHSWV_CH1SWV_MASK)
#define MSPWM_CHSWV_CH0SWV_MASK                              (0x1U)
#define MSPWM_CHSWV_CH0SWV_SHIFT                             (0U)
#define MSPWM_CHSWV_CH0SWV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHSWV_CH0SWV_SHIFT)) & MSPWM_CHSWV_CH0SWV_MASK)
/* MSPWM_CHMASK Register */
#define MSPWM_CHMASK_CH7MV_WIDTH                             (1)
#define MSPWM_CHMASK_CH7MV_MASK                              (0x800000U)
#define MSPWM_CHMASK_CH7MV_SHIFT                             (23U)
#define MSPWM_CHMASK_CH7MV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH7MV_SHIFT)) & MSPWM_CHMASK_CH7MV_MASK)
#define MSPWM_CHMASK_CH6MV_WIDTH                             (1)
#define MSPWM_CHMASK_CH6MV_MASK                              (0x400000U)
#define MSPWM_CHMASK_CH6MV_SHIFT                             (22U)
#define MSPWM_CHMASK_CH6MV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH6MV_SHIFT)) & MSPWM_CHMASK_CH6MV_MASK)
#define MSPWM_CHMASK_CH5MV_WIDTH                             (1)
#define MSPWM_CHMASK_CH5MV_MASK                              (0x200000U)
#define MSPWM_CHMASK_CH5MV_SHIFT                             (21U)
#define MSPWM_CHMASK_CH5MV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH5MV_SHIFT)) & MSPWM_CHMASK_CH5MV_MASK)
#define MSPWM_CHMASK_CH4MV_WIDTH                             (1)
#define MSPWM_CHMASK_CH4MV_MASK                              (0x100000U)
#define MSPWM_CHMASK_CH4MV_SHIFT                             (20U)
#define MSPWM_CHMASK_CH4MV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH4MV_SHIFT)) & MSPWM_CHMASK_CH4MV_MASK)
#define MSPWM_CHMASK_CH3MV_WIDTH                             (1)
#define MSPWM_CHMASK_CH3MV_MASK                              (0x80000U)
#define MSPWM_CHMASK_CH3MV_SHIFT                             (19U)
#define MSPWM_CHMASK_CH3MV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH3MV_SHIFT)) & MSPWM_CHMASK_CH3MV_MASK)
#define MSPWM_CHMASK_CH2MV_WIDTH                             (1)
#define MSPWM_CHMASK_CH2MV_MASK                              (0x40000U)
#define MSPWM_CHMASK_CH2MV_SHIFT                             (18U)
#define MSPWM_CHMASK_CH2MV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH2MV_SHIFT)) & MSPWM_CHMASK_CH2MV_MASK)
#define MSPWM_CHMASK_CH1MV_WIDTH                             (1)
#define MSPWM_CHMASK_CH1MV_MASK                              (0x20000U)
#define MSPWM_CHMASK_CH1MV_SHIFT                             (17U)
#define MSPWM_CHMASK_CH1MV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH1MV_SHIFT)) & MSPWM_CHMASK_CH1MV_MASK)
#define MSPWM_CHMASK_CH0MV_WIDTH                             (1)
#define MSPWM_CHMASK_CH0MV_MASK                              (0x10000U)
#define MSPWM_CHMASK_CH0MV_SHIFT                             (16U)
#define MSPWM_CHMASK_CH0MV(x)                                (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH0MV_SHIFT)) & MSPWM_CHMASK_CH0MV_MASK)
#define MSPWM_CHMASK_CH7M_MASK                               (0x80U)
#define MSPWM_CHMASK_CH7M_SHIFT                              (7U)
#define MSPWM_CHMASK_CH7M(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH7M_SHIFT)) & MSPWM_CHMASK_CH7M_MASK)
#define MSPWM_CHMASK_CH6M_MASK                               (0x40U)
#define MSPWM_CHMASK_CH6M_SHIFT                              (6U)
#define MSPWM_CHMASK_CH6M(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH6M_SHIFT)) & MSPWM_CHMASK_CH6M_MASK)
#define MSPWM_CHMASK_CH5M_MASK                               (0x20U)
#define MSPWM_CHMASK_CH5M_SHIFT                              (5U)
#define MSPWM_CHMASK_CH5M(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH5M_SHIFT)) & MSPWM_CHMASK_CH5M_MASK)
#define MSPWM_CHMASK_CH4M_MASK                               (0x10U)
#define MSPWM_CHMASK_CH4M_SHIFT                              (4U)
#define MSPWM_CHMASK_CH4M(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH4M_SHIFT)) & MSPWM_CHMASK_CH4M_MASK)
#define MSPWM_CHMASK_CH3M_MASK                               (0x8U)
#define MSPWM_CHMASK_CH3M_SHIFT                              (3U)
#define MSPWM_CHMASK_CH3M(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH3M_SHIFT)) & MSPWM_CHMASK_CH3M_MASK)
#define MSPWM_CHMASK_CH2M_MASK                               (0x4U)
#define MSPWM_CHMASK_CH2M_SHIFT                              (2U)
#define MSPWM_CHMASK_CH2M(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH2M_SHIFT)) & MSPWM_CHMASK_CH2M_MASK)
#define MSPWM_CHMASK_CH1M_MASK                               (0x2U)
#define MSPWM_CHMASK_CH1M_SHIFT                              (1U)
#define MSPWM_CHMASK_CH1M(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH1M_SHIFT)) & MSPWM_CHMASK_CH1M_MASK)
#define MSPWM_CHMASK_CH0M_MASK                               (0x1U)
#define MSPWM_CHMASK_CH0M_SHIFT                              (0U)
#define MSPWM_CHMASK_CH0M(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CHMASK_CH0M_SHIFT)) & MSPWM_CHMASK_CH0M_MASK)
/* MSPWM_MOD Register */
#define MSPWM_MOD_MOD_MASK                                   (0xFFFFU)
#define MSPWM_MOD_MOD_SHIFT                                  (0U)
#define MSPWM_MOD_MOD(x)                                     (((uint32_t)(((uint32_t)(x)) << MSPWM_MOD_MOD_SHIFT)) & MSPWM_MOD_MOD_MASK)
/* MSPWM_CH_CTRL Register */
#define MSPWM_CH_CTRL_LDEN_MASK                                 (0x10000000U)
#define MSPWM_CH_CTRL_LDEN_SHIFT                                (28U)
#define MSPWM_CH_CTRL_LDEN(x)                                   (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_CTRL_LDEN_SHIFT)) & MSPWM_CH_CTRL_LDEN_MASK)
#define MSPWM_CH_CTRL_VAL1T1EN_MASK                             (0x80000U)
#define MSPWM_CH_CTRL_VAL1T1EN_SHIFT                            (19U)
#define MSPWM_CH_CTRL_VAL1T1EN(x)                               (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_CTRL_VAL1T1EN_SHIFT)) & MSPWM_CH_CTRL_VAL1T1EN_MASK)
#define MSPWM_CH_CTRL_VAL0T1EN_MASK                             (0x40000U)
#define MSPWM_CH_CTRL_VAL0T1EN_SHIFT                            (18U)
#define MSPWM_CH_CTRL_VAL0T1EN(x)                               (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_CTRL_VAL0T1EN_SHIFT)) & MSPWM_CH_CTRL_VAL0T1EN_MASK)
#define MSPWM_CH_CTRL_VAL1T0EN_MASK                             (0x20000U)
#define MSPWM_CH_CTRL_VAL1T0EN_SHIFT                            (17U)
#define MSPWM_CH_CTRL_VAL1T0EN(x)                               (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_CTRL_VAL1T0EN_SHIFT)) & MSPWM_CH_CTRL_VAL1T0EN_MASK)
#define MSPWM_CH_CTRL_VAL0T0EN_MASK                             (0x10000U)
#define MSPWM_CH_CTRL_VAL0T0EN_SHIFT                            (16U)
#define MSPWM_CH_CTRL_VAL0T0EN(x)                               (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_CTRL_VAL0T0EN_SHIFT)) & MSPWM_CH_CTRL_VAL0T0EN_MASK)
#define MSPWM_CH_CTRL_PWMSRC_MASK                               (0x300U)
#define MSPWM_CH_CTRL_PWMSRC_SHIFT                              (8U)
#define MSPWM_CH_CTRL_PWMSRC(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_CTRL_PWMSRC_SHIFT)) & MSPWM_CH_CTRL_PWMSRC_MASK)
#define MSPWM_CH_CTRL_CHINIT_MASK                               (0x10U)
#define MSPWM_CH_CTRL_CHINIT_SHIFT                              (4U)
#define MSPWM_CH_CTRL_CHINIT(x)                                 (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_CTRL_CHINIT_SHIFT)) & MSPWM_CH_CTRL_CHINIT_MASK)
#define MSPWM_CH_CTRL_CHEN_MASK                                 (0x1U)
#define MSPWM_CH_CTRL_CHEN_SHIFT                                (0U)
#define MSPWM_CH_CTRL_CHEN(x)                                   (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_CTRL_CHEN_SHIFT)) & MSPWM_CH_CTRL_CHEN_MASK)
/* MSPWM_CH_VAL0 Register */
#define MSPWM_CH_VAL0_VAL0_MASK                                 (0xFFFFU)
#define MSPWM_CH_VAL0_VAL0_SHIFT                                (0U)
#define MSPWM_CH_VAL0_VAL0(x)                                   (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_VAL0_VAL0_SHIFT)) & MSPWM_CH_VAL0_VAL0_MASK)
/* MSPWM_CH_VAL1 Register */
#define MSPWM_CH_VAL1_VAL1_MASK                                 (0xFFFFU)
#define MSPWM_CH_VAL1_VAL1_SHIFT                                (0U)
#define MSPWM_CH_VAL1_VAL1(x)                                   (((uint32_t)(((uint32_t)(x)) << MSPWM_CH_VAL1_VAL1_SHIFT)) & MSPWM_CH_VAL1_VAL1_MASK)



/*!
 * @}
 */ /* end of group MSPWM_Register_Masks */


/*!
 * @}
 */ /* end of group MSPWM_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- CCTMR Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup CCTMR_Peripheral_Access_Layer CCTMR Peripheral Access Layer
 * @{
 */


/** CCTMR - Size of Registers Arrays */
#define CCTMR_CH_COUNT                     (2)

/* CCTMR Register Layout Typedef */
typedef struct {
    __IO uint32_t STS;                                /**< Status Register, offset: 0x0000 */
    __IO uint32_t IOSTS;                              /**< Input/Output Status Register, offset: 0x0004 */
    __IO uint32_t CNT;                                /**< Counter Value Register, offset: 0x0008 */
    __IO uint32_t RESERVED_3;                         /**< RESERVED_3, offset: 0x000C */
    __IO uint32_t CTRL;                               /**< Control Register, offset: 0x0010 */
    __IO uint32_t SYNC;                               /**< Synchronous Register, offset: 0x0014 */
    __IO uint32_t OTRIG;                              /**< Output Trigger Register, offset: 0x0018 */
    __IO uint32_t INTE;                               /**< Interrupt Enable Register, offset: 0x001C */
    __IO uint32_t CHSWV;                              /**< Channel Software Value Register, offset: 0x0020 */
    __IO uint32_t MOD;                                /**< Counter Modulus Value Register, offset: 0x0024 */
    __IO uint32_t RESERVED_10;                        /**< RESERVED_10, offset: 0x0028 */
    __IO uint32_t Reserved0[ 5];                      /**< Reserved0, offset: 0x002C */
    struct {
        __IO uint32_t CTRL;                               /**< Channel Control Register, offset: 0x0040 */
        __IO uint32_t VAL0;                               /**< Value 0 Register, offset: 0x0044 */
        __IO uint32_t VAL1;                               /**< Value 1 Register, offset: 0x0048 */
        __IO uint32_t CVAL;                               /**< Capture Value Register, offset: 0x004C */
    __IO uint32_t Reserved1[ 4];                      /**< , offset: 0x0050 */

    } CH[2];

} CCTMR_Type, *CCTMR_MemMapPtr;

/** Number of instances of the CCTMR module. */
#define CCTMR_INSTANCE_COUNT                           (2u)

/* CCTMR0  base address */
#define CCTMR0_BASE                                        (0x40039000)
#define CCTMR0                                             ((CCTMR_Type *)(CCTMR0_BASE))
/* CCTMR1  base address */
#define CCTMR1_BASE                                        (0x4003A000)
#define CCTMR1                                             ((CCTMR_Type *)(CCTMR1_BASE))

/** Array initializer of CCTMR peripheral base addresses */
#define CCTMR_BASE_ADDRS                                   { CCTMR0_BASE,  CCTMR1_BASE }
/** Array initializer of CCTMR peripheral base pointers */
#define CCTMR_BASE_PTRS                                    { CCTMR0,  CCTMR1 }
/** Number of interrupt vector arrays for the CCTMR module. */
#define CCTMR_IRQS_ARR_COUNT                               (2u)
/** Number of interrupt channels for the Overflow type of CCTMR. */
#define CCTMR_OVF_IRQS_CH_COUNT                   (1u)
#define CCTMR_OVF_IRQS                            { CCTMR0_Ovf_IRQn, CCTMR1_Ovf_IRQn }
/** Number of interrupt channels for the CHN type of CCTMR. */
#define CCTMR_CHN_IRQS_CH_COUNT                   (1u)
#define CCTMR_CHN_IRQS                            { CCTMR0_Channel_IRQn, CCTMR1_Channel_IRQn }

/* CCTMR Register Mask */
/* CCTMR_STS Register */
#define CCTMR_STS_TOF_MASK                                   (0x2000U)
#define CCTMR_STS_TOF_SHIFT                                  (13U)
#define CCTMR_STS_TOF(x)                                     (((uint32_t)(((uint32_t)(x)) << CCTMR_STS_TOF_SHIFT)) & CCTMR_STS_TOF_MASK)
#define CCTMR_STS_CH1F_MASK                                  (0x2U)
#define CCTMR_STS_CH1F_SHIFT                                 (1U)
#define CCTMR_STS_CH1F(x)                                    (((uint32_t)(((uint32_t)(x)) << CCTMR_STS_CH1F_SHIFT)) & CCTMR_STS_CH1F_MASK)
#define CCTMR_STS_CH0F_MASK                                  (0x1U)
#define CCTMR_STS_CH0F_SHIFT                                 (0U)
#define CCTMR_STS_CH0F(x)                                    (((uint32_t)(((uint32_t)(x)) << CCTMR_STS_CH0F_SHIFT)) & CCTMR_STS_CH0F_MASK)
/* CCTMR_IOSTS Register */
#define CCTMR_IOSTS_CH1IO_MASK                               (0x2U)
#define CCTMR_IOSTS_CH1IO_SHIFT                              (1U)
#define CCTMR_IOSTS_CH1IO(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_IOSTS_CH1IO_SHIFT)) & CCTMR_IOSTS_CH1IO_MASK)
#define CCTMR_IOSTS_CH0IO_MASK                               (0x1U)
#define CCTMR_IOSTS_CH0IO_SHIFT                              (0U)
#define CCTMR_IOSTS_CH0IO(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_IOSTS_CH0IO_SHIFT)) & CCTMR_IOSTS_CH0IO_MASK)
/* CCTMR_CNT Register */
#define CCTMR_CNT_CNT_MASK                                   (0xFFFFU)
#define CCTMR_CNT_CNT_SHIFT                                  (0U)
#define CCTMR_CNT_CNT(x)                                     (((uint32_t)(((uint32_t)(x)) << CCTMR_CNT_CNT_SHIFT)) & CCTMR_CNT_CNT_MASK)
/* CCTMR_CTRL Register */
#define CCTMR_CTRL_CAPTST_MASK                               (0x80000000U)
#define CCTMR_CTRL_CAPTST_SHIFT                              (31U)
#define CCTMR_CTRL_CAPTST(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_CTRL_CAPTST_SHIFT)) & CCTMR_CTRL_CAPTST_MASK)
#define CCTMR_CTRL_TRIGMD_WIDTH                              (2)
#define CCTMR_CTRL_TRIGMD_MASK                               (0x30000U)
#define CCTMR_CTRL_TRIGMD_SHIFT                              (16U)
#define CCTMR_CTRL_TRIGMD(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_CTRL_TRIGMD_SHIFT)) & CCTMR_CTRL_TRIGMD_MASK)
#define CCTMR_CTRL_DBGDIS_MASK                               (0x8000U)
#define CCTMR_CTRL_DBGDIS_SHIFT                              (15U)
#define CCTMR_CTRL_DBGDIS(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_CTRL_DBGDIS_SHIFT)) & CCTMR_CTRL_DBGDIS_MASK)
#define CCTMR_CTRL_CLKPRS_WIDTH                              (7)
#define CCTMR_CTRL_CLKPRS_MASK                               (0x7F00U)
#define CCTMR_CTRL_CLKPRS_SHIFT                              (8U)
#define CCTMR_CTRL_CLKPRS(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_CTRL_CLKPRS_SHIFT)) & CCTMR_CTRL_CLKPRS_MASK)
#define CCTMR_CTRL_CNTMD_MASK                                (0x10U)
#define CCTMR_CTRL_CNTMD_SHIFT                               (4U)
#define CCTMR_CTRL_CNTMD(x)                                  (((uint32_t)(((uint32_t)(x)) << CCTMR_CTRL_CNTMD_SHIFT)) & CCTMR_CTRL_CNTMD_MASK)
#define CCTMR_CTRL_GLOBEN_MASK                               (0x2U)
#define CCTMR_CTRL_GLOBEN_SHIFT                              (1U)
#define CCTMR_CTRL_GLOBEN(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_CTRL_GLOBEN_SHIFT)) & CCTMR_CTRL_GLOBEN_MASK)
#define CCTMR_CTRL_EN_MASK                                   (0x1U)
#define CCTMR_CTRL_EN_SHIFT                                  (0U)
#define CCTMR_CTRL_EN(x)                                     (((uint32_t)(((uint32_t)(x)) << CCTMR_CTRL_EN_SHIFT)) & CCTMR_CTRL_EN_MASK)
/* CCTMR_SYNC Register */
#define CCTMR_SYNC_GLOB_MASK                                 (0x80000000U)
#define CCTMR_SYNC_GLOB_SHIFT                                (31U)
#define CCTMR_SYNC_GLOB(x)                                   (((uint32_t)(((uint32_t)(x)) << CCTMR_SYNC_GLOB_SHIFT)) & CCTMR_SYNC_GLOB_MASK)
#define CCTMR_SYNC_SWTRIG_MASK                               (0x1U)
#define CCTMR_SYNC_SWTRIG_SHIFT                              (0U)
#define CCTMR_SYNC_SWTRIG(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_SYNC_SWTRIG_SHIFT)) & CCTMR_SYNC_SWTRIG_MASK)
/* CCTMR_OTRIG Register */
#define CCTMR_OTRIG_TFRQ_WIDTH                               (4)
#define CCTMR_OTRIG_TFRQ_MASK                                (0xF000U)
#define CCTMR_OTRIG_TFRQ_SHIFT                               (12U)
#define CCTMR_OTRIG_TFRQ(x)                                  (((uint32_t)(((uint32_t)(x)) << CCTMR_OTRIG_TFRQ_SHIFT)) & CCTMR_OTRIG_TFRQ_MASK)
#define CCTMR_OTRIG_PWMTSEL_WIDTH                            (3)
#define CCTMR_OTRIG_PWMTSEL_MASK                             (0x700U)
#define CCTMR_OTRIG_PWMTSEL_SHIFT                            (8U)
#define CCTMR_OTRIG_PWMTSEL(x)                               (((uint32_t)(((uint32_t)(x)) << CCTMR_OTRIG_PWMTSEL_SHIFT)) & CCTMR_OTRIG_PWMTSEL_MASK)
#define CCTMR_OTRIG_TSRC_MASK                                (0x10U)
#define CCTMR_OTRIG_TSRC_SHIFT                               (4U)
#define CCTMR_OTRIG_TSRC(x)                                  (((uint32_t)(((uint32_t)(x)) << CCTMR_OTRIG_TSRC_SHIFT)) & CCTMR_OTRIG_TSRC_MASK)
#define CCTMR_OTRIG_MODTEN_MASK                              (0x1U)
#define CCTMR_OTRIG_MODTEN_SHIFT                             (0U)
#define CCTMR_OTRIG_MODTEN(x)                                (((uint32_t)(((uint32_t)(x)) << CCTMR_OTRIG_MODTEN_SHIFT)) & CCTMR_OTRIG_MODTEN_MASK)
/* CCTMR_INTE Register */
#define CCTMR_INTE_TOIE_MASK                                 (0x2000U)
#define CCTMR_INTE_TOIE_SHIFT                                (13U)
#define CCTMR_INTE_TOIE(x)                                   (((uint32_t)(((uint32_t)(x)) << CCTMR_INTE_TOIE_SHIFT)) & CCTMR_INTE_TOIE_MASK)
#define CCTMR_INTE_CH1IE_MASK                                (0x2U)
#define CCTMR_INTE_CH1IE_SHIFT                               (1U)
#define CCTMR_INTE_CH1IE(x)                                  (((uint32_t)(((uint32_t)(x)) << CCTMR_INTE_CH1IE_SHIFT)) & CCTMR_INTE_CH1IE_MASK)
#define CCTMR_INTE_CH0IE_MASK                                (0x1U)
#define CCTMR_INTE_CH0IE_SHIFT                               (0U)
#define CCTMR_INTE_CH0IE(x)                                  (((uint32_t)(((uint32_t)(x)) << CCTMR_INTE_CH0IE_SHIFT)) & CCTMR_INTE_CH0IE_MASK)
/* CCTMR_CHSWV Register */
#define CCTMR_CHSWV_CH1SWV_MASK                              (0x2U)
#define CCTMR_CHSWV_CH1SWV_SHIFT                             (1U)
#define CCTMR_CHSWV_CH1SWV(x)                                (((uint32_t)(((uint32_t)(x)) << CCTMR_CHSWV_CH1SWV_SHIFT)) & CCTMR_CHSWV_CH1SWV_MASK)
#define CCTMR_CHSWV_CH0SWV_MASK                              (0x1U)
#define CCTMR_CHSWV_CH0SWV_SHIFT                             (0U)
#define CCTMR_CHSWV_CH0SWV(x)                                (((uint32_t)(((uint32_t)(x)) << CCTMR_CHSWV_CH0SWV_SHIFT)) & CCTMR_CHSWV_CH0SWV_MASK)
/* CCTMR_MOD Register */
#define CCTMR_MOD_MOD_MASK                                   (0xFFFFU)
#define CCTMR_MOD_MOD_SHIFT                                  (0U)
#define CCTMR_MOD_MOD(x)                                     (((uint32_t)(((uint32_t)(x)) << CCTMR_MOD_MOD_SHIFT)) & CCTMR_MOD_MOD_MASK)
/* CCTMR_CH_CTRL Register */
#define CCTMR_CH_CTRL_CAPEDGE_WIDTH                             (2)
#define CCTMR_CH_CTRL_CAPEDGE_MASK                              (0x3000000U)
#define CCTMR_CH_CTRL_CAPEDGE_SHIFT                             (24U)
#define CCTMR_CH_CTRL_CAPEDGE(x)                                (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CTRL_CAPEDGE_SHIFT)) & CCTMR_CH_CTRL_CAPEDGE_MASK)
#define CCTMR_CH_CTRL_CFCNT_WIDTH                               (4)
#define CCTMR_CH_CTRL_CFCNT_MASK                                (0xF00000U)
#define CCTMR_CH_CTRL_CFCNT_SHIFT                               (20U)
#define CCTMR_CH_CTRL_CFCNT(x)                                  (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CTRL_CFCNT_SHIFT)) & CCTMR_CH_CTRL_CFCNT_MASK)
#define CCTMR_CH_CTRL_CFPER_WIDTH                               (4)
#define CCTMR_CH_CTRL_CFPER_MASK                                (0xF0000U)
#define CCTMR_CH_CTRL_CFPER_SHIFT                               (16U)
#define CCTMR_CH_CTRL_CFPER(x)                                  (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CTRL_CFPER_SHIFT)) & CCTMR_CH_CTRL_CFPER_MASK)
#define CCTMR_CH_CTRL_VAL1CMP_WIDTH                             (2)
#define CCTMR_CH_CTRL_VAL1CMP_MASK                              (0xC000U)
#define CCTMR_CH_CTRL_VAL1CMP_SHIFT                             (14U)
#define CCTMR_CH_CTRL_VAL1CMP(x)                                (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CTRL_VAL1CMP_SHIFT)) & CCTMR_CH_CTRL_VAL1CMP_MASK)
#define CCTMR_CH_CTRL_VAL0CMP_WIDTH                             (2)
#define CCTMR_CH_CTRL_VAL0CMP_MASK                              (0x3000U)
#define CCTMR_CH_CTRL_VAL0CMP_SHIFT                             (12U)
#define CCTMR_CH_CTRL_VAL0CMP(x)                                (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CTRL_VAL0CMP_SHIFT)) & CCTMR_CH_CTRL_VAL0CMP_MASK)
#define CCTMR_CH_CTRL_PWMSRC_MASK                               (0x300U)
#define CCTMR_CH_CTRL_PWMSRC_SHIFT                              (8U)
#define CCTMR_CH_CTRL_PWMSRC(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CTRL_PWMSRC_SHIFT)) & CCTMR_CH_CTRL_PWMSRC_MASK)
#define CCTMR_CH_CTRL_VAL1TEN_MASK                              (0x20U)
#define CCTMR_CH_CTRL_VAL1TEN_SHIFT                             (5U)
#define CCTMR_CH_CTRL_VAL1TEN(x)                                (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CTRL_VAL1TEN_SHIFT)) & CCTMR_CH_CTRL_VAL1TEN_MASK)
#define CCTMR_CH_CTRL_VAL0TEN_MASK                              (0x10U)
#define CCTMR_CH_CTRL_VAL0TEN_SHIFT                             (4U)
#define CCTMR_CH_CTRL_VAL0TEN(x)                                (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CTRL_VAL0TEN_SHIFT)) & CCTMR_CH_CTRL_VAL0TEN_MASK)
#define CCTMR_CH_CTRL_CHMODE_WIDTH                              (2)
#define CCTMR_CH_CTRL_CHMODE_MASK                               (0x3U)
#define CCTMR_CH_CTRL_CHMODE_SHIFT                              (0U)
#define CCTMR_CH_CTRL_CHMODE(x)                                 (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CTRL_CHMODE_SHIFT)) & CCTMR_CH_CTRL_CHMODE_MASK)
/* CCTMR_CH_VAL0 Register */
#define CCTMR_CH_VAL0_VAL0_MASK                                 (0xFFFFU)
#define CCTMR_CH_VAL0_VAL0_SHIFT                                (0U)
#define CCTMR_CH_VAL0_VAL0(x)                                   (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_VAL0_VAL0_SHIFT)) & CCTMR_CH_VAL0_VAL0_MASK)
/* CCTMR_CH_VAL1 Register */
#define CCTMR_CH_VAL1_VAL1_MASK                                 (0xFFFFU)
#define CCTMR_CH_VAL1_VAL1_SHIFT                                (0U)
#define CCTMR_CH_VAL1_VAL1(x)                                   (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_VAL1_VAL1_SHIFT)) & CCTMR_CH_VAL1_VAL1_MASK)
/* CCTMR_CH_CVAL Register */
#define CCTMR_CH_CVAL_CVAL_MASK                                 (0xFFFFU)
#define CCTMR_CH_CVAL_CVAL_SHIFT                                (0U)
#define CCTMR_CH_CVAL_CVAL(x)                                   (((uint32_t)(((uint32_t)(x)) << CCTMR_CH_CVAL_CVAL_SHIFT)) & CCTMR_CH_CVAL_CVAL_MASK)



/*!
 * @}
 */ /* end of group CCTMR_Register_Masks */


/*!
 * @}
 */ /* end of group CCTMR_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- ADC Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup ADC_Peripheral_Access_Layer ADC Peripheral Access Layer
 * @{
 */


/** ADC - Size of Registers Arrays */
#define ADC_CHSEL_COUNT                     (8)

/* ADC Register Layout Typedef */
typedef struct {
    __IO uint32_t STS;                                /**< Status register, offset: 0x0000 */
    __IO uint32_t INTE;                               /**< Interrupt Enable Register, offset: 0x0004 */
    __IO uint32_t CTRL;                               /**< Control Register, offset: 0x0008 */
    __IO uint32_t CFG0;                               /**< Configuration 0 Register, offset: 0x000C */
    __IO uint32_t CFG1;                               /**< Configuration 1 Register, offset: 0x0010 */
    __IO uint32_t SMP;                                /**< Sampling Register, offset: 0x0014 */
    __IO uint32_t WDCTRL;                             /**< Watchdog Control Register, offset: 0x0018 */
    __IO uint32_t WDTH;                               /**< Watchdog Threshold Register, offset: 0x001C */
    __IO uint32_t Reserved0[ 3];                      /**< Reserved0, offset: 0x0020 */
    __IO uint8_t CHSEL[ 8];                          /**< Channel Configure 0 Register, offset: 0x002C */
    __IO uint32_t Reserved1[ 3];                      /**< Reserved1, offset: 0x0034 */
    __IO uint32_t DAC;                                /**< DAC Register, offset: 0x0040 */
    __IO uint32_t Reserved2[ 2];                      /**< Reserved2, offset: 0x0044 */
    __IO uint32_t FIFO;                               /**< FIFO Access Register, offset: 0x004C */
    __IO uint32_t RESERVED_14;                        /**< RESERVED_14, offset: 0x0050 */
    __IO uint32_t TRIM;                               /**< Trim Register, offset: 0x0054 */

} ADC_Type, *ADC_MemMapPtr;

/** Number of instances of the ADC module. */
#define ADC_INSTANCE_COUNT                             (1u)

/* ADC0  base address */
#define ADC0_BASE                                          (0x4003B000)
#define ADC0                                               ((ADC_Type *)(ADC0_BASE))

/** Array initializer of ADC peripheral base addresses */
#define ADC_BASE_ADDRS                                     { ADC0_BASE }
/** Array initializer of ADC peripheral base pointers */
#define ADC_BASE_PTRS                                      { ADC0 }
/** Number of interrupt vector arrays for the ADC module. */
#define ADC_IRQS_ARR_COUNT                                 (1u)
/** Number of interrupt channels for the ADC. */
#define ADC_IRQS_CH_COUNT                         (1u)
/** Interrupt vectors for the ADC peripheral type */
#define ADC_IRQS                                  { ADC0_IRQn }

/* ADC Register Mask */
/* ADC_STS Register */
#define ADC_STS_FIFOCNT_WIDTH                              (3)
#define ADC_STS_FIFOCNT_MASK                               (0x7000U)
#define ADC_STS_FIFOCNT_SHIFT                              (12U)
#define ADC_STS_FIFOCNT(x)                                 (((uint32_t)(((uint32_t)(x)) << ADC_STS_FIFOCNT_SHIFT)) & ADC_STS_FIFOCNT_MASK)
#define ADC_STS_ERR_MASK                                   (0x100U)
#define ADC_STS_ERR_SHIFT                                  (8U)
#define ADC_STS_ERR(x)                                     (((uint32_t)(((uint32_t)(x)) << ADC_STS_ERR_SHIFT)) & ADC_STS_ERR_MASK)
#define ADC_STS_WD_MASK                                    (0x80U)
#define ADC_STS_WD_SHIFT                                   (7U)
#define ADC_STS_WD(x)                                      (((uint32_t)(((uint32_t)(x)) << ADC_STS_WD_SHIFT)) & ADC_STS_WD_MASK)
#define ADC_STS_EMPTY_MASK                                 (0x40U)
#define ADC_STS_EMPTY_SHIFT                                (6U)
#define ADC_STS_EMPTY(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_STS_EMPTY_SHIFT)) & ADC_STS_EMPTY_MASK)
#define ADC_STS_FULL_MASK                                  (0x20U)
#define ADC_STS_FULL_SHIFT                                 (5U)
#define ADC_STS_FULL(x)                                    (((uint32_t)(((uint32_t)(x)) << ADC_STS_FULL_SHIFT)) & ADC_STS_FULL_MASK)
#define ADC_STS_OVR_MASK                                   (0x10U)
#define ADC_STS_OVR_SHIFT                                  (4U)
#define ADC_STS_OVR(x)                                     (((uint32_t)(((uint32_t)(x)) << ADC_STS_OVR_SHIFT)) & ADC_STS_OVR_MASK)
#define ADC_STS_EOSEQ_MASK                                 (0x8U)
#define ADC_STS_EOSEQ_SHIFT                                (3U)
#define ADC_STS_EOSEQ(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_STS_EOSEQ_SHIFT)) & ADC_STS_EOSEQ_MASK)
#define ADC_STS_EOC_MASK                                   (0x4U)
#define ADC_STS_EOC_SHIFT                                  (2U)
#define ADC_STS_EOC(x)                                     (((uint32_t)(((uint32_t)(x)) << ADC_STS_EOC_SHIFT)) & ADC_STS_EOC_MASK)
#define ADC_STS_EOSMP_MASK                                 (0x2U)
#define ADC_STS_EOSMP_SHIFT                                (1U)
#define ADC_STS_EOSMP(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_STS_EOSMP_SHIFT)) & ADC_STS_EOSMP_MASK)
#define ADC_STS_ADRDY_MASK                                 (0x1U)
#define ADC_STS_ADRDY_SHIFT                                (0U)
#define ADC_STS_ADRDY(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_STS_ADRDY_SHIFT)) & ADC_STS_ADRDY_MASK)
/* ADC_INTE Register */
#define ADC_INTE_ERRIE_MASK                                (0x100U)
#define ADC_INTE_ERRIE_SHIFT                               (8U)
#define ADC_INTE_ERRIE(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_INTE_ERRIE_SHIFT)) & ADC_INTE_ERRIE_MASK)
#define ADC_INTE_WDIE_MASK                                 (0x80U)
#define ADC_INTE_WDIE_SHIFT                                (7U)
#define ADC_INTE_WDIE(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_INTE_WDIE_SHIFT)) & ADC_INTE_WDIE_MASK)
#define ADC_INTE_OVRIE_MASK                                (0x10U)
#define ADC_INTE_OVRIE_SHIFT                               (4U)
#define ADC_INTE_OVRIE(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_INTE_OVRIE_SHIFT)) & ADC_INTE_OVRIE_MASK)
#define ADC_INTE_EOSEQIE_MASK                              (0x8U)
#define ADC_INTE_EOSEQIE_SHIFT                             (3U)
#define ADC_INTE_EOSEQIE(x)                                (((uint32_t)(((uint32_t)(x)) << ADC_INTE_EOSEQIE_SHIFT)) & ADC_INTE_EOSEQIE_MASK)
#define ADC_INTE_EOCIE_MASK                                (0x4U)
#define ADC_INTE_EOCIE_SHIFT                               (2U)
#define ADC_INTE_EOCIE(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_INTE_EOCIE_SHIFT)) & ADC_INTE_EOCIE_MASK)
#define ADC_INTE_EOSMPIE_MASK                              (0x2U)
#define ADC_INTE_EOSMPIE_SHIFT                             (1U)
#define ADC_INTE_EOSMPIE(x)                                (((uint32_t)(((uint32_t)(x)) << ADC_INTE_EOSMPIE_SHIFT)) & ADC_INTE_EOSMPIE_MASK)
#define ADC_INTE_ADRDYIE_MASK                              (0x1U)
#define ADC_INTE_ADRDYIE_SHIFT                             (0U)
#define ADC_INTE_ADRDYIE(x)                                (((uint32_t)(((uint32_t)(x)) << ADC_INTE_ADRDYIE_SHIFT)) & ADC_INTE_ADRDYIE_MASK)
/* ADC_CTRL Register */
#define ADC_CTRL_FIFORST_MASK                              (0x10U)
#define ADC_CTRL_FIFORST_SHIFT                             (4U)
#define ADC_CTRL_FIFORST(x)                                (((uint32_t)(((uint32_t)(x)) << ADC_CTRL_FIFORST_SHIFT)) & ADC_CTRL_FIFORST_MASK)
#define ADC_CTRL_ADSTOP_MASK                               (0x8U)
#define ADC_CTRL_ADSTOP_SHIFT                              (3U)
#define ADC_CTRL_ADSTOP(x)                                 (((uint32_t)(((uint32_t)(x)) << ADC_CTRL_ADSTOP_SHIFT)) & ADC_CTRL_ADSTOP_MASK)
#define ADC_CTRL_ADSTART_MASK                              (0x4U)
#define ADC_CTRL_ADSTART_SHIFT                             (2U)
#define ADC_CTRL_ADSTART(x)                                (((uint32_t)(((uint32_t)(x)) << ADC_CTRL_ADSTART_SHIFT)) & ADC_CTRL_ADSTART_MASK)
#define ADC_CTRL_ADDIS_MASK                                (0x2U)
#define ADC_CTRL_ADDIS_SHIFT                               (1U)
#define ADC_CTRL_ADDIS(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_CTRL_ADDIS_SHIFT)) & ADC_CTRL_ADDIS_MASK)
#define ADC_CTRL_ADEN_MASK                                 (0x1U)
#define ADC_CTRL_ADEN_SHIFT                                (0U)
#define ADC_CTRL_ADEN(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_CTRL_ADEN_SHIFT)) & ADC_CTRL_ADEN_MASK)
/* ADC_CFG0 Register */
#define ADC_CFG0_SEQLEN_WIDTH                              (3)
#define ADC_CFG0_SEQLEN_MASK                               (0x7000000U)
#define ADC_CFG0_SEQLEN_SHIFT                              (24U)
#define ADC_CFG0_SEQLEN(x)                                 (((uint32_t)(((uint32_t)(x)) << ADC_CFG0_SEQLEN_SHIFT)) & ADC_CFG0_SEQLEN_MASK)
#define ADC_CFG0_ALIGN_MASK                                (0x80000U)
#define ADC_CFG0_ALIGN_SHIFT                               (19U)
#define ADC_CFG0_ALIGN(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_CFG0_ALIGN_SHIFT)) & ADC_CFG0_ALIGN_MASK)
#define ADC_CFG0_OVRMD_MASK                                (0x40000U)
#define ADC_CFG0_OVRMD_SHIFT                               (18U)
#define ADC_CFG0_OVRMD(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_CFG0_OVRMD_SHIFT)) & ADC_CFG0_OVRMD_MASK)
#define ADC_CFG0_AUTOOFF_MASK                              (0x20000U)
#define ADC_CFG0_AUTOOFF_SHIFT                             (17U)
#define ADC_CFG0_AUTOOFF(x)                                (((uint32_t)(((uint32_t)(x)) << ADC_CFG0_AUTOOFF_SHIFT)) & ADC_CFG0_AUTOOFF_MASK)
#define ADC_CFG0_WAIT_MASK                                 (0x10000U)
#define ADC_CFG0_WAIT_SHIFT                                (16U)
#define ADC_CFG0_WAIT(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_CFG0_WAIT_SHIFT)) & ADC_CFG0_WAIT_MASK)
#define ADC_CFG0_TRIGMD_WIDTH                              (3)
#define ADC_CFG0_TRIGMD_MASK                               (0x700U)
#define ADC_CFG0_TRIGMD_SHIFT                              (8U)
#define ADC_CFG0_TRIGMD(x)                                 (((uint32_t)(((uint32_t)(x)) << ADC_CFG0_TRIGMD_SHIFT)) & ADC_CFG0_TRIGMD_MASK)
#define ADC_CFG0_VREF_WIDTH                                (2)
#define ADC_CFG0_VREF_MASK                                 (0x30U)
#define ADC_CFG0_VREF_SHIFT                                (4U)
#define ADC_CFG0_VREF(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_CFG0_VREF_SHIFT)) & ADC_CFG0_VREF_MASK)
#define ADC_CFG0_MODE_WIDTH                                (2)
#define ADC_CFG0_MODE_MASK                                 (0x3U)
#define ADC_CFG0_MODE_SHIFT                                (0U)
#define ADC_CFG0_MODE(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_CFG0_MODE_SHIFT)) & ADC_CFG0_MODE_MASK)
/* ADC_CFG1 Register */
#define ADC_CFG1_PRS_MASK                                  (0xF0000U)
#define ADC_CFG1_PRS_SHIFT                                 (16U)
#define ADC_CFG1_PRS(x)                                    (((uint32_t)(((uint32_t)(x)) << ADC_CFG1_PRS_SHIFT)) & ADC_CFG1_PRS_MASK)
#define ADC_CFG1_STCNT_MASK                                (0x1FFU)
#define ADC_CFG1_STCNT_SHIFT                               (0U)
#define ADC_CFG1_STCNT(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_CFG1_STCNT_SHIFT)) & ADC_CFG1_STCNT_MASK)
/* ADC_SMP Register */
#define ADC_SMP_SMP_MASK                                   (0xFFU)
#define ADC_SMP_SMP_SHIFT                                  (0U)
#define ADC_SMP_SMP(x)                                     (((uint32_t)(((uint32_t)(x)) << ADC_SMP_SMP_SHIFT)) & ADC_SMP_SMP_MASK)
/* ADC_WDCTRL Register */
#define ADC_WDCTRL_WDEN_MASK                               (0x80U)
#define ADC_WDCTRL_WDEN_SHIFT                              (7U)
#define ADC_WDCTRL_WDEN(x)                                 (((uint32_t)(((uint32_t)(x)) << ADC_WDCTRL_WDEN_SHIFT)) & ADC_WDCTRL_WDEN_MASK)
#define ADC_WDCTRL_WDSGL_MASK                              (0x40U)
#define ADC_WDCTRL_WDSGL_SHIFT                             (6U)
#define ADC_WDCTRL_WDSGL(x)                                (((uint32_t)(((uint32_t)(x)) << ADC_WDCTRL_WDSGL_SHIFT)) & ADC_WDCTRL_WDSGL_MASK)
#define ADC_WDCTRL_WDCHSEL_MASK                            (0x1FU)
#define ADC_WDCTRL_WDCHSEL_SHIFT                           (0U)
#define ADC_WDCTRL_WDCHSEL(x)                              (((uint32_t)(((uint32_t)(x)) << ADC_WDCTRL_WDCHSEL_SHIFT)) & ADC_WDCTRL_WDCHSEL_MASK)
/* ADC_WDTH Register */
#define ADC_WDTH_THMD_MASK                                 (0x80000000U)
#define ADC_WDTH_THMD_SHIFT                                (31U)
#define ADC_WDTH_THMD(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_WDTH_THMD_SHIFT)) & ADC_WDTH_THMD_MASK)
#define ADC_WDTH_HIGH_MASK                                 (0x3FF0000U)
#define ADC_WDTH_HIGH_SHIFT                                (16U)
#define ADC_WDTH_HIGH(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_WDTH_HIGH_SHIFT)) & ADC_WDTH_HIGH_MASK)
#define ADC_WDTH_LOW_MASK                                  (0x3FFU)
#define ADC_WDTH_LOW_SHIFT                                 (0U)
#define ADC_WDTH_LOW(x)                                    (((uint32_t)(((uint32_t)(x)) << ADC_WDTH_LOW_SHIFT)) & ADC_WDTH_LOW_MASK)
/* ADC_CHSEL Register */
#define ADC_CHSEL_CHSEL_MASK                               (0x1FU)
#define ADC_CHSEL_CHSEL_SHIFT                              (0U)
#define ADC_CHSEL_CHSEL(x)                                 (((uint32_t)(((uint32_t)(x)) << ADC_CHSEL_CHSEL_SHIFT)) & ADC_CHSEL_CHSEL_MASK)
/* ADC_DAC Register */
#define ADC_DAC_DACVAL_MASK                                (0x3FFU)
#define ADC_DAC_DACVAL_SHIFT                               (0U)
#define ADC_DAC_DACVAL(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_DAC_DACVAL_SHIFT)) & ADC_DAC_DACVAL_MASK)
/* ADC_FIFO Register */
#define ADC_FIFO_CHID_MASK                                 (0x1F0000U)
#define ADC_FIFO_CHID_SHIFT                                (16U)
#define ADC_FIFO_CHID(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_FIFO_CHID_SHIFT)) & ADC_FIFO_CHID_MASK)
#define ADC_FIFO_DATA_MASK                                 (0xFFFFU)
#define ADC_FIFO_DATA_SHIFT                                (0U)
#define ADC_FIFO_DATA(x)                                   (((uint32_t)(((uint32_t)(x)) << ADC_FIFO_DATA_SHIFT)) & ADC_FIFO_DATA_MASK)
/* ADC_TRIM Register */
#define ADC_TRIM_TRIM2_WIDTH                               (7)
#define ADC_TRIM_TRIM2_MASK                                (0x7F0000U)
#define ADC_TRIM_TRIM2_SHIFT                               (16U)
#define ADC_TRIM_TRIM2(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_TRIM_TRIM2_SHIFT)) & ADC_TRIM_TRIM2_MASK)
#define ADC_TRIM_TRIM1_WIDTH                               (7)
#define ADC_TRIM_TRIM1_MASK                                (0x7F00U)
#define ADC_TRIM_TRIM1_SHIFT                               (8U)
#define ADC_TRIM_TRIM1(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_TRIM_TRIM1_SHIFT)) & ADC_TRIM_TRIM1_MASK)
#define ADC_TRIM_TRIM0_WIDTH                               (7)
#define ADC_TRIM_TRIM0_MASK                                (0x7FU)
#define ADC_TRIM_TRIM0_SHIFT                               (0U)
#define ADC_TRIM_TRIM0(x)                                  (((uint32_t)(((uint32_t)(x)) << ADC_TRIM_TRIM0_SHIFT)) & ADC_TRIM_TRIM0_MASK)


/*!
 * @}
 */ /* end of group ADC_Register_Masks */


/*!
 * @}
 */ /* end of group ADC_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- PREDRV Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup PREDRV_Peripheral_Access_Layer PREDRV Peripheral Access Layer
 * @{
 */


/** PREDRV - Size of Registers Arrays */

/* PREDRV Register Layout Typedef */
typedef struct {
    __IO uint32_t STS;                                /**< Status Register, offset: 0x0000 */
    __IO uint32_t IOSTS;                              /**< Input/Output Status Register, offset: 0x0004 */
    __IO uint32_t INTE;                               /**< Interrupt Enable Register, offset: 0x0008 */
    __IO uint32_t CTRL;                               /**< Control Register, offset: 0x000C */
    __IO uint32_t FAULT0;                             /**< Fault 0 Register, offset: 0x0010 */
    __IO uint32_t FAULT1;                             /**< Fault 1 Control Register, offset: 0x0014 */
    __IO uint32_t FDRV;                               /**< Fault Driver Register, offset: 0x0018 */
    __IO uint32_t DT;                                 /**< Dead-Time Register, offset: 0x001C */
    __IO uint32_t Reserved1[ 4];                      /**< , offset: 0x0020 */
    __IO uint32_t ILS;                                /**< ILS Register, offset: 0x0030 */

} PREDRV_Type, *PREDRV_MemMapPtr;

/** Number of instances of the PREDRV module. */
#define PREDRV_INSTANCE_COUNT                          (1u)

/* PREDRV base address */
#define PREDRV_BASE                                       (0x40071000)
#define PREDRV                                            ((PREDRV_Type *)(PREDRV_BASE))

/** Array initializer of PREDRV peripheral base addresses */
#define PREDRV_BASE_ADDRS                                  { PREDRV_BASE }
/** Array initializer of PREDRV peripheral base pointers */
#define PREDRV_BASE_PTRS                                   { PREDRV }
/** Number of interrupt vector arrays for the PREDRV module. */
#define PREDRV_IRQS_ARR_COUNT                              (2u)
/** Number of interrupt channels for the FAULT type of PREDRV. */
#define PREDRV_FAULT_IRQS_CH_COUNT                 (1u)
#define PREDRV_FAULT_IRQS                          { PREDRV_Fault_IRQn }
/** Number of interrupt channels for the VDS type of PREDRV. */
#define PREDRV_VDS_IRQS_CH_COUNT                   (1u)
#define PREDRV_VDS_IRQS                            { PREDRV_Vds_IRQn }

/* PREDRV Register Mask */
/* PREDRV_STS Register */
#define PREDRV_STS_VDSTF_MASK                                 (0x800U)
#define PREDRV_STS_VDSTF_SHIFT                                (11U)
#define PREDRV_STS_VDSTF(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_STS_VDSTF_SHIFT)) & PREDRV_STS_VDSTF_MASK)
#define PREDRV_STS_VDSWF_MASK                                 (0x400U)
#define PREDRV_STS_VDSWF_SHIFT                                (10U)
#define PREDRV_STS_VDSWF(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_STS_VDSWF_SHIFT)) & PREDRV_STS_VDSWF_MASK)
#define PREDRV_STS_VDSVF_MASK                                 (0x200U)
#define PREDRV_STS_VDSVF_SHIFT                                (9U)
#define PREDRV_STS_VDSVF(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_STS_VDSVF_SHIFT)) & PREDRV_STS_VDSVF_MASK)
#define PREDRV_STS_VDSUF_MASK                                 (0x100U)
#define PREDRV_STS_VDSUF_SHIFT                                (8U)
#define PREDRV_STS_VDSUF(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_STS_VDSUF_SHIFT)) & PREDRV_STS_VDSUF_MASK)
#define PREDRV_STS_F3F_MASK                                   (0x8U)
#define PREDRV_STS_F3F_SHIFT                                  (3U)
#define PREDRV_STS_F3F(x)                                     (((uint32_t)(((uint32_t)(x)) << PREDRV_STS_F3F_SHIFT)) & PREDRV_STS_F3F_MASK)
#define PREDRV_STS_F2F_MASK                                   (0x4U)
#define PREDRV_STS_F2F_SHIFT                                  (2U)
#define PREDRV_STS_F2F(x)                                     (((uint32_t)(((uint32_t)(x)) << PREDRV_STS_F2F_SHIFT)) & PREDRV_STS_F2F_MASK)
#define PREDRV_STS_F1F_MASK                                   (0x2U)
#define PREDRV_STS_F1F_SHIFT                                  (1U)
#define PREDRV_STS_F1F(x)                                     (((uint32_t)(((uint32_t)(x)) << PREDRV_STS_F1F_SHIFT)) & PREDRV_STS_F1F_MASK)
#define PREDRV_STS_F0F_MASK                                   (0x1U)
#define PREDRV_STS_F0F_SHIFT                                  (0U)
#define PREDRV_STS_F0F(x)                                     (((uint32_t)(((uint32_t)(x)) << PREDRV_STS_F0F_SHIFT)) & PREDRV_STS_F0F_MASK)
/* PREDRV_IOSTS Register */
#define PREDRV_IOSTS_F3_MASK                                  (0x8U)
#define PREDRV_IOSTS_F3_SHIFT                                 (3U)
#define PREDRV_IOSTS_F3(x)                                    (((uint32_t)(((uint32_t)(x)) << PREDRV_IOSTS_F3_SHIFT)) & PREDRV_IOSTS_F3_MASK)
#define PREDRV_IOSTS_F2_MASK                                  (0x4U)
#define PREDRV_IOSTS_F2_SHIFT                                 (2U)
#define PREDRV_IOSTS_F2(x)                                    (((uint32_t)(((uint32_t)(x)) << PREDRV_IOSTS_F2_SHIFT)) & PREDRV_IOSTS_F2_MASK)
#define PREDRV_IOSTS_F1_MASK                                  (0x2U)
#define PREDRV_IOSTS_F1_SHIFT                                 (1U)
#define PREDRV_IOSTS_F1(x)                                    (((uint32_t)(((uint32_t)(x)) << PREDRV_IOSTS_F1_SHIFT)) & PREDRV_IOSTS_F1_MASK)
#define PREDRV_IOSTS_F0_MASK                                  (0x1U)
#define PREDRV_IOSTS_F0_SHIFT                                 (0U)
#define PREDRV_IOSTS_F0(x)                                    (((uint32_t)(((uint32_t)(x)) << PREDRV_IOSTS_F0_SHIFT)) & PREDRV_IOSTS_F0_MASK)
/* PREDRV_INTE Register */
#define PREDRV_INTE_VDSIE_MASK                                (0x100U)
#define PREDRV_INTE_VDSIE_SHIFT                               (8U)
#define PREDRV_INTE_VDSIE(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_INTE_VDSIE_SHIFT)) & PREDRV_INTE_VDSIE_MASK)
#define PREDRV_INTE_FIE_MASK                                  (0x1U)
#define PREDRV_INTE_FIE_SHIFT                                 (0U)
#define PREDRV_INTE_FIE(x)                                    (((uint32_t)(((uint32_t)(x)) << PREDRV_INTE_FIE_SHIFT)) & PREDRV_INTE_FIE_MASK)
/* PREDRV_CTRL Register */
#define PREDRV_CTRL_UNLOCK_MASK                               (0x80000000U)
#define PREDRV_CTRL_UNLOCK_SHIFT                              (31U)
#define PREDRV_CTRL_UNLOCK(x)                                 (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_UNLOCK_SHIFT)) & PREDRV_CTRL_UNLOCK_MASK)
#define PREDRV_CTRL_LOCK_MASK                                 (0x40000000U)
#define PREDRV_CTRL_LOCK_SHIFT                                (30U)
#define PREDRV_CTRL_LOCK(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_LOCK_SHIFT)) & PREDRV_CTRL_LOCK_MASK)
#define PREDRV_CTRL_FDRVPRI_WIDTH                             (3)
#define PREDRV_CTRL_FDRVPRI_MASK                              (0x7000000U)
#define PREDRV_CTRL_FDRVPRI_SHIFT                             (24U)
#define PREDRV_CTRL_FDRVPRI(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_FDRVPRI_SHIFT)) & PREDRV_CTRL_FDRVPRI_MASK)
#define PREDRV_CTRL_TDRV_MASK                                 (0xC00000U)
#define PREDRV_CTRL_TDRV_SHIFT                                (22U)
#define PREDRV_CTRL_TDRV(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_TDRV_SHIFT)) & PREDRV_CTRL_TDRV_MASK)
#define PREDRV_CTRL_WDRV_MASK                                 (0x300000U)
#define PREDRV_CTRL_WDRV_SHIFT                                (20U)
#define PREDRV_CTRL_WDRV(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_WDRV_SHIFT)) & PREDRV_CTRL_WDRV_MASK)
#define PREDRV_CTRL_VDRV_MASK                                 (0xC0000U)
#define PREDRV_CTRL_VDRV_SHIFT                                (18U)
#define PREDRV_CTRL_VDRV(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_VDRV_SHIFT)) & PREDRV_CTRL_VDRV_MASK)
#define PREDRV_CTRL_UDRV_MASK                                 (0x30000U)
#define PREDRV_CTRL_UDRV_SHIFT                                (16U)
#define PREDRV_CTRL_UDRV(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_UDRV_SHIFT)) & PREDRV_CTRL_UDRV_MASK)
#define PREDRV_CTRL_CSEN_MASK                                 (0x1000U)
#define PREDRV_CTRL_CSEN_SHIFT                                (12U)
#define PREDRV_CTRL_CSEN(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_CSEN_SHIFT)) & PREDRV_CTRL_CSEN_MASK)
#define PREDRV_CTRL_CSCAL_MASK                                (0x100U)
#define PREDRV_CTRL_CSCAL_SHIFT                               (8U)
#define PREDRV_CTRL_CSCAL(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_CSCAL_SHIFT)) & PREDRV_CTRL_CSCAL_MASK)
#define PREDRV_CTRL_VSMSW_MASK                                (0x10U)
#define PREDRV_CTRL_VSMSW_SHIFT                               (4U)
#define PREDRV_CTRL_VSMSW(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_VSMSW_SHIFT)) & PREDRV_CTRL_VSMSW_MASK)
#define PREDRV_CTRL_EN_MASK                                   (0x1U)
#define PREDRV_CTRL_EN_SHIFT                                  (0U)
#define PREDRV_CTRL_EN(x)                                     (((uint32_t)(((uint32_t)(x)) << PREDRV_CTRL_EN_SHIFT)) & PREDRV_CTRL_EN_MASK)
/* PREDRV_FAULT0 Register */
#define PREDRV_FAULT0_VDSSW_MASK                              (0x1000000U)
#define PREDRV_FAULT0_VDSSW_SHIFT                             (24U)
#define PREDRV_FAULT0_VDSSW(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_VDSSW_SHIFT)) & PREDRV_FAULT0_VDSSW_MASK)
#define PREDRV_FAULT0_TVDS_WIDTH                              (8)
#define PREDRV_FAULT0_TVDS_MASK                               (0xFF0000U)
#define PREDRV_FAULT0_TVDS_SHIFT                              (16U)
#define PREDRV_FAULT0_TVDS(x)                                 (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_TVDS_SHIFT)) & PREDRV_FAULT0_TVDS_MASK)
#define PREDRV_FAULT0_VDSTEN_MASK                             (0x800U)
#define PREDRV_FAULT0_VDSTEN_SHIFT                            (11U)
#define PREDRV_FAULT0_VDSTEN(x)                               (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_VDSTEN_SHIFT)) & PREDRV_FAULT0_VDSTEN_MASK)
#define PREDRV_FAULT0_VDSWEN_MASK                             (0x400U)
#define PREDRV_FAULT0_VDSWEN_SHIFT                            (10U)
#define PREDRV_FAULT0_VDSWEN(x)                               (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_VDSWEN_SHIFT)) & PREDRV_FAULT0_VDSWEN_MASK)
#define PREDRV_FAULT0_VDSVEN_MASK                             (0x200U)
#define PREDRV_FAULT0_VDSVEN_SHIFT                            (9U)
#define PREDRV_FAULT0_VDSVEN(x)                               (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_VDSVEN_SHIFT)) & PREDRV_FAULT0_VDSVEN_MASK)
#define PREDRV_FAULT0_VDSUEN_MASK                             (0x100U)
#define PREDRV_FAULT0_VDSUEN_SHIFT                            (8U)
#define PREDRV_FAULT0_VDSUEN(x)                               (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_VDSUEN_SHIFT)) & PREDRV_FAULT0_VDSUEN_MASK)
#define PREDRV_FAULT0_OCPEN_MASK                              (0x8U)
#define PREDRV_FAULT0_OCPEN_SHIFT                             (3U)
#define PREDRV_FAULT0_OCPEN(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_OCPEN_SHIFT)) & PREDRV_FAULT0_OCPEN_MASK)
#define PREDRV_FAULT0_OTPEN_MASK                              (0x4U)
#define PREDRV_FAULT0_OTPEN_SHIFT                             (2U)
#define PREDRV_FAULT0_OTPEN(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_OTPEN_SHIFT)) & PREDRV_FAULT0_OTPEN_MASK)
#define PREDRV_FAULT0_UVPEN_MASK                              (0x2U)
#define PREDRV_FAULT0_UVPEN_SHIFT                             (1U)
#define PREDRV_FAULT0_UVPEN(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_UVPEN_SHIFT)) & PREDRV_FAULT0_UVPEN_MASK)
#define PREDRV_FAULT0_OVPEN_MASK                              (0x1U)
#define PREDRV_FAULT0_OVPEN_SHIFT                             (0U)
#define PREDRV_FAULT0_OVPEN(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT0_OVPEN_SHIFT)) & PREDRV_FAULT0_OVPEN_MASK)
/* PREDRV_FAULT1 Register */
#define PREDRV_FAULT1_FFCNT_WIDTH                             (4)
#define PREDRV_FAULT1_FFCNT_MASK                              (0xF0000000U)
#define PREDRV_FAULT1_FFCNT_SHIFT                             (28U)
#define PREDRV_FAULT1_FFCNT(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_FFCNT_SHIFT)) & PREDRV_FAULT1_FFCNT_MASK)
#define PREDRV_FAULT1_FFPER_WIDTH                             (4)
#define PREDRV_FAULT1_FFPER_MASK                              (0xF000000U)
#define PREDRV_FAULT1_FFPER_SHIFT                             (24U)
#define PREDRV_FAULT1_FFPER(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_FFPER_SHIFT)) & PREDRV_FAULT1_FFPER_MASK)
#define PREDRV_FAULT1_STRETCH_MASK                            (0x200000U)
#define PREDRV_FAULT1_STRETCH_SHIFT                           (21U)
#define PREDRV_FAULT1_STRETCH(x)                              (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_STRETCH_SHIFT)) & PREDRV_FAULT1_STRETCH_MASK)
#define PREDRV_FAULT1_FCOMB_MASK                              (0x100000U)
#define PREDRV_FAULT1_FCOMB_SHIFT                             (20U)
#define PREDRV_FAULT1_FCOMB(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_FCOMB_SHIFT)) & PREDRV_FAULT1_FCOMB_MASK)
#define PREDRV_FAULT1_RCVRY_WIDTH                             (1)
#define PREDRV_FAULT1_RCVRY_MASK                              (0x40000U)
#define PREDRV_FAULT1_RCVRY_SHIFT                             (18U)
#define PREDRV_FAULT1_RCVRY(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_RCVRY_SHIFT)) & PREDRV_FAULT1_RCVRY_MASK)
#define PREDRV_FAULT1_FAUTO_MASK                              (0x30000U)
#define PREDRV_FAULT1_FAUTO_SHIFT                             (16U)
#define PREDRV_FAULT1_FAUTO(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_FAUTO_SHIFT)) & PREDRV_FAULT1_FAUTO_MASK)
#define PREDRV_FAULT1_F3POL_MASK                              (0x800U)
#define PREDRV_FAULT1_F3POL_SHIFT                             (11U)
#define PREDRV_FAULT1_F3POL(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_F3POL_SHIFT)) & PREDRV_FAULT1_F3POL_MASK)
#define PREDRV_FAULT1_F2POL_MASK                              (0x400U)
#define PREDRV_FAULT1_F2POL_SHIFT                             (10U)
#define PREDRV_FAULT1_F2POL(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_F2POL_SHIFT)) & PREDRV_FAULT1_F2POL_MASK)
#define PREDRV_FAULT1_F1POL_MASK                              (0x200U)
#define PREDRV_FAULT1_F1POL_SHIFT                             (9U)
#define PREDRV_FAULT1_F1POL(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_F1POL_SHIFT)) & PREDRV_FAULT1_F1POL_MASK)
#define PREDRV_FAULT1_F0POL_MASK                              (0x100U)
#define PREDRV_FAULT1_F0POL_SHIFT                             (8U)
#define PREDRV_FAULT1_F0POL(x)                                (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_F0POL_SHIFT)) & PREDRV_FAULT1_F0POL_MASK)
#define PREDRV_FAULT1_F3EN_MASK                               (0x8U)
#define PREDRV_FAULT1_F3EN_SHIFT                              (3U)
#define PREDRV_FAULT1_F3EN(x)                                 (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_F3EN_SHIFT)) & PREDRV_FAULT1_F3EN_MASK)
#define PREDRV_FAULT1_F2EN_MASK                               (0x4U)
#define PREDRV_FAULT1_F2EN_SHIFT                              (2U)
#define PREDRV_FAULT1_F2EN(x)                                 (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_F2EN_SHIFT)) & PREDRV_FAULT1_F2EN_MASK)
#define PREDRV_FAULT1_F1EN_MASK                               (0x2U)
#define PREDRV_FAULT1_F1EN_SHIFT                              (1U)
#define PREDRV_FAULT1_F1EN(x)                                 (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_F1EN_SHIFT)) & PREDRV_FAULT1_F1EN_MASK)
#define PREDRV_FAULT1_F0EN_MASK                               (0x1U)
#define PREDRV_FAULT1_F0EN_SHIFT                              (0U)
#define PREDRV_FAULT1_F0EN(x)                                 (((uint32_t)(((uint32_t)(x)) << PREDRV_FAULT1_F0EN_SHIFT)) & PREDRV_FAULT1_F0EN_MASK)
/* PREDRV_FDRV Register */
#define PREDRV_FDRV_OCDRV_MASK                                (0x3000000U)
#define PREDRV_FDRV_OCDRV_SHIFT                               (24U)
#define PREDRV_FDRV_OCDRV(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_FDRV_OCDRV_SHIFT)) & PREDRV_FDRV_OCDRV_MASK)
#define PREDRV_FDRV_VDSDRV_MASK                               (0xC00000U)
#define PREDRV_FDRV_VDSDRV_SHIFT                              (22U)
#define PREDRV_FDRV_VDSDRV(x)                                 (((uint32_t)(((uint32_t)(x)) << PREDRV_FDRV_VDSDRV_SHIFT)) & PREDRV_FDRV_VDSDRV_MASK)
#define PREDRV_FDRV_OTDRV_MASK                                (0x300000U)
#define PREDRV_FDRV_OTDRV_SHIFT                               (20U)
#define PREDRV_FDRV_OTDRV(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_FDRV_OTDRV_SHIFT)) & PREDRV_FDRV_OTDRV_MASK)
#define PREDRV_FDRV_UVDRV_MASK                                (0xC0000U)
#define PREDRV_FDRV_UVDRV_SHIFT                               (18U)
#define PREDRV_FDRV_UVDRV(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_FDRV_UVDRV_SHIFT)) & PREDRV_FDRV_UVDRV_MASK)
#define PREDRV_FDRV_OVDRV_MASK                                (0x30000U)
#define PREDRV_FDRV_OVDRV_SHIFT                               (16U)
#define PREDRV_FDRV_OVDRV(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_FDRV_OVDRV_SHIFT)) & PREDRV_FDRV_OVDRV_MASK)
#define PREDRV_FDRV_F3DRV_MASK                                (0xC0U)
#define PREDRV_FDRV_F3DRV_SHIFT                               (6U)
#define PREDRV_FDRV_F3DRV(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_FDRV_F3DRV_SHIFT)) & PREDRV_FDRV_F3DRV_MASK)
#define PREDRV_FDRV_F2DRV_MASK                                (0x30U)
#define PREDRV_FDRV_F2DRV_SHIFT                               (4U)
#define PREDRV_FDRV_F2DRV(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_FDRV_F2DRV_SHIFT)) & PREDRV_FDRV_F2DRV_MASK)
#define PREDRV_FDRV_F1DRV_MASK                                (0xCU)
#define PREDRV_FDRV_F1DRV_SHIFT                               (2U)
#define PREDRV_FDRV_F1DRV(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_FDRV_F1DRV_SHIFT)) & PREDRV_FDRV_F1DRV_MASK)
#define PREDRV_FDRV_F0DRV_MASK                                (0x3U)
#define PREDRV_FDRV_F0DRV_SHIFT                               (0U)
#define PREDRV_FDRV_F0DRV(x)                                  (((uint32_t)(((uint32_t)(x)) << PREDRV_FDRV_F0DRV_SHIFT)) & PREDRV_FDRV_F0DRV_MASK)
/* PREDRV_DT Register */
#define PREDRV_DT_ITOPDT_MASK                                 (0xFF000000U)
#define PREDRV_DT_ITOPDT_SHIFT                                (24U)
#define PREDRV_DT_ITOPDT(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_DT_ITOPDT_SHIFT)) & PREDRV_DT_ITOPDT_MASK)
#define PREDRV_DT_IBOTDT_MASK                                 (0xFF0000U)
#define PREDRV_DT_IBOTDT_SHIFT                                (16U)
#define PREDRV_DT_IBOTDT(x)                                   (((uint32_t)(((uint32_t)(x)) << PREDRV_DT_IBOTDT_SHIFT)) & PREDRV_DT_IBOTDT_MASK)
#define PREDRV_DT_TOPDT_MASK                                  (0xFF00U)
#define PREDRV_DT_TOPDT_SHIFT                                 (8U)
#define PREDRV_DT_TOPDT(x)                                    (((uint32_t)(((uint32_t)(x)) << PREDRV_DT_TOPDT_SHIFT)) & PREDRV_DT_TOPDT_MASK)
#define PREDRV_DT_BOTDT_MASK                                  (0xFFU)
#define PREDRV_DT_BOTDT_SHIFT                                 (0U)
#define PREDRV_DT_BOTDT(x)                                    (((uint32_t)(((uint32_t)(x)) << PREDRV_DT_BOTDT_SHIFT)) & PREDRV_DT_BOTDT_MASK)
/* PREDRV_ILS Register */
#define PREDRV_ILS_TRIM_MASK                                  (0x3U)
#define PREDRV_ILS_TRIM_SHIFT                                 (0U)
#define PREDRV_ILS_TRIM(x)                                    (((uint32_t)(((uint32_t)(x)) << PREDRV_ILS_TRIM_SHIFT)) & PREDRV_ILS_TRIM_MASK)


/*!
 * @}
 */ /* end of group PREDRV_Register_Masks */


/*!
 * @}
 */ /* end of group PREDRV_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- ZDU Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup ZDU_Peripheral_Access_Layer ZDU Peripheral Access Layer
 * @{
 */


/** ZDU - Size of Registers Arrays */

/* ZDU Register Layout Typedef */
typedef struct {
    __IO uint32_t STS;                                /**< Status Register, offset: 0x0000 */
    __IO uint32_t INTE;                               /**< Interrupt Enable Register, offset: 0x0004 */
    __IO uint32_t CTRL;                               /**< Control Register, offset: 0x0008 */
    __IO uint32_t MUX;                                /**< MUX Register, offset: 0x000C */
    __IO uint32_t FILT;                               /**< Synchronous Register, offset: 0x0010 */
    __IO uint32_t MON;                                /**< Synchronous Register, offset: 0x0020 */

} ZDU_Type, *ZDU_MemMapPtr;

/** Number of instances of the ZDU module. */
#define ZDU_INSTANCE_COUNT                             (1u)

/* ZDU base address */
#define ZDU_BASE                                          (0x40073000)
#define ZDU                                               ((ZDU_Type *)(ZDU_BASE))

/** Array initializer of ZDU peripheral base addresses */
#define ZDU_BASE_ADDRS                                     { ZDU_BASE }
/** Array initializer of ZDU peripheral base pointers */
#define ZDU_BASE_PTRS                                      { ZDU }

/* ZDU Register Mask */
/* ZDU_STS Register */
#define ZDU_STS_NF_MASK                                    (0x4U)
#define ZDU_STS_NF_SHIFT                                   (2U)
#define ZDU_STS_NF(x)                                      (((uint32_t)(((uint32_t)(x)) << ZDU_STS_NF_SHIFT)) & ZDU_STS_NF_MASK)
#define ZDU_STS_PF_MASK                                    (0x2U)
#define ZDU_STS_PF_SHIFT                                   (1U)
#define ZDU_STS_PF(x)                                      (((uint32_t)(((uint32_t)(x)) << ZDU_STS_PF_SHIFT)) & ZDU_STS_PF_MASK)
#define ZDU_STS_OUT_MASK                                   (0x1U)
#define ZDU_STS_OUT_SHIFT                                  (0U)
#define ZDU_STS_OUT(x)                                     (((uint32_t)(((uint32_t)(x)) << ZDU_STS_OUT_SHIFT)) & ZDU_STS_OUT_MASK)
/* ZDU_INTE Register */
#define ZDU_INTE_IE_MASK                                   (0x1U)
#define ZDU_INTE_IE_SHIFT                                  (0U)
#define ZDU_INTE_IE(x)                                     (((uint32_t)(((uint32_t)(x)) << ZDU_INTE_IE_SHIFT)) & ZDU_INTE_IE_MASK)
/* ZDU_CTRL Register */
#define ZDU_CTRL_OTSEL_WIDTH                               (2)
#define ZDU_CTRL_OTSEL_MASK                                (0x300000U)
#define ZDU_CTRL_OTSEL_SHIFT                               (20U)
#define ZDU_CTRL_OTSEL(x)                                  (((uint32_t)(((uint32_t)(x)) << ZDU_CTRL_OTSEL_SHIFT)) & ZDU_CTRL_OTSEL_MASK)
#define ZDU_CTRL_OTEN_MASK                                 (0x10000U)
#define ZDU_CTRL_OTEN_SHIFT                                (16U)
#define ZDU_CTRL_OTEN(x)                                   (((uint32_t)(((uint32_t)(x)) << ZDU_CTRL_OTEN_SHIFT)) & ZDU_CTRL_OTEN_MASK)
#define ZDU_CTRL_EDGESEL_WIDTH                             (2)
#define ZDU_CTRL_EDGESEL_MASK                              (0x3000U)
#define ZDU_CTRL_EDGESEL_SHIFT                             (12U)
#define ZDU_CTRL_EDGESEL(x)                                (((uint32_t)(((uint32_t)(x)) << ZDU_CTRL_EDGESEL_SHIFT)) & ZDU_CTRL_EDGESEL_MASK)
#define ZDU_CTRL_OUTSEL_MASK                               (0x100U)
#define ZDU_CTRL_OUTSEL_SHIFT                              (8U)
#define ZDU_CTRL_OUTSEL(x)                                 (((uint32_t)(((uint32_t)(x)) << ZDU_CTRL_OUTSEL_SHIFT)) & ZDU_CTRL_OUTSEL_MASK)
#define ZDU_CTRL_MODE_MASK                                 (0x10U)
#define ZDU_CTRL_MODE_SHIFT                                (4U)
#define ZDU_CTRL_MODE(x)                                   (((uint32_t)(((uint32_t)(x)) << ZDU_CTRL_MODE_SHIFT)) & ZDU_CTRL_MODE_MASK)
#define ZDU_CTRL_EN_MASK                                   (0x1U)
#define ZDU_CTRL_EN_SHIFT                                  (0U)
#define ZDU_CTRL_EN(x)                                     (((uint32_t)(((uint32_t)(x)) << ZDU_CTRL_EN_SHIFT)) & ZDU_CTRL_EN_MASK)
/* ZDU_MUX Register */
#define ZDU_MUX_PHSEL_WIDTH                                (2)
#define ZDU_MUX_PHSEL_MASK                                 (0x3U)
#define ZDU_MUX_PHSEL_SHIFT                                (0U)
#define ZDU_MUX_PHSEL(x)                                   (((uint32_t)(((uint32_t)(x)) << ZDU_MUX_PHSEL_SHIFT)) & ZDU_MUX_PHSEL_MASK)
/* ZDU_FILT Register */
#define ZDU_FILT_FCNT_WIDTH                                (8)
#define ZDU_FILT_FCNT_MASK                                 (0xFF00U)
#define ZDU_FILT_FCNT_SHIFT                                (8U)
#define ZDU_FILT_FCNT(x)                                   (((uint32_t)(((uint32_t)(x)) << ZDU_FILT_FCNT_SHIFT)) & ZDU_FILT_FCNT_MASK)
#define ZDU_FILT_FPER_WIDTH                                (4)
#define ZDU_FILT_FPER_MASK                                 (0xFU)
#define ZDU_FILT_FPER_SHIFT                                (0U)
#define ZDU_FILT_FPER(x)                                   (((uint32_t)(((uint32_t)(x)) << ZDU_FILT_FPER_SHIFT)) & ZDU_FILT_FPER_MASK)
/* ZDU_MON Register */
#define ZDU_MON_NPEN_MASK                                  (0x2U)
#define ZDU_MON_NPEN_SHIFT                                 (1U)
#define ZDU_MON_NPEN(x)                                    (((uint32_t)(((uint32_t)(x)) << ZDU_MON_NPEN_SHIFT)) & ZDU_MON_NPEN_MASK)
#define ZDU_MON_PPEN_MASK                                  (0x1U)
#define ZDU_MON_PPEN_SHIFT                                 (0U)
#define ZDU_MON_PPEN(x)                                    (((uint32_t)(((uint32_t)(x)) << ZDU_MON_PPEN_SHIFT)) & ZDU_MON_PPEN_MASK)


/*!
 * @}
 */ /* end of group ZDU_Register_Masks */


/*!
 * @}
 */ /* end of group ZDU_Peripheral_Access_Layer */


/* -------------------------------------------------------------
   -- WDG Peripheral Access Layer
   ------------------------------------------------------------- */

/*!
 * @addtogroup WDG_Peripheral_Access_Layer WDG Peripheral Access Layer
 * @{
 */


/** WDG - Size of Registers Arrays */

/* WDG Register Layout Typedef */
typedef struct {
    __O  uint32_t SVCR;                               /**< Service Code Register, offset: 0x0000 */
    __IO uint32_t CR;                                 /**< Control Register, offset: 0x0004 */
    __IO uint32_t LR;                                 /**< Lock Register, offset: 0x0008 */
    __IO uint32_t TOVR;                               /**< Timer Overflow Value, offset: 0x000C */
    __IO uint32_t WVR;                                /**< Window Value Register, offset: 0x0010 */
    __I  uint32_t CNTCVR;                             /**< Counter Current Value Register, offset: 0x0014 */
    __IO uint32_t INTF;                               /**< Interrupt Flag register, offset: 0x0018 */

} WDG_Type, *WDG_MemMapPtr;

/** Number of instances of the WDG module. */
#define WDG_INSTANCE_COUNT                             (1u)

/* WDG base address */
#define WDG_BASE                                          (0x40052000)
#define WDG                                               ((WDG_Type *)(WDG_BASE))

/** Array initializer of WDG peripheral base addresses */
#define WDG_BASE_ADDRS                                     { WDG_BASE }
/** Array initializer of WDG peripheral base pointers */
#define WDG_BASE_PTRS                                      { WDG }
/** Number of interrupt vector arrays for the WDG module. */
#define WDG_IRQS_ARR_COUNT                                 (1u)
/** Number of interrupt channels for the WDG. */
#define WDG_IRQS_CH_COUNT                         (1u)
/** Interrupt vectors for the WDG peripheral type */
#define WDG_IRQS                                  { WDG_IRQn }

/* WDG Register Mask */
/* WDG_SVCR Register */
#define WDG_SVCR_SVCODE_MASK                               (0xFFFFU)
#define WDG_SVCR_SVCODE_SHIFT                              (0U)
#define WDG_SVCR_SVCODE(x)                                 (((uint32_t)(((uint32_t)(x)) << WDG_SVCR_SVCODE_SHIFT)) & WDG_SVCR_SVCODE_MASK)
/* WDG_CR Register */
#define WDG_CR_RIA_MASK                                    (0x80U)
#define WDG_CR_RIA_SHIFT                                   (7U)
#define WDG_CR_RIA(x)                                      (((uint32_t)(((uint32_t)(x)) << WDG_CR_RIA_SHIFT)) & WDG_CR_RIA_MASK)
#define WDG_CR_WIN_MASK                                    (0x40U)
#define WDG_CR_WIN_SHIFT                                   (6U)
#define WDG_CR_WIN(x)                                      (((uint32_t)(((uint32_t)(x)) << WDG_CR_WIN_SHIFT)) & WDG_CR_WIN_MASK)
#define WDG_CR_IBR_MASK                                    (0x20U)
#define WDG_CR_IBR_SHIFT                                   (5U)
#define WDG_CR_IBR(x)                                      (((uint32_t)(((uint32_t)(x)) << WDG_CR_IBR_SHIFT)) & WDG_CR_IBR_MASK)
#define WDG_CR_CLKSRC_MASK                                 (0x18U)
#define WDG_CR_CLKSRC_SHIFT                                (3U)
#define WDG_CR_CLKSRC(x)                                   (((uint32_t)(((uint32_t)(x)) << WDG_CR_CLKSRC_SHIFT)) & WDG_CR_CLKSRC_MASK)
#define WDG_CR_DSDIS_MASK                                  (0x4U)
#define WDG_CR_DSDIS_SHIFT                                 (2U)
#define WDG_CR_DSDIS(x)                                    (((uint32_t)(((uint32_t)(x)) << WDG_CR_DSDIS_SHIFT)) & WDG_CR_DSDIS_MASK)
#define WDG_CR_DBGDIS_MASK                                 (0x2U)
#define WDG_CR_DBGDIS_SHIFT                                (1U)
#define WDG_CR_DBGDIS(x)                                   (((uint32_t)(((uint32_t)(x)) << WDG_CR_DBGDIS_SHIFT)) & WDG_CR_DBGDIS_MASK)
#define WDG_CR_EN_MASK                                     (0x1U)
#define WDG_CR_EN_SHIFT                                    (0U)
#define WDG_CR_EN(x)                                       (((uint32_t)(((uint32_t)(x)) << WDG_CR_EN_SHIFT)) & WDG_CR_EN_MASK)
/* WDG_LR Register */
#define WDG_LR_HL_MASK                                     (0x2U)
#define WDG_LR_HL_SHIFT                                    (1U)
#define WDG_LR_HL(x)                                       (((uint32_t)(((uint32_t)(x)) << WDG_LR_HL_SHIFT)) & WDG_LR_HL_MASK)
#define WDG_LR_SL_MASK                                     (0x1U)
#define WDG_LR_SL_SHIFT                                    (0U)
#define WDG_LR_SL(x)                                       (((uint32_t)(((uint32_t)(x)) << WDG_LR_SL_SHIFT)) & WDG_LR_SL_MASK)
/* WDG_TOVR Register */
#define WDG_TOVR_TO_MASK                                   (0xFFFFU)
#define WDG_TOVR_TO_SHIFT                                  (0U)
#define WDG_TOVR_TO(x)                                     (((uint32_t)(((uint32_t)(x)) << WDG_TOVR_TO_SHIFT)) & WDG_TOVR_TO_MASK)
/* WDG_WVR Register */
#define WDG_WVR_WIN_MASK                                   (0xFFFFU)
#define WDG_WVR_WIN_SHIFT                                  (0U)
#define WDG_WVR_WIN(x)                                     (((uint32_t)(((uint32_t)(x)) << WDG_WVR_WIN_SHIFT)) & WDG_WVR_WIN_MASK)
/* WDG_CNTCVR Register */
#define WDG_CNTCVR_CVAL_MASK                               (0xFFFFU)
#define WDG_CNTCVR_CVAL_SHIFT                              (0U)
#define WDG_CNTCVR_CVAL(x)                                 (((uint32_t)(((uint32_t)(x)) << WDG_CNTCVR_CVAL_SHIFT)) & WDG_CNTCVR_CVAL_MASK)
/* WDG_INTF Register */
#define WDG_INTF_IF_MASK                                   (0x1U)
#define WDG_INTF_IF_SHIFT                                  (0U)
#define WDG_INTF_IF(x)                                     (((uint32_t)(((uint32_t)(x)) << WDG_INTF_IF_SHIFT)) & WDG_INTF_IF_MASK)


/*!
 * @}
 */ /* end of group WDG_Register_Masks */


/*!
 * @}
 */ /* end of group WDG_Peripheral_Access_Layer */




/* ----------------------------------------------------------------------------
   -- Device Peripheral Access Layer for YTM32Z1MC0
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Peripheral_access_layer_YTM32B1L Device Peripheral Access Layer for YTM32Z1MC0
 * @{
 */

/* @brief This module covers memory mapped registers available on SoC */

/* ----------------------------------------------------------------------------
   -- Backward Compatibility for YTM32Z1MC0
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Backward_Compatibility_Symbols_YTM32Z1MC0 Backward Compatibility for YTM32Z1MC0
 * @{
 */

/* No backward compatibility issues. */

/*!
 * @}
 */ /* end of group Backward_Compatibility_Symbols_YTM32Z1MC0 */


#else /* #if !defined(YTM32Z1MC0_H_) */
  /* There is already included the same memory map. Check if it is compatible (has the same major version) */
  #if (MCU_MEM_MAP_VERSION != 0x0100u)
    #if (!defined(MCU_MEM_MAP_SUPPRESS_VERSION_WARNING))
      #warning There are included two not compatible versions of memory maps. Please check possible differences.
    #endif /* (!defined(MCU_MEM_MAP_SUPPRESS_VERSION_WARNING)) */
  #endif /* (MCU_MEM_MAP_VERSION != 0x0100u) */
#endif  /* #if !defined(YTM32Z1MC0_H_) */

/* YTM32Z1MC0.h, eof. */